# -*- encoding: utf-8 -*-
# frozen_string_literal: true
# This file generated automatically using rdf vocabulary format from http://purl.org/dcx/lrmi-terms/
require 'rdf'
module RDF::Vocab
  # Vocabulary for <http://purl.org/dcx/lrmi-terms/>
  # @!visibility private
  LRMI = Class.new(RDF::Vocabulary("http://purl.org/dcx/lrmi-terms/")) do

    # Ontology definition
    ontology :"http://purl.org/dcx/lrmi-terms/",
      "http://purl.org/dc/terms/creator": {en: "LRMI Task Group"},
      "http://purl.org/dc/terms/description": {en: "The LRMI specification is a collection of classes and properties for markup and description of educational resources. The specification builds on the extensive vocabulary provided by Schema.org and other standards. Note: the labels provided here are not considered normative."},
      "http://purl.org/dc/terms/identifier": "http://dublincore.org/dcx/lrmi-terms/",
      "http://purl.org/dc/terms/isVersionOf": "http://purl.org/dcx/lrmi-terms/1.1/",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://purl.org/dc/terms/license": "https://creativecommons.org/licenses/by/4.0/",
      "http://purl.org/dc/terms/title": {en: "LRMI RDF Specification"},
      "http://www.w3.org/2004/02/skos/core#historyNote": "2020-11-12: changes made reflecting developments in schema.org: added class LearningResource; added properties assesses, educationalLevel, teaches; fixed error in domain of timerequired; updated label and definition of isBasedOnUrl; skos:scopeNote used instead of dcterms:description for additional non-normative information; note added that rdfs:label is not considered normative; rangeIncludes statements updated to include skos:Concept for terms where there is an LRMI Concept Scheme or that reference a competence."

    # Class definitions
    term :AlignmentObject,
      comment: {en: "An intangible item that describes an alignment between a learning resource and a node in an educational framework."},
      equivalentClass: "http://schema.org/AlignmentObject",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added scopeNote",
      "http://www.w3.org/2004/02/skos/core#scopeNote": "This class should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Alignment Object"},
      subClassOf: "http://schema.org/Intangible",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :EducationalAudience,
      comment: {en: "An individual or group for whom the learning resource was created or useful."},
      equivalentClass: "http://schema.org/EducationalAudience",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Audience"},
      subClassOf: "http://schema.org/Intangible",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :LearningResource,
      comment: {en: "A persistent resource that has one or more physical or digital representations, and that explicitly involves, specifies or entails a learning activity or learning experience."},
      equivalentClass: "http://schema.org/LearningResource",
      "http://purl.org/dc/terms/issued": "2020-11-12",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "LearningResource is expected to be used as an addition to a primary type such as http://purl.org/ontology/bibo/Book, https://schema.org/Video, http://purl.org/dc/terms/PhysicalResource etc."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Learning Resource"},
      subClassOf: "http://schema.org/CreativeWork",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"

    # Property definitions
    property :alignmentType,
      comment: {en: "A category of alignment between the learning resource and the framework node."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      equivalentProperty: "http://schema.org/alignmentType",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added scopeNote; added skos:Concept to rangeIncludes.",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'. For 'assesses', 'teaches', and 'educationLevel' the specific properties with those names should be used."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Alignment Type"},
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :assesses,
      comment: {en: "The item being described is intended to assess the competency or learning outcome defined by the referenced term."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/assesses",
      "http://purl.org/dc/terms/issued": "2020-11-12",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Assesses"},
      rangeIncludes: ["http://schema.org/DefinedTerm", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :educationalAlignment,
      comment: {en: "An alignment to an established educational framework."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/educationalAlignment",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added scopeNote",
      "http://www.w3.org/2004/02/skos/core#scopeNote": "This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Alignment"},
      rangeIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :educationalFramework,
      comment: {en: "The framework to which the resource being described is aligned."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      equivalentProperty: "http://schema.org/educationalFramework",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Framework"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :educationalLevel,
      comment: "The level of a resource in terms of progression through an educational or training context.",
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/assesses",
      "http://purl.org/dc/terms/issued": "2020-11-12",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Level"},
      rangeIncludes: ["http://schema.org/DefinedTerm", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :educationalRole,
      comment: {en: "The role that describes the target audience of the content."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/EducationalAudience", "http://schema.org/EducationalAudience"],
      equivalentProperty: "http://schema.org/educationalRole",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added skos:Concept to rangeIncludes",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "The educational function assumed or part played by the group for whom the resource is intended."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Role"},
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :educationalUse,
      comment: {en: "The purpose of a work in the context of education."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: ["http://schema.org/educationalUse", "http://www.w3.org/2004/02/skos/core#Concept"],
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added skos:Concept to rangeIncludes",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "For example, 'assignment', 'group work'."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Educational Use"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :interactivityType,
      comment: {en: "The predominant mode of learning supported by the learning resource."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/interactivityType",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added skos:Concept to rangeIncludes",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "Based on, and mappable from, IEEE LOM 5.1: Interactivity Type."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Interactivity Type"},
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :isBasedOnUrl,
      comment: {en: "A resource from which this work is derived or from which it is a modification or adaption."},
      domainIncludes: "http://schema.org/CreativeWork",
      equivalentProperty: ["http://schema.org/isBasedOn", "http://schema.org/isBasedOnUrl"],
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "This term can be repeated for multiple sources."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Is Based On"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#anyURI",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :learningResourceType,
      comment: {en: "The predominant type or kind characterizing the learning resource."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/learningResourceType",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "For example, 'presentation', 'handout'."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Learning Resource Type"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :targetDescription,
      comment: {en: "The description of a node in an established educational framework."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      equivalentProperty: "http://schema.org/targetDescription",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Target Description"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :targetName,
      comment: {en: "The name of a node in an established educational framework."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      equivalentProperty: "http://schema.org/targetName",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Target Name"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :targetUrl,
      comment: {en: "The URL of a node in an established educational framework."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject", "http://schema.org/AlignmentObject"],
      equivalentProperty: "http://schema.org/targetUrl",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Target URL"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#anyURI",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :teaches,
      comment: {en: "The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term."},
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource", "http://schema.org/CreativeWork", "http://schema.org/LearningResource"],
      equivalentProperty: "http://schema.org/teaches",
      "http://purl.org/dc/terms/issued": "2020-11-12",
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Teaches"},
      rangeIncludes: ["http://schema.org/DefinedTerm", "http://www.w3.org/2004/02/skos/core#Concept"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :timeRequired,
      comment: {en: "Approximate or typical time it takes to work with or through this learning resource for the typical intended target audience."},
      domainIncludes: "http://schema.org/CreativeWork",
      equivalentProperty: "http://schema.org/timeRequired",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: error in domain fixed, changed from lrmi:AlignmentObject to schema:CreativeWork",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "For example, 'PT30M' and 'PT1H25M'"},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Time Required"},
      rangeIncludes: "http://schema.org/Duration",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :typicalAgeRange,
      comment: {en: "The typical expected age range."},
      domainIncludes: "http://schema.org/CreativeWork",
      equivalentProperty: "http://schema.org/typicalAgeRange",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "For example, '7-9', '18-'."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Typical Age Range"},
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :useRightsUrl,
      comment: {en: "The URL where the owner specifies permissions for using the   resource."},
      domainIncludes: "http://schema.org/CreativeWork",
      "http://purl.org/dc/terms/issued": "2015-02-09",
      "http://www.w3.org/2004/02/skos/core#scopeNote": {en: "For example: 'http://creativecommons.org/licenses/by/3.0/',\n   'http://publisher.com/content-use-description'."},
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/",
      label: {en: "Use Rights URL"},
      rangeIncludes: ["http://schema.org/CreativeWork", "http://www.w3.org/2001/XMLSchema#anyURI"],
      subPropertyOf: "http://schema.org/license",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
  end
end
