# -*- encoding: utf-8 -*-
# frozen_string_literal: true
# This file generated automatically using rdf vocabulary format from http://www.loc.gov/mods/rdf/v1#
require 'rdf'
module RDF::Vocab
  # Vocabulary for <http://www.loc.gov/mods/rdf/v1#>
  # @!visibility private
  MODS = Class.new(RDF::StrictVocabulary("http://www.loc.gov/mods/rdf/v1#")) do

    # Ontology definition
    ontology :"http://www.loc.gov/mods/rdf/v1#",
      "http://www.w3.org/2002/07/owl#imports": ["http://id.loc.gov/ontologies/ClassificationSchemes", "http://id.loc.gov/ontologies/Identifiers", "http://id.loc.gov/ontologies/ResourceTypes", "http://id.loc.gov/ontologies/Roles", "http://id.loc.gov/ontologies/TargetAudiences", "http://purl.org/dc/dcmitype/", "http://purl.org/dc/elements/1.1/", "http://purl.org/vocab/changeset/schema", "http://purl.org/vocab/vann/", "http://vocab.org/changeset/", "http://www.loc.gov/mads/rdf/v1", "http://www.loc.gov/standards/mads/rdf/v1.rdf", "http://www.w3.org/2004/02/skos/core", "http://www.w3.org/2008/05/skos-xl", "http://xmlns.com/foaf/0.1/"],
      type: "http://www.w3.org/2002/07/owl#Ontology"

    # Class definitions
    term :Cartographics,
      comment: "Aggregates cartographic properties.",
      label: "MODS - Cartographic Information",
      subClassOf: "http://www.w3.org/2002/07/owl#Thing",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :ClassificationGroup,
      comment: "For a classification whose scheme is not part of the controlled vocabulary. Bundles together a classification number and scheme.",
      label: "MODS - Classification Group",
      subClassOf: "http://www.w3.org/2002/07/owl#Thing",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :IdentifierGroup,
      comment: "Used when the identifier type is not from the controlled list. Bundles together an identifier and its type.",
      label: "MODS - Identifier - Typed",
      subClassOf: "http://www.w3.org/2002/07/owl#Thing",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Location,
      comment: {en: "An aggregator for location properties."},
      label: "MODS - Location",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :LocationCopy,
      comment: " An aggregator for copy properties.",
      label: "MODS - Location - Copy",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :ModsResource,
      comment: "\nThe resource which is the subject of this description.\n  ",
      equivalentClass: "http://id.loc.gov/vocabulary/resourceTypes/Res",
      label: "MODS - A  MODS Resource",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :NoteGroup,
      comment: "Aggregates a note with its type.  ",
      label: "MODS - Note Typed",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Part,
      comment: {en: "An aggregator for part properties."},
      label: "MODS - Part",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :RoleRelationship,
      comment: "Aggregates a name with its role. ",
      label: "MODS - Role Relationship",
      type: "http://www.w3.org/2002/07/owl#Class"

    # Property definitions
    property :abstract,
      comment: "A summary of the content of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Abstract",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :accessCondition,
      comment: "Information about restrictions imposed on access to  the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Access Condition",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :adminMetadata,
      comment: "Administrative metadata for the MODS description, corresponds to recordInfo (MODS XML) which is, minimimally, a Class defined outside of the MADS/RDF namespace. The RecordInfo Class from the RecordInfo ontology is recommended.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Administrative Metadata",
      range: "http://id.loc.gov/ontologies/RecordInfo#AdminMetadata",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :cartographics,
      comment: "A geographic entity expressed in cartographic terms.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Cartographics ",
      range: "http://www.loc.gov/mods/rdf/v1#Cartographics",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :cartographicsCoordinates,
      domain: "http://www.loc.gov/mods/rdf/v1#Cartographics",
      label: "Cartographics - Coordinates",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: ["http://www.w3.org/1999/02/22-rdf-syntax-ns#Property", "http://www.w3.org/2002/07/owl#DatatypeProperty"]
    property :cartographicsProjection,
      domain: "http://www.loc.gov/mods/rdf/v1#Cartographics",
      label: "Cartographics - Projection",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: ["http://www.w3.org/1999/02/22-rdf-syntax-ns#Property", "http://www.w3.org/2002/07/owl#DatatypeProperty"]
    property :cartographicsScale,
      domain: "http://www.loc.gov/mods/rdf/v1#Cartographics",
      label: "Cartographics - Scale",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :classification,
      comment: "A designation applied to the resource that indicates the subject by applying a formal system of coding and organizing resources according to subject areas.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      equivalentProperty: "http://id.loc.gov/vocabulary/classSchemes/classification",
      label: "Classification",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :classificationGroup,
      comment: "Used when classification scheme is not in controlled vocabulary. Bundles together the classification number with its scheme.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Classification Group",
      range: "http://www.loc.gov/mods/rdf/v1#ClassificationGroup",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :classificationGroupScheme,
      comment: "The classification scheme",
      domain: "http://www.loc.gov/mods/rdf/v1#ClassificationGroup",
      label: "Classification Group - Scheme",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :classificationGroupValue,
      comment: "The classification value",
      domain: "http://www.loc.gov/mods/rdf/v1#ClassificationGroup",
      label: "Classification Group - Value",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :dateCaptured,
      comment: "Date that the resource  was digitized or a subsequent snapshot was taken.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Captured",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateCapturedEnd,
      comment: "When there is both a start and end for the capture date this is the end  date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Captured - End",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateCaptured",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateCapturedStart,
      comment: "When there is both a start and end for the capture date this is the start date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Captured -  Start",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateCaptured",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateCreated,
      comment: "The resource's creation date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: " Date Created",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateCreatedEnd,
      comment: "When there is both a start and end for the creation date this is the end date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Created - End",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateCreated",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateCreatedStart,
      comment: "When there is both a start and end for the creation date this is the start date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Created -  Start",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateCreated",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateModified,
      comment: "Date when resource was modified.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Modified",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateModifiedEnd,
      comment: "When there is both a start and end for the modification date this is the end date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Modified - End",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateModified",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateModifiedStart,
      comment: "When there is both a start and end for the modification date this is the start date.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Modified -  Start",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateModified",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateOfCopyright,
      comment: "Date when resource was copyrighted.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date of Copyright",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateOfCopyrightEnd,
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date of Copyright - End",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateOfCopyright",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateOfCopyrightStart,
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date of Copyright -  Start",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateOfCopyright",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateValid,
      comment: "A date when resource was valid. (Not necessarily the first or last date, but this is an assertion that on that given date the information was valid.)",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Valid",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateValidEnd,
      comment: "When the resource is valid over an interval with a start and end date, this is the end date. (When start and end date are given, it is an assertion that the information was valid over the course of this interval.  It does not necessarily assert that is was not valid before the start or after the end of the interval.)",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Valid - End",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateValid",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :dateValidStart,
      comment: "When the resource is valid over an interval with a start and end date, this is the start date. (When start and end date are given, it is an assertion that the information was valid over the course of this interval.  It does not necessarily assert that is was not valid before the start or after the end of the interval.)",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date Valid -  Start",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#dateValid",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :digitalOrigin,
      comment: "a designation of the source of a digital file important to its creation, use and management.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Digital Origin",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :edition,
      comment: "Version of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Edition",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :frequency,
      comment: "publication frequency",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Frequency",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :genre,
      comment: "The genre (or one of several genres) of the resource. Represented in the MADS namespace. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Genre",
      range: "http://www.loc.gov/mads/rdf/v1#GenreForm",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :identifier,
      comment: "identifier is a property for which all terms in the \"identifier\" vocabulary become subproperties.  Thus for example 'identifer:isbn' is a subproperty saying in effect \"has this ISBN\" where 'isbn' is a term within that vocabulary. (The prefix 'identifier:' is used to denote the namespace for the \"identifier\" vocabulary.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      equivalentProperty: "http://id.loc.gov/vocabulary/identifiers/id",
      label: "Identifier",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :identifierGroup,
      comment: "Used when identifier type is not in controlled vocabulary. Bundles together the identifier with its type.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Identifier Group",
      range: "http://www.loc.gov/mods/rdf/v1#IdentifierGroup",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :identifierGroupType,
      comment: "The identifier type.",
      domain: "http://www.loc.gov/mods/rdf/v1#IdentifierGroup",
      label: "Identifier Group - Type",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :identifierGroupValue,
      comment: "The identifier value\t.",
      domain: "http://www.loc.gov/mods/rdf/v1#IdentifierGroup",
      label: "Identifier Group - Value",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :identifierValue,
      comment: "Used in conjuction with identifierType, when the type is not from the controlled vocabulary.",
      domain: "http://www.loc.gov/mods/rdf/v1#IdentifierGroup",
      label: "Identifier - Value",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :issuance,
      comment: "Describes the issuance of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Issuance",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :languageOfResource,
      comment: "The language (or one of several languages) of the resource. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Language of Resource",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :locationCopy,
      comment: "Information about a specific tangible instance of a bibliographic resource or set which comprises one or more pieces via indication of sublocation and/or locator.",
      domain: "http://www.loc.gov/mods/rdf/v1#Location",
      label: "Location - Copy",
      range: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :locationCopyElectronicLocator,
      comment: "URI of the copy of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy -- Electronic Locator",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyEnumerationAndChronology,
      comment: "A summary holdings statement for the copy. A string with information including volume or issue, date of publication or date of issue of a component of a multi-part resource, distinguishing it from other components of the same resource. ",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy  - Enumeration And Chronology",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyEnumerationAndChronologyBasic,
      comment: "One of three levels of enumerationAndChronology: 'basic'",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy  - Enumeration And Chronology -- Basic",
      range: "http://www.w3.org/2001/XMLSchema#string",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#locationCopyEnumerationAndChronology",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyEnumerationAndChronologyIndex,
      comment: "One of three levels of enumerationAndChronology:'index'",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy  - Enumeration And Chronology -- Index",
      range: "http://www.w3.org/2001/XMLSchema#string",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#locationCopyEnumerationAndChronology",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyEnumerationAndChronologySupplement,
      comment: "One of three levels  of enumerationAndChronology:'supplement'",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy  - Enumeration And Chronology -- Supplement",
      range: "http://www.w3.org/2001/XMLSchema#string",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#locationCopyEnumerationAndChronology",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyForm,
      comment: "The form of a particular copy may be indicated when the general description refers to multiple forms and there is different detailed holdings information associated with different forms.",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy -- Form",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyNote,
      comment: "A note pertaining to a specific copy.",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy -- Note",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopyShelfLocator,
      comment: "Shelfmark or other shelving designation that indicates the location identifier for a copy.",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy -- Shelf Locator",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationCopySublocation,
      comment: "Department, division, or section of an institution holding a copy of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#LocationCopy",
      label: "Location - Copy -- Sublocation",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationOfResource,
      comment: "The location (or one of several locations) at which the resource resides.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Location",
      range: "http://www.loc.gov/mods/rdf/v1#Location",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :locationPhysical,
      comment: "The institution or repository that holds the resource, or where it is available.",
      domain: "http://www.loc.gov/mods/rdf/v1#Location",
      label: "Location - Physical Location",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationShelfLocator,
      comment: "Shelfmark or other shelving designation",
      domain: "http://www.loc.gov/mods/rdf/v1#Location",
      label: "Location - Shelf Locator",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :locationUrl,
      comment: "Location of the resource (a URL)",
      domain: "http://www.loc.gov/mods/rdf/v1#Location",
      label: "Location - URL",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :mediaType,
      comment: "An Internet Media (MIME) type e.g. text/html. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Media Type",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :name,
      comment: "A name  - personal, corporate, conference, or family - associated with the resource. Represented in the MADS namespace. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Name",
      range: "http://www.loc.gov/mads/rdf/v1#Name",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :namePrincipal,
      comment: "A name that has been distinguished as the principal name associated with the resource. There should be no more than one name principal name. (The rule for determining the principal name is as follows: If the role associated with the name is 'creator' AND if it is the only name whose role is 'creator' then it is the principal name. Thus if there are more than one name, or no name, whose role is 'creator', then there is no principal name.) If there is a principal name, and if there is a uniform title, then that name and title are to be combined into a nameTitle. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Name -  Principle",
      range: "http://www.loc.gov/mads/rdf/v1#Name",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#name",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :note,
      comment: "Textual information about the resource. This property is used when no type is specified. (In contrast to hasTypedNote, whose object is an aggregator that includes both the type and note.)",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Note",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :noteGroup,
      comment: "Used for a note with a type (other than \"statement of responsibility\")",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Note  Group",
      range: "http://www.loc.gov/mods/rdf/v1#NoteGroup",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :noteGroupType,
      comment: "A property of NoteGroup - used when a type is supplied for the note.  The type.",
      domain: "http://www.loc.gov/mods/rdf/v1#NoteGroup",
      label: "NoteGroup - Type",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :noteGroupValue,
      comment: "A property of noteGroup - used when a type is supplied for the note. The text of the note.",
      domain: "http://www.loc.gov/mods/rdf/v1#NoteGroup",
      label: "NoteGroup - Value",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :part,
      comment: "Information about a physical part of the resource, including the part number, its caption and title, and dimensions. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Part",
      range: "http://www.loc.gov/mods/rdf/v1#Part",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :partDate,
      comment: "Date associated with a part.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part Date",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#date",
      type: "http://www.w3.org/2002/07/owl#AnnotationProperty"
    property :partDetailType,
      comment: "The type of the resource part, e.g. volume, issue, page.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Detail Type",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partEnd,
      comment: "The value of the end of a part. For example, if unit of the part has value 'page', this is the number of the last page. ",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - End",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partLevel,
      comment: "A property of a part - the level of numbering in the host/parent item.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Level",
      range: "http://www.w3.org/2001/XMLSchema#positiveInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partList,
      comment: "A property of a part - a textual listing of the units within the part.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - List",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partName,
      comment: "A string that designates the part name.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Name",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partNumber,
      comment: "A string that designates the part number.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Number",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partOrder,
      comment: "An integer that designates the sequence of parts",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Order",
      range: "http://www.w3.org/2001/XMLSchema#integer",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partStart,
      comment: "The beginning unit of the part.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Start",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partTotal,
      comment: "The total number of units within a part.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Total",
      range: "http://www.w3.org/2001/XMLSchema#positiveInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partType,
      comment: "The segment type of a part. (When parts are included, the resource is ususally a document, so the part type would be the segment type of the document.)",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Type",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :partUnit,
      comment: "the unit -- e.g. page, chapter -- applying to the start, end, and total values.",
      domain: "http://www.loc.gov/mods/rdf/v1#Part",
      label: "Part - Unit",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :physicalExtent,
      comment: "a statement of the number and specific material of the units of the resource that express physical extent.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Physical Extent",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :physicalForm,
      comment: "A particular physical presentation of the resource, including the physical form or medium of material for a resource. Example: oil paint",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Physical Form",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :placeOfOrigin,
      comment: "Place of publication/origin. Used in connection with the origin of a resource, i.e., creation, publication, issuance, etc.  Represented as a MADS Geographic.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Place",
      range: "http://www.loc.gov/mads/rdf/v1#Geographic",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :publisher,
      comment: "The name of the entity that published, printed, distributed, released, issued, or produced the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Publisher",
      range: "http://www.loc.gov/mads/rdf/v1#Name",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :recordContentSource,
      comment: "The code or name of the organization that either created the original description or modified it.",
      domain: "http://id.loc.gov/ontologies/RecordInfo#AdminMetadata",
      label: "Record Content Source",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :recordDescriptionStandard,
      comment: "Part of administrative metadata. The standard  which designates the rules used for the content of the description.",
      domain: "http://id.loc.gov/ontologies/RecordInfo#AdminMetadata",
      label: "Record Description Standard",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :recordIdentifier,
      comment: "The system control number assigned by the organization creating, using, or distributing the description.",
      domain: "http://id.loc.gov/ontologies/RecordInfo#AdminMetadata",
      label: "Record Identifier",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :recordOrigin,
      comment: "Describes the origin or provenance of the description.",
      domain: "http://id.loc.gov/ontologies/RecordInfo#AdminMetadata",
      label: "Record Origin",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :reformattingQuality,
      comment: "The reformatting quality;  e.g. access, preservation,  replacement.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Reformatting Quality",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :relatedConstituent,
      comment: "Relates the described MODS resource to another MODS resource which is a constituent of the described resource. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Constituent",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedFormat,
      comment: "Relates the described MODS resource to a similar MODS resource of a different format.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Other Format",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedHost,
      comment: "Relates the described MODS resource to another MODS resource which is a host of the described resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Host",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedInstantiation,
      comment: "Relates the described resource to a another MODS resource with different origination information.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Instantiation",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedItem,
      comment: "Relates the described MODS resource to another, related MODS resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related Item",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedOriginal,
      comment: "Relates the described MODS resource to another MODS resource which is an original of the described resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Original",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedPreceding,
      comment: "Relates the described MODS resource to a MODS resource which preceded the described resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Preceding",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedReference,
      comment: "Relates the described MODS resource to another MODS resource which the described resource references.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Reference",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedReferencedBy,
      comment: ["", "Relates the described MODS resource to another MODS resource which references the described resource."],
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Referenced By",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedReview,
      comment: "Relates the described MODS resource to another MODS resource which is review of the described resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Review",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedSeries,
      comment: "Relates the described resource to a another MODS resource which is a series of which the described resource is a part.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Series",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedSucceeding,
      comment: "Relates the described resource to a another MODS resource which suceeded it.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related item - Suceeding",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :relatedVersion,
      comment: "Relates the described MODS resource to another MODS resource which is a different version of the described resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Related Item - Other Version",
      range: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#relatedItem",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :role,
      comment: "role is an abstract property, for which all terms in the relator vocabulary of roles become subproperties.  Thus for example 'relator:artist' refers to the role 'artist' within that vocabulary. (The prefix 'relator:' is used to denote the namespace for the \"relator\" vocabulary. \n\nThe property 'relator:artist' relates the resource to an artist associated with the resource, represented as a mads name.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      equivalentProperty: "http://id.loc.gov/vocabulary/relators/role",
      label: "Role (unbound)",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :roleRelationship,
      comment: "Binds a name to the role that the named entity played for the resource. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Role Relationship",
      range: "http://www.loc.gov/mods/rdf/v1#RoleRelationship",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :roleRelationshipName,
      comment: "The name included in a roleRelationship.  The roleRelationship binds an name and a role, where the name is a name associated with the resource and is specified elsewhere via the hasName property.  This mechanism is used when the role is not part of a known vocabulary.  Otherwise, the relationship is expressed by using the role vocabulary term as the property; for example, see relator:creator.",
      domain: "http://www.loc.gov/mods/rdf/v1#RoleRelationship",
      label: "Role Relationship - Name",
      range: "http://www.loc.gov/mads/rdf/v1#Name",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :roleRelationshipRole,
      comment: "The role associated with a name, where the name and role are bound together in a roleRelationship.",
      domain: "http://www.loc.gov/mods/rdf/v1#RoleRelationship",
      label: "Role Relationship -  Role",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :statementOfResponsibility,
      comment: "A note, when the note type is \"statement of responsibility\"",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Statement of Responsibility",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :subject,
      comment: "An abstract property defined for which the various subject catergories (e.g. subjectGenre, subjectTitle) are subproperties.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectComplex,
      comment: "A subject of the resource composed of several component subjects. ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Complex",
      range: "http://www.loc.gov/mads/rdf/v1#ComplexSubject",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectGenre,
      comment: "A subject of the resource which is a genre, expressed in terms of a MADS GenreForm.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Genre Subject",
      range: "http://www.loc.gov/mads/rdf/v1#GenreForm",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectGeographic,
      comment: "A subject of the resource which is a geographic entity, expressed in terms of a MADS Geographic.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Geographic ",
      range: "http://www.loc.gov/mads/rdf/v1#Geographic",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectGeographicCode,
      comment: "A subject of the resource which is a geographic entity, expressed as a geographic code and in terms of a MADS Geographic.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Geographic Code ",
      range: "http://www.loc.gov/mads/rdf/v1#Geographic",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subjectGeographic",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectHierarchicalGeographic,
      comment: "A subject of the resource which is a hierarchy of geographic entities expressed in terms of a MADS Geographics.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject -  Hierarchical Geographic ",
      range: "http://www.loc.gov/mads/rdf/v1#HierarchicalGeographic",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectName,
      comment: "A subject of the resource which is a name, expressed in terms of a MADS Name.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Name Subject",
      range: "http://www.loc.gov/mads/rdf/v1#Name",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectOccupation,
      comment: "A subject of the resource which is an occupation, expressed in terms of a MADS Occupation.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Occupation",
      range: "http://www.loc.gov/mads/rdf/v1#Occupation",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectTemporal,
      comment: "A subject of the resource which is a temporal expression, expressed in terms of a MADS Temporal.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Temporal",
      range: "http://www.loc.gov/mads/rdf/v1#Temporal",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectTitle,
      comment: "A subject of the resource which is a title, expressed in terms of a MADS Title.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Title",
      range: "http://www.loc.gov/mads/rdf/v1#Title",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subjectTopic,
      comment: "A subject of the resource which is a topic, expressed in terms of a MADS Topic.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Subject - Topic",
      range: "http://www.loc.gov/mads/rdf/v1#Topic",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :tableOfContents,
      comment: "Description of the contents of the resource.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Table of Contents",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :targetAudience,
      comment: "The target audience of the resource. Examples: adolescent, adult, general, juvenile, preschool,  specialized.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Target Audience",
      range: "http://www.w3.org/2001/XMLSchema#string",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :title,
      comment: "A title for the resource. Represented as a MADS Title.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Title",
      range: "http://www.loc.gov/mads/rdf/v1#Title",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :titlePrincipal,
      comment: "A title which has been distinguished as the principal  title. (This corresponds to a MODS XML titleInfo with  no type attribute.) There should be no more than one principal title. Represented as a MADS Title.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Title - Principal",
      range: "http://www.loc.gov/mads/rdf/v1#Title",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#title",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :titleUniform,
      comment: "A title which has been distinguished as a uniform title. (This corresponds to a MODS XML titleInfo with 'type=uniform' attribute.) There should be no more than one uniform title.  Represented as a MADS Title, or, if there is a primary name, it is represented as a MADS NameTitle.  ",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Title - Uniform",
      range: "http://www.loc.gov/mads/rdf/v1#Title",
      subPropertyOf: "http://www.loc.gov/mods/rdf/v1#title",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"

    # Extra definitions
    term :access,
      type: ["http://www.loc.gov/mods/rdf/ReformattingQuality", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :date,
      comment: "An abstract property for which date properties in general are subproperties.",
      domain: "http://www.loc.gov/mods/rdf/v1#ModsResource",
      label: "Date"
    term :digitizedAnalog,
      type: ["http://www.loc.gov/mods/rdf/DigitalOrigin", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :digitizedMicrofilm,
      type: ["http://www.loc.gov/mods/rdf/DigitalOrigin", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :integratingResource,
      type: ["http://www.loc.gov/mods/rdf/Issuance", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :monographic,
      type: ["http://www.loc.gov/mods/rdf/Issuance", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :reformattedDigital,
      type: ["http://www.loc.gov/mods/rdf/DigitalOrigin", "http://www.w3.org/2002/07/owl#NamedIndividual"]
    term :serial,
      type: ["http://www.loc.gov/mods/rdf/Issuance", "http://www.w3.org/2002/07/owl#NamedIndividual"]
  end
end
