# -*- encoding: utf-8 -*-
# frozen_string_literal: true
# This file generated automatically using rdf vocabulary format from http://rdfs.org/sioc/ns#
require 'rdf'
module RDF::Vocab
  # Vocabulary for <http://rdfs.org/sioc/ns#>
  # @!visibility private
  SIOC = Class.new(RDF::StrictVocabulary("http://rdfs.org/sioc/ns#")) do

    # Ontology definition
    ontology :"http://rdfs.org/sioc/ns#",
      "http://purl.org/dc/terms/description": {en: "SIOC (Semantically-Interlinked Online Communities) is an ontology for describing the information in online communities. \nThis information can be used to export information from online communities and to link them together. The scope of the application areas that SIOC can be used for includes (and is not limited to) weblogs, message boards, mailing lists and chat channels."},
      "http://purl.org/dc/terms/title": {en: "SIOC Core Ontology Namespace"},
      "http://www.w3.org/2000/01/rdf-schema#seeAlso": "http://rdfs.org/sioc/spec",
      "http://www.w3.org/2002/07/owl#versionInfo": "Revision: 1.36",
      type: ["http://www.w3.org/2002/07/owl#Ontology", "http://www.w3.org/2002/07/owl#Thing"]

    # Class definitions
    term :Community,
      comment: {en: "Community is a high-level concept that defines an online community and what it consists of."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#UserAccount"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Community"},
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Container,
      comment: {en: "An area in which content Items are contained."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#UserAccount", "http://rdfs.org/sioc/ns#Usergroup"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Container"},
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Forum,
      comment: {en: "A discussion area on which Posts or entries are made."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Forum"},
      subClassOf: "http://rdfs.org/sioc/ns#Container",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Item,
      comment: {en: "An Item is something which can be in a Container."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Container", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#Space", "http://rdfs.org/sioc/ns#UserAccount", "http://rdfs.org/sioc/ns#Usergroup"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Item"},
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Post,
      comment: {en: "An article or message that can be posted to a Forum."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Post"},
      subClassOf: ["http://rdfs.org/sioc/ns#Item", "http://xmlns.com/foaf/0.1/Document"],
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Role,
      comment: {en: "A Role is a function of a UserAccount within a scope of a particular Forum, Site, etc."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Container", "http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Space", "http://rdfs.org/sioc/ns#UserAccount", "http://rdfs.org/sioc/ns#Usergroup"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Role"},
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Site,
      comment: {en: "A Site can be the location of an online community or set of communities, with UserAccounts and Usergroups creating Items in a set of Containers. It can be thought of as a web-accessible data Space."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Site"},
      subClassOf: "http://rdfs.org/sioc/ns#Space",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Space,
      comment: {en: "A Space is a place where data resides, e.g. on a website, desktop, fileshare, etc."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#UserAccount", "http://rdfs.org/sioc/ns#Usergroup"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Space"},
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Thread,
      comment: {en: "A container for a series of threaded discussion Posts or Items."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Thread"},
      subClassOf: "http://rdfs.org/sioc/ns#Container",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :User,
      comment: {en: "UserAccount is now preferred. This is a deprecated class for a User in an online community site."},
      equivalentClass: "http://rdfs.org/sioc/ns#UserAccount",
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Container", "http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#Space", "http://rdfs.org/sioc/ns#Usergroup"],
      "http://www.w3.org/2002/07/owl#versionInfo": "This class is deprecated. Use sioc:UserAccount from the SIOC ontology instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "User"},
      subClassOf: "http://xmlns.com/foaf/0.1/OnlineAccount",
      type: "http://www.w3.org/2002/07/owl#DeprecatedClass"
    term :UserAccount,
      comment: {en: "A user account in an online community site."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Container", "http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#Space", "http://rdfs.org/sioc/ns#Usergroup"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "User Account"},
      subClassOf: "http://xmlns.com/foaf/0.1/OnlineAccount",
      type: "http://www.w3.org/2002/07/owl#Class"
    term :Usergroup,
      comment: {en: "A set of UserAccounts whose owners have a common purpose or interest. Can be used for access control purposes."},
      "http://www.w3.org/2002/07/owl#disjointWith": ["http://rdfs.org/sioc/ns#Container", "http://rdfs.org/sioc/ns#Item", "http://rdfs.org/sioc/ns#Role", "http://rdfs.org/sioc/ns#Space", "http://rdfs.org/sioc/ns#UserAccount"],
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "Usergroup"},
      type: "http://www.w3.org/2002/07/owl#Class"

    # Property definitions
    property :about,
      comment: {en: "Specifies that this Item is about a particular resource, e.g. a Post describing a book, hotel, etc."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "about"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :account_of,
      comment: {en: "Refers to the foaf:Agent or foaf:Person who owns this sioc:UserAccount."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://xmlns.com/foaf/0.1/account",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "account of"},
      range: "http://xmlns.com/foaf/0.1/Agent",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :addressed_to,
      comment: {en: "Refers to who (e.g. a UserAccount, e-mail address, etc.) a particular Item is addressed to."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "addressed to"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :administrator_of,
      comment: {en: "A Site that the UserAccount is an administrator of."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_administrator",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "administrator of"},
      range: "http://rdfs.org/sioc/ns#Site",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :attachment,
      comment: {en: "The URI of a file attached to an Item."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "attachment"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :avatar,
      comment: {en: "An image or depiction used to represent this UserAccount."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "avatar"},
      subPropertyOf: "http://xmlns.com/foaf/0.1/depiction",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :container_of,
      comment: {en: "An Item that this Container contains."},
      domain: "http://rdfs.org/sioc/ns#Container",
      inverseOf: "http://rdfs.org/sioc/ns#has_container",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "container of"},
      range: "http://rdfs.org/sioc/ns#Item",
      subPropertyOf: "http://purl.org/dc/terms/hasPart",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :content,
      comment: {en: "The content of the Item in plain text format."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "content"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :content_encoded,
      comment: {en: "The encoded content of the Post, contained in CDATA areas."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use content:encoded from the RSS 1.0 content module instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "content encoded"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :created_at,
      comment: {en: "When this was created, in ISO 8601 format."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:created from the Dublin Core ontology instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "created at"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :creator_of,
      comment: {en: "A resource that the UserAccount is a creator of."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_creator",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "creator of"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :delivered_at,
      comment: {en: "When this was delivered, in ISO 8601 format."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "delivered at"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :description,
      comment: {en: "The content of the Post."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use sioc:content or other methods (AtomOwl, content:encoded from RSS 1.0, etc.) instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "description"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :discussion_of,
      comment: {en: "The Item that this discussion is about."},
      inverseOf: "http://rdfs.org/sioc/ns#has_discussion",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "discussion of"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :earlier_version,
      comment: {en: "Links to a previous (older) revision of this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#later_version",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "earlier version"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#TransitiveProperty"
    property :email,
      comment: {en: "An electronic mail address of the UserAccount."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "email"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :email_sha1,
      comment: {en: "An electronic mail address of the UserAccount, encoded using SHA1."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "email sha1"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :embeds_knowledge,
      comment: {en: "This links Items to embedded statements, facts and structured content."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "embeds knowledge"},
      range: "http://www.w3.org/2004/03/trix/rdfg-1/Graph",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :feed,
      comment: {en: "A feed (e.g. RSS, Atom, etc.) pertaining to this resource (e.g. for a Forum, Site, UserAccount, etc.)."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "feed"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :first_name,
      comment: {en: "First (real) name of this User. Synonyms include given name or christian name."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use foaf:name or foaf:firstName from the FOAF vocabulary instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "first name"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :follows,
      comment: {en: "Indicates that one UserAccount follows another UserAccount (e.g. for microblog posts or other content item updates)."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "follows"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :function_of,
      comment: {en: "A UserAccount that has this Role."},
      domain: "http://rdfs.org/sioc/ns#Role",
      inverseOf: "http://rdfs.org/sioc/ns#has_function",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "function of"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :generator,
      comment: {en: "A URI for the application used to generate this Item."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "generator"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :group_of,
      "http://www.w3.org/2002/07/owl#versionInfo": "This property has been renamed. Use sioc:usergroup_of instead.",
      inverseOf: "http://rdfs.org/sioc/ns#has_group",
      label: {en: "group of"},
      type: ["http://www.w3.org/2002/07/owl#DeprecatedProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :has_administrator,
      comment: {en: "A UserAccount that is an administrator of this Site."},
      domain: "http://rdfs.org/sioc/ns#Site",
      inverseOf: "http://rdfs.org/sioc/ns#administrator_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has administrator"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_container,
      comment: {en: "The Container to which this Item belongs."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#container_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has container"},
      range: "http://rdfs.org/sioc/ns#Container",
      subPropertyOf: "http://purl.org/dc/terms/partOf",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_creator,
      comment: {en: "This is the UserAccount that made this resource."},
      inverseOf: "http://rdfs.org/sioc/ns#creator_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has creator"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_discussion,
      comment: {en: "A discussion that is related to this Item. The discussion can be anything, for example, a sioc:Forum or sioc:Thread, a sioct:WikiArticle or simply a foaf:Document."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#discussion_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has discussion"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_function,
      comment: {en: "A Role that this UserAccount has."},
      inverseOf: "http://rdfs.org/sioc/ns#function_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has function"},
      range: "http://rdfs.org/sioc/ns#Role",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_group,
      "http://www.w3.org/2002/07/owl#versionInfo": "This property has been renamed. Use sioc:has_usergroup instead.",
      inverseOf: "http://rdfs.org/sioc/ns#group_of",
      label: {en: "has group"},
      type: ["http://www.w3.org/2002/07/owl#DeprecatedProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :has_host,
      comment: {en: "The Site that hosts this Container."},
      domain: "http://rdfs.org/sioc/ns#Container",
      inverseOf: "http://rdfs.org/sioc/ns#host_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has host"},
      range: "http://rdfs.org/sioc/ns#Site",
      subPropertyOf: "http://rdfs.org/sioc/ns#has_space",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_member,
      comment: {en: "A UserAccount that is a member of this Usergroup."},
      domain: "http://rdfs.org/sioc/ns#Usergroup",
      inverseOf: "http://rdfs.org/sioc/ns#member_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has member"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_moderator,
      comment: {en: "A UserAccount that is a moderator of this Forum."},
      domain: "http://rdfs.org/sioc/ns#Forum",
      inverseOf: "http://rdfs.org/sioc/ns#moderator_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has moderator"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_modifier,
      comment: {en: "A UserAccount that modified this resource (e.g. Item, Container, Space)."},
      inverseOf: "http://rdfs.org/sioc/ns#modifier_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has modifier"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_owner,
      comment: {en: "A UserAccount that this resource is owned by."},
      inverseOf: "http://rdfs.org/sioc/ns#owner_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has owner"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_parent,
      comment: {en: "A Container or Forum that this Container or Forum is a child of."},
      domain: "http://rdfs.org/sioc/ns#Container",
      inverseOf: "http://rdfs.org/sioc/ns#parent_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has parent"},
      range: "http://rdfs.org/sioc/ns#Container",
      subPropertyOf: "http://purl.org/dc/terms/partOf",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_part,
      comment: {en: "An resource that is a part of this subject."},
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:hasPart from the Dublin Core ontology instead.",
      inverseOf: "http://rdfs.org/sioc/ns#part_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has part"},
      type: ["http://www.w3.org/2002/07/owl#DeprecatedProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :has_reply,
      comment: {en: "Points to an Item or Post that is a reply or response to this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#reply_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has reply"},
      range: "http://rdfs.org/sioc/ns#Item",
      subPropertyOf: "http://rdfs.org/sioc/ns#related_to",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_scope,
      comment: {en: "A resource that this Role applies to."},
      domain: "http://rdfs.org/sioc/ns#Role",
      inverseOf: "http://rdfs.org/sioc/ns#scope_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has scope"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_space,
      comment: {en: "A data Space which this resource is a part of."},
      inverseOf: "http://rdfs.org/sioc/ns#space_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has space"},
      range: "http://rdfs.org/sioc/ns#Space",
      subPropertyOf: "http://purl.org/dc/terms/partOf",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_subscriber,
      comment: {en: "A UserAccount that is subscribed to this Container."},
      domain: "http://rdfs.org/sioc/ns#Container",
      "http://www.w3.org/2000/01/rdf-schema#seeAlso": "http://rdfs.org/sioc/ns#feed",
      inverseOf: "http://rdfs.org/sioc/ns#subscriber_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has subscriber"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :has_usergroup,
      comment: {en: "Points to a Usergroup that has certain access to this Space."},
      domain: "http://rdfs.org/sioc/ns#Space",
      inverseOf: "http://rdfs.org/sioc/ns#usergroup_of",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "has usergroup"},
      range: "http://rdfs.org/sioc/ns#Usergroup",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :host_of,
      comment: {en: "A Container that is hosted on this Site."},
      domain: "http://rdfs.org/sioc/ns#Site",
      inverseOf: "http://rdfs.org/sioc/ns#has_host",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "host of"},
      range: "http://rdfs.org/sioc/ns#Container",
      subPropertyOf: "http://rdfs.org/sioc/ns#space_of",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :id,
      comment: {en: "An identifier of a SIOC concept instance. For example, a user ID. Must be unique for instances of each type of SIOC concept within the same site."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "id"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :ip_address,
      comment: {en: "The IP address used when creating this Item, UserAccount, etc. This can be associated with a creator. Some wiki articles list the IP addresses for the creator or modifiers when the usernames are absent."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "ip address"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :last_activity_date,
      comment: {en: "The date and time of the last activity associated with a SIOC concept instance, and expressed in ISO 8601 format. This could be due to a reply Post or Comment, a modification to an Item, etc."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "last activity date"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      subPropertyOf: "http://purl.org/dc/terms/date",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :last_item_date,
      comment: {en: "The date and time of the last Post (or Item) in a Forum (or a Container), in ISO 8601 format."},
      domain: "http://rdfs.org/sioc/ns#Container",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "last item date"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      subPropertyOf: "http://purl.org/dc/terms/date",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :last_name,
      comment: {en: "Last (real) name of this user. Synonyms include surname or family name."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use foaf:name or foaf:surname from the FOAF vocabulary instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "last name"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :last_reply_date,
      comment: {en: "The date and time of the last reply Post or Comment, which could be associated with a starter Item or Post or with a Thread, and expressed in ISO 8601 format."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "last reply date"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      subPropertyOf: "http://purl.org/dc/terms/date",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :later_version,
      comment: {en: "Links to a later (newer) revision of this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#earlier_version",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "later version"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#TransitiveProperty"
    property :latest_version,
      comment: {en: "Links to the latest revision of this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "latest version"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :likes,
      comment: {en: "Used to indicate some form of endorsement by a UserAccount or Agent of an Item, Container, Space, UserAccount, etc."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "likes"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :link,
      comment: {en: "A URI of a document which contains this SIOC object."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "link"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :links_to,
      comment: {en: "Links extracted from hyperlinks within a SIOC concept, e.g. Post or Site."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "links to"},
      subPropertyOf: "http://purl.org/dc/terms/references",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :member_of,
      comment: {en: "A Usergroup that this UserAccount is a member of."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_member",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "member of"},
      range: "http://rdfs.org/sioc/ns#Usergroup",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :mentions,
      comment: {en: "Refers to a UserAccount that a particular Item mentions."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "mentions"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :moderator_of,
      comment: {en: "A Forum that a UserAccount is a moderator of."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_moderator",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "moderator of"},
      range: "http://rdfs.org/sioc/ns#Forum",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :modified_at,
      comment: {en: "When this was modified, in ISO 8601 format."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:modified from the Dublin Core ontology instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "modified at"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :modifier_of,
      comment: {en: "A resource that this UserAccount has modified."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_modifier",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "modifier of"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :name,
      comment: {en: "The name of a SIOC concept instance, e.g. a username for a UserAccount, group name for a Usergroup, etc."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "name"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :next_by_date,
      comment: {en: "Next Item or Post in a given Container sorted by date."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#previous_by_date",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "next by date"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :next_version,
      comment: {en: "Links to the next revision of this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#previous_version",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "next version"},
      range: "http://rdfs.org/sioc/ns#Item",
      subPropertyOf: "http://rdfs.org/sioc/ns#later_version",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :note,
      comment: {en: "A note associated with this resource, for example, if it has been edited by a UserAccount."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "note"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :num_authors,
      comment: {en: "The number of unique authors (UserAccounts and unregistered posters) who have contributed to this Item, Thread, Post, etc."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "num authors"},
      range: "http://www.w3.org/2001/XMLSchema#nonNegativeInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :num_items,
      comment: {en: "The number of Posts (or Items) in a Forum (or a Container)."},
      domain: "http://rdfs.org/sioc/ns#Container",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "num items"},
      range: "http://www.w3.org/2001/XMLSchema#nonNegativeInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :num_replies,
      comment: {en: "The number of replies that this Item, Thread, Post, etc. has. Useful for when the reply structure is absent."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "num replies"},
      range: "http://www.w3.org/2001/XMLSchema#nonNegativeInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :num_threads,
      comment: {en: "The number of Threads (AKA discussion topics) in a Forum."},
      domain: "http://rdfs.org/sioc/ns#Forum",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "num threads"},
      range: "http://www.w3.org/2001/XMLSchema#nonNegativeInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :num_views,
      comment: {en: "The number of times this Item, Thread, UserAccount profile, etc. has been viewed."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "num views"},
      range: "http://www.w3.org/2001/XMLSchema#nonNegativeInteger",
      type: "http://www.w3.org/2002/07/owl#DatatypeProperty"
    property :owner_of,
      comment: {en: "A resource owned by a particular UserAccount, for example, a weblog or image gallery."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      inverseOf: "http://rdfs.org/sioc/ns#has_owner",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "owner of"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :parent_of,
      comment: {en: "A child Container or Forum that this Container or Forum is a parent of."},
      domain: "http://rdfs.org/sioc/ns#Container",
      inverseOf: "http://rdfs.org/sioc/ns#has_parent",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "parent of"},
      range: "http://rdfs.org/sioc/ns#Container",
      subPropertyOf: "http://purl.org/dc/terms/hasPart",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :part_of,
      comment: {en: "A resource that the subject is a part of."},
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:isPartOf from the Dublin Core ontology instead.",
      inverseOf: "http://rdfs.org/sioc/ns#has_part",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "part of"},
      type: ["http://www.w3.org/2002/07/owl#DeprecatedProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :previous_by_date,
      comment: {en: "Previous Item or Post in a given Container sorted by date."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#next_by_date",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "previous by date"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :previous_version,
      comment: {en: "Links to the previous revision of this Item or Post."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#next_version",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "previous version"},
      range: "http://rdfs.org/sioc/ns#Item",
      subPropertyOf: "http://rdfs.org/sioc/ns#earlier_version",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :read_at,
      comment: {en: "When this was read, in ISO 8601 format."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "read at"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :reference,
      comment: {en: "Links either created explicitly or extracted implicitly on the HTML level from the Post."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "Renamed to sioc:links_to.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "reference"},
      type: ["http://www.w3.org/2002/07/owl#DeprecatedProperty", "http://www.w3.org/2002/07/owl#ObjectProperty"]
    property :related_to,
      comment: {en: "Related resources for this resource, e.g. for Posts, perhaps determined implicitly from topics or references."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "related to"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :reply_of,
      comment: {en: "Links to an Item or Post which this Item or Post is a reply to."},
      domain: "http://rdfs.org/sioc/ns#Item",
      inverseOf: "http://rdfs.org/sioc/ns#has_reply",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "reply of"},
      range: "http://rdfs.org/sioc/ns#Item",
      subPropertyOf: "http://rdfs.org/sioc/ns#related_to",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :respond_to,
      comment: {en: "For the reply-to address set in email messages, IMs, etc. The property name was chosen to avoid confusion with has_reply/reply_of (the reply graph)."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "respond to"},
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :scope_of,
      comment: {en: "A Role that has a scope of this resource."},
      inverseOf: "http://rdfs.org/sioc/ns#has_scope",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "scope of"},
      range: "http://rdfs.org/sioc/ns#Role",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :shared_by,
      comment: {en: "For shared Items where there is a certain creator_of and an intermediary who shares or forwards it (e.g. as a sibling Item)."},
      domain: "http://rdfs.org/sioc/ns#Item",
      "http://www.w3.org/2000/01/rdf-schema#seeAlso": "http://rdfs.org/sioc/ns#sibling",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "shared by"},
      range: "http://rdfs.org/sioc/ns#UserAccount",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :sibling,
      comment: {en: "An Item may have a sibling or a twin that exists in a different Container, but the siblings may differ in some small way (for example, language, category, etc.). The sibling of this Item should be self-describing (that is, it should contain all available information)."},
      domain: "http://rdfs.org/sioc/ns#Item",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "sibling"},
      range: "http://rdfs.org/sioc/ns#Item",
      type: "http://www.w3.org/2002/07/owl#SymmetricProperty"
    property :space_of,
      comment: {en: "A resource which belongs to this data Space."},
      domain: "http://rdfs.org/sioc/ns#Space",
      inverseOf: "http://rdfs.org/sioc/ns#has_space",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "space of"},
      subPropertyOf: "http://purl.org/dc/terms/hasPart",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :subject,
      comment: {en: "Keyword(s) describing subject of the Post."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:subject from the Dublin Core ontology for text keywords and sioc:topic if the subject can be represented by a URI instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "subject"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :subscriber_of,
      comment: {en: "A Container that a UserAccount is subscribed to."},
      domain: "http://rdfs.org/sioc/ns#UserAccount",
      "http://www.w3.org/2000/01/rdf-schema#seeAlso": "http://rdfs.org/sioc/ns#feed",
      inverseOf: "http://rdfs.org/sioc/ns#has_subscriber",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "subscriber of"},
      range: "http://rdfs.org/sioc/ns#Container",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :title,
      comment: {en: "This is the title (subject line) of the Post. Note that for a Post within a threaded discussion that has no parents, it would detail the topic thread."},
      domain: "http://rdfs.org/sioc/ns#Post",
      "http://www.w3.org/2002/07/owl#versionInfo": "This property is deprecated. Use dcterms:title from the Dublin Core ontology instead.",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "title"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: ["http://www.w3.org/2002/07/owl#DatatypeProperty", "http://www.w3.org/2002/07/owl#DeprecatedProperty"]
    property :topic,
      comment: {en: "A topic of interest, linking to the appropriate URI, e.g. in the Open Directory Project or of a SKOS category."},
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "topic"},
      subPropertyOf: "http://purl.org/dc/terms/subject",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
    property :usergroup_of,
      comment: {en: "A Space that the Usergroup has access to."},
      domain: "http://rdfs.org/sioc/ns#Usergroup",
      inverseOf: "http://rdfs.org/sioc/ns#has_usergroup",
      isDefinedBy: "http://rdfs.org/sioc/ns#",
      label: {en: "usergroup of"},
      range: "http://rdfs.org/sioc/ns#Space",
      type: "http://www.w3.org/2002/07/owl#ObjectProperty"
  end
end
