# -*- encoding: utf-8 -*-
# frozen_string_literal: true
# This file generated automatically using rdf vocabulary format from http://www.cidoc-crm.org/cidoc-crm/
require 'rdf'
module RDF::Vocab
  # Vocabulary for <http://www.cidoc-crm.org/cidoc-crm/>
  # @!visibility private
  CRM = Class.new(RDF::StrictVocabulary("http://www.cidoc-crm.org/cidoc-crm/")) do

    # Class definitions
    term :E10_Transfer_of_Custody,
      comment: {en: "This class comprises transfers of physical custody of objects between instances of E39 Actor. \nThe recording of the donor and/or recipient is optional. It is possible that in an instance of E10 Transfer of Custody there is either no donor or no recipient. Depending on the circumstances it may describe:\n1.\tthe beginning of custody \n2.\tthe end of custody \n3.\tthe transfer of custody \n4.\tthe receipt of custody from an unknown source\n5.\tthe declared loss of an object\nThe distinction between the legal responsibility for custody and the actual physical possession of the object should be expressed using the property P2 has type (is type of). A specific case of transfer of custody is theft.\nThe interpretation of the museum notion of \"accession\" differs between institutions. The CRM therefore models legal ownership and physical custody separately. Institutions will then model their specific notions of accession and deaccession as combinations of these.\n"},
      label: {en: "Transfer of Custody", cn: "保管作业转移", de: "Übertragung des Gewahrsams", el: "Μεταβίβαση  Κατοχής", fr: "Changement de détenteur", pt: "Transferência de Custódia", ru: "Передача Опеки"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E11_Modification,
      comment: {en: "This class comprises all instances of E7 Activity that create, alter or change E24 Physical Man-Made Thing. \nThis class includes the production of an item from raw materials, and other so far undocumented objects, and the preventive treatment or restoration of an object for conservation. \nSince the distinction between modification and production is not always clear, modification is regarded as the more generally applicable concept. This implies that some items may be consumed or destroyed in a Modification, and that others may be produced as a result of it. An event should also be documented using E81 Transformation if it results in the destruction of one or more objects and the simultaneous production of others using parts or material from the originals. In this case, the new items have separate identities. \nIf the instance of the E29 Design or Procedure utilized for the modification prescribes the use of specific materials, they should be documented using property P68 foresees use of (use foreseen by): E57 Material of E29 Design or Procedure, rather than via P126 employed (was employed in): E57 Material.\n"},
      label: {en: "Modification", cn: "修改", de: "Bearbeitung", el: "Τροποποίηση", fr: "Modification", pt: "Modificação", ru: "Событие Изменения"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E12_Production,
      comment: {en: "This class comprises activities that are designed to, and succeed in, creating one or more new items. \nIt specializes the notion of modification into production. The decision as to whether or not an object is regarded as new is context sensitive. Normally, items are considered “new” if there is no obvious overall similarity between them and the consumed items and material used in their production. In other cases, an item is considered “new” because it becomes relevant to documentation by a modification. For example, the scribbling of a name on a potsherd may make it a voting token. The original potsherd may not be worth documenting, in contrast to the inscribed one. \nThis entity can be collective: the printing of a thousand books, for example, would normally be considered a single event. \nAn event should also be documented using E81 Transformation if it results in the destruction of one or more objects and the simultaneous production of others using parts or material from the originals. In this case, the new items have separate identities and matter is preserved, but identity is not.\n"},
      label: {en: "Production", cn: "生产", de: "Herstellung", el: "Παραγωγή", fr: "Production", pt: "Produção", ru: "Событие Производства"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E11_Modification", "http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E13_Attribute_Assignment,
      comment: {en: "This class comprises the actions of making assertions about properties of an object or any relation between two items or concepts. \nThis class allows the documentation of how the respective assignment came about, and whose opinion it was. All the attributes or properties assigned in such an action can also be seen as directly attached to the respective item or concept, possibly as a collection of contradictory values. All cases of properties in this model that are also described indirectly through an action are characterised as \"short cuts\" of this action. This redundant modelling of two alternative views is preferred because many implementations may have good reasons to model either the action or the short cut, and the relation between both alternatives can be captured by simple rules. \nIn particular, the class describes the actions of people making propositions and statements during certain museum procedures, e.g. the person and date when a condition statement was made, an identifier was assigned, the museum object was measured, etc. Which kinds of such assignments and statements need to be documented explicitly in structures of a schema rather than free text, depends on if this information should be accessible by structured queries. \n"},
      label: {en: "Attribute Assignment", cn: "屬性指定", de: "Merkmalszuweisung", el: "Απόδοση Ιδιοτήτων", fr: "Affectation d'attribut", pt: "Atribuição de Característica", ru: "Присвоение Атрибута"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E14_Condition_Assessment,
      comment: {en: "This class describes the act of assessing the state of preservation of an object during a particular period. \nThe condition assessment may be carried out by inspection, measurement or through historical research. This class is used to document circumstances of the respective assessment that may be relevant to interpret its quality at a later stage, or to continue research on related documents. \n"},
      label: {en: "Condition Assessment", cn: "状态评估", de: "Zustandsfeststellung", el: "Εκτίμηση Κατάστασης", fr: "Expertise de l'état matériel", pt: "Avaliação do Estado Material", ru: "Оценка Состояния"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E15_Identifier_Assignment,
      comment: {en: "This class comprises activities that result in the allocation of an identifier to an instance of E1 CRM Entity. An E15 Identifier Assignment may include the creation of the identifier from multiple constituents, which themselves may be instances of E41 Appellation. The syntax and kinds of constituents to be used may be declared in a rule constituting an instance of E29 Design or Procedure.\nExamples of such identifiers include Find Numbers, Inventory Numbers, uniform titles in the sense of librarianship and Digital Object Identifiers (DOI). Documenting the act of identifier assignment and deassignment is especially useful when objects change custody or the identification system of an organization is changed. In order to keep track of the identity of things in such cases, it is important to document by whom, when and for what purpose an identifier is assigned to an item.\nThe fact that an identifier is a preferred one for an organisation can be expressed by using the property E1 CRM Entity. P48 has preferred identifier (is preferred identifier of): E42 Identifier. It can better be expressed in a context independent form by assigning a suitable E55 Type, such as “preferred identifier assignment”, to the respective instance of E15 Identifier Assignment via the P2 has type property.\n"},
      label: {en: "Identifier Assignment", cn: "标识符指定", de: "Kennzeichenzuweisung", el: "Απόδοση Αναγνωριστικού", fr: "Attribution d’identificateur", pt: "Atribuição de Identificador", ru: "Назначение Идентификатора"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E16_Measurement,
      comment: {en: "This class comprises actions measuring physical properties and other values that can be determined by a systematic procedure. \nExamples include measuring the monetary value of a collection of coins or the running time of a specific video cassette. \nThe E16 Measurement may use simple counting or tools, such as yardsticks or radiation detection devices. The interest is in the method and care applied, so that the reliability of the result may be judged at a later stage, or research continued on the associated documents. The date of the event is important for dimensions, which may change value over time, such as the length of an object subject to shrinkage. Details of methods and devices are best handled as free text, whereas basic techniques such as \"carbon 14 dating\" should be encoded using P2 has type (is type of:) E55 Type.\n"},
      label: {en: "Measurement", cn: "测量", de: "Messung", el: "Μέτρηση", fr: "Mesurage", pt: "Medição", ru: "Событие Измерения"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E17_Type_Assignment,
      comment: {en: "This class comprises the actions of classifying items of whatever kind. Such items include objects, specimens, people, actions and concepts. \nThis class allows for the documentation of the context of classification acts in cases where the value of the classification depends on the personal opinion of the classifier, and the date that the classification was made. This class also encompasses the notion of \"determination,\" i.e. the systematic and molecular identification of a specimen in biology. \n"},
      label: {en: "Type Assignment", cn: "类型指定", de: "Typuszuweisung", el: "Απόδοση Τύπου", fr: "Attribution de type", pt: "Atribuição de Tipo", ru: "Присвоение Типа"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E18_Physical_Thing,
      comment: {en: "This class comprises all persistent physical items with a relatively stable form, man-made or natural. \nDepending on the existence of natural boundaries of such things, the CRM distinguishes the instances of E19 Physical Object from instances of E26 Physical Feature, such as holes, rivers, pieces of land etc. Most instances of E19 Physical Object can be moved (if not too heavy), whereas features are integral to the surrounding matter. \nThe CRM is generally not concerned with amounts of matter in fluid or gaseous states. \n"},
      label: {en: "Physical Thing", cn: "实体物", de: "Materielles", el: "Υλικό Πράγμα", fr: "Chose matérielle", pt: "Coisa Material", ru: "Физическая Вещь"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E19_Physical_Object,
      comment: {en: "This class comprises items of a material nature that are units for documentation and have physical boundaries that separate them completely in an objective way from other objects. \nThe class also includes all aggregates of objects made for functional purposes of whatever kind, independent of physical coherence, such as a set of chessmen. Typically, instances of E19 Physical Object can be moved (if not too heavy).\nIn some contexts, such objects, except for aggregates, are also called “bona fide objects” (Smith & Varzi, 2000, pp.401-420), i.e. naturally defined objects. \nThe decision as to what is documented as a complete item, rather than by its parts or components, may be a purely administrative decision or may be a result of the order in which the item was acquired.\n"},
      label: {en: "Physical Object", cn: "实体物件", de: "Materieller Gegenstand", el: "Υλικό Αντικείμενο", fr: "Objet matériel", pt: "Objeto Material", ru: "Физический Объект"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E1_CRM_Entity,
      comment: {en: "This class comprises all things in the universe of discourse of the CIDOC Conceptual Reference Model. \nIt is an abstract concept providing for three general properties:\n1.\tIdentification by name or appellation, and in particular by a preferred identifier\n2.\tClassification by type, allowing further refinement of the specific subclass an instance belongs to \n3.\tAttachment of free text for the expression of anything not captured by formal properties\nWith the exception of E59 Primitive Value, all other classes within the CRM are directly or indirectly specialisations of E1 CRM Entity. \n"},
      label: {en: "CRM Entity", cn: "CRM实体", de: "CRM Entität", el: "Οντότητα CIDOC CRM", fr: "Entité CRM", pt: "Entidade CRM", ru: "CRM Сущность"},
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E20_Biological_Object,
      comment: {en: "This class comprises individual items of a material nature, which live, have lived or are natural products of or from living organisms. \nArtificial objects that incorporate biological elements, such as Victorian butterfly frames, can be documented as both instances of E20 Biological Object and E22 Man-Made Object. \n"},
      label: {en: "Biological Object", cn: "生物体", de: "Biologischer Gegenstand", el: "Βιολογικό Ακτικείμενο", fr: "Objet biologique", pt: "Objeto Biológico", ru: "Биологический Объект"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E21_Person,
      comment: {en: "This class comprises real persons who live or are assumed to have lived. \nLegendary figures that may have existed, such as Ulysses and King Arthur, fall into this class if the documentation refers to them as historical figures. In cases where doubt exists as to whether several persons are in fact identical, multiple instances can be created and linked to indicate their relationship. The CRM does not propose a specific form to support reasoning about possible identity.\n"},
      label: {en: "Person", cn: "人物", de: "Person", el: "Πρόσωπο", fr: "Personne", pt: "Pessoa", ru: "Личность"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E20_Biological_Object", "http://www.cidoc-crm.org/cidoc-crm/E39_Actor"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E22_Man-Made_Object",
      comment: {en: "This class comprises physical objects purposely created by human activity.\nNo assumptions are made as to the extent of modification required to justify regarding an object as man-made. For example, an inscribed piece of rock or a preserved butterfly are both regarded as instances of E22 Man-Made Object.\n"},
      label: {en: "Man-Made Object", cn: "人造物件", de: "Künstlicher Gegenstand", el: "Ανθρωπογενές Αντικείμενο", fr: "Objet fabriqué", pt: "Objeto Fabricado", ru: "Рукотворный Объект"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object", "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E24_Physical_Man-Made_Thing",
      comment: {en: "This class comprises all persistent physical items that are purposely created by human activity.\nThis class comprises man-made objects, such as a swords, and man-made features, such as rock art. No assumptions are made as to the extent of modification required to justify regarding an object as man-made. For example, a “cup and ring” carving on bedrock is regarded as instance of E24 Physical Man-Made Thing. \n"},
      label: {en: "Physical Man-Made Thing", cn: "人造实体物", de: "Hergestelltes", el: "Ανθρωπογενές Υλικό Πράγμα", fr: "Chose matérielle fabriquée", pt: "Coisa Material Fabricada", ru: "Физическая Рукотворная Вещь"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing", "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E25_Man-Made_Feature",
      comment: {en: "This class comprises physical features that are purposely created by human activity, such as scratches, artificial caves, artificial water channels, etc. \nNo assumptions are made as to the extent of modification required to justify regarding a feature as man-made. For example, rock art or even “cup and ring” carvings on bedrock a regarded as types of E25 Man-Made Feature.\n"},
      label: {en: "Man-Made Feature", cn: "人造外貌表征", de: "Hergestelltes Merkmal", el: "Ανθρωπογενές Μόρφωμα", fr: "Caractéristique fabriquée", pt: "Característica Fabricada", ru: "Искусственный Признак"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing", "http://www.cidoc-crm.org/cidoc-crm/E26_Physical_Feature"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E26_Physical_Feature,
      comment: {en: "This class comprises identifiable features that are physically attached in an integral way to particular physical objects. \nInstances of E26 Physical Feature share many of the attributes of instances of E19 Physical Object. They may have a one-, two- or three-dimensional geometric extent, but there are no natural borders that separate them completely in an objective way from the carrier objects. For example, a doorway is a feature but the door itself, being attached by hinges, is not. \nInstances of E26 Physical Feature can be features in a narrower sense, such as scratches, holes, reliefs, surface colours, reflection zones in an opal crystal or a density change in a piece of wood. In the wider sense, they are portions of particular objects with partially imaginary borders, such as the core of the Earth, an area of property on the surface of the Earth, a landscape or the head of a contiguous marble statue. They can be measured and dated, and it is sometimes possible to state who or what is or was responsible for them. They cannot be separated from the carrier object, but a segment of the carrier object may be identified (or sometimes removed) carrying the complete feature. \nThis definition coincides with the definition of \"fiat objects\" (Smith & Varzi, 2000, pp.401-420), with the exception of aggregates of “bona fide objects”. \n"},
      label: {en: "Physical Feature", cn: "实体外貌表征", de: "Materielles Merkmal", el: "Υλικό Μόρφωμα", fr: "Caractéristique matérielle", pt: "Característica Material", ru: "Физический Признак"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E27_Site,
      comment: {en: "This class comprises pieces of land or sea floor. \nIn contrast to the purely geometric notion of E53 Place, this class describes constellations of matter on the surface of the Earth or other celestial body, which can be represented by photographs, paintings and maps.\n Instances of E27 Site are composed of relatively immobile material items and features in a particular configuration at a particular location"},
      label: {en: "Site", cn: "场地", de: "Gelände", el: "Φυσικός Χώρος", fr: "Site", pt: "Lugar", ru: "Участок"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E26_Physical_Feature",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E28_Conceptual_Object,
      comment: {en: "This class comprises non-material products of our minds and other human produced data that \t\thave become objects of a discourse about their identity, circumstances of creation or historical \t\timplication. The production of such information may have been supported by the use of    \t\ttechnical devices such as cameras or computers.\nCharacteristically, instances of this class are created, invented or thought by someone, and then may be documented or communicated between persons. Instances of E28 Conceptual Object have the ability to exist on more than one particular carrier at the same time, such as paper, electronic signals, marks, audio media, paintings, photos, human memories, etc.\nThey cannot be destroyed. They exist as long as they can be found on at least one carrier or in at least one human memory. Their existence ends when the last carrier and the last memory are lost. \n"},
      label: {en: "Conceptual Object", cn: "概念物件", de: "Begrifflicher Gegenstand", el: "Νοητικό Αντικείμενο", fr: "Objet conceptuel", pt: "Objeto Conceitual", ru: "Концептуальный Объект"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E29_Design_or_Procedure,
      comment: {en: "This class comprises documented plans for the execution of actions in order to achieve a result of a specific quality, form or contents. In particular it comprises plans for deliberate human activities that may result in the modification or production of instances of E24 Physical Thing. \nInstances of E29 Design or Procedure can be structured in parts and sequences or depend on others. This is modelled using P69 has association with (is associated with). \nDesigns or procedures can be seen as one of the following:\n1.\tA schema for the activities it describes\n2.\tA schema of the products that result from their application. \n3.\tAn independent intellectual product that may have never been applied, such as Leonardo da Vinci’s famous plans for flying machines.\nBecause designs or procedures may never be applied or only partially executed, the CRM models a loose relationship between the plan and the respective product.\n"},
      label: {en: "Design or Procedure", cn: "设计或程序", de: "Entwurf oder Verfahren", el: "Σχέδιο", fr: "Conception ou procédure", pt: "Projeto ou Procedimento", ru: "Проект или Процедура"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E2_Temporal_Entity,
      comment: {en: "This class comprises all phenomena, such as the instances of E4 Periods, E5 Events and states, which happen over a limited extent in time. \n\tIn some contexts, these are also called perdurants. This class is disjoint from E77 Persistent Item. This is an abstract class and has no direct instances. E2 Temporal Entity is specialized into E4 Period, which applies to a particular geographic area (defined with a greater or lesser degree of precision), and E3 Condition State, which applies to instances of E18 Physical Thing.\n"},
      label: {en: "Temporal Entity", cn: "时间实体", de: "Geschehendes", el: "Έγχρονη  Οντότητα", fr: "Entité temporelle", pt: "Entidade Temporal", ru: "Временная Сущность"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E30_Right,
      comment: {en: "This class comprises legal privileges concerning material and immaterial things or their derivatives. \nThese include reproduction and property rights"},
      label: {en: "Right", cn: "权限", de: "Recht", el: "Δικαίωμα", fr: "Droit", pt: "Direitos", ru: "Право"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E31_Document,
      comment: {en: "This class comprises identifiable immaterial items that make propositions about reality.\nThese propositions may be expressed in text, graphics, images, audiograms, videograms or by other similar means. Documentation databases are regarded as a special case of E31 Document. This class should not be confused with the term “document” in Information Technology, which is compatible with E73 Information Object.\n"},
      label: {en: "Document", cn: "文献", de: "Dokument", el: "Τεκμήριο", fr: "Document", pt: "Documento", ru: "Документ"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E32_Authority_Document,
      comment: {en: "This class comprises encyclopaedia, thesauri, authority lists and other documents that define terminology or conceptual systems for consistent use.\n"},
      label: {en: "Authority Document", cn: "权威文献", de: "Referenzdokument", el: "Πηγή Καθιερωμένων Όρων", fr: "Document de référence", pt: "Documento de Referência", ru: "Официальный Документ"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E31_Document",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E33_Linguistic_Object,
      comment: {en: "This class comprises identifiable expressions in natural language or languages. \nInstances of E33 Linguistic Object can be expressed in many ways: e.g. as written texts, recorded speech or sign language. However, the CRM treats instances of E33 Linguistic Object independently from the medium or method by which they are expressed. Expressions in formal languages, such as computer code or mathematical formulae, are not treated as instances of E33 Linguistic Object by the CRM. These should be modelled as instances of E73 Information Object.\nThe text of an instance of E33 Linguistic Object can be documented in a note by P3 has note: E62 String\n"},
      label: {en: "Linguistic Object", cn: "语言物件", de: "Sprachlicher Gegenstand", el: "Γλωσσικό Αντικείμενο", fr: "Objet linguistique", pt: "Objeto Lingüístico", ru: "Линвистический Объект"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E34_Inscription,
      comment: {en: "This class comprises recognisable, short texts attached to instances of E24 Physical Man-Made Thing. \nThe transcription of the text can be documented in a note by P3 has note: E62 String. The alphabet used can be documented by P2 has type: E55 Type. This class does not intend to describe the idiosyncratic characteristics of an individual physical embodiment of an inscription, but the underlying prototype. The physical embodiment is modelled in the CRM as E24 Physical Man-Made Thing.\nThe relationship of a physical copy of a book to the text it contains is modelled using E84 Information Carrier. P128 carries (is carried by): E33 Linguistic Object. \n"},
      label: {en: "Inscription", cn: "题字", de: "Inschrift", el: "Επιγραφή", fr: "Inscription", pt: "Inscrição", ru: "Надпись"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object", "http://www.cidoc-crm.org/cidoc-crm/E37_Mark"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E35_Title,
      comment: {en: "This class comprises the names assigned to works, such as texts, artworks or pieces of music. \nTitles are proper noun phrases or verbal phrases, and should not be confused with generic object names such as “chair”, “painting” or “book” (the latter are common nouns that stand for instances of E55 Type). Titles may be assigned by the creator of the work itself, or by a social group. \nThis class also comprises the translations of titles that are used as surrogates for the original titles in different social contexts.\n"},
      label: {en: "Title", cn: "题目", de: "Titel", el: " Τίτλος", fr: "Titre", pt: "Título", ru: "Заголовок"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object", "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E36_Visual_Item,
      comment: {en: "This class comprises the intellectual or conceptual aspects of recognisable marks and images.\nThis class does not intend to describe the idiosyncratic characteristics of an individual physical embodiment of a visual item, but the underlying prototype. For example, a mark such as the ICOM logo is generally considered to be the same logo when used on any number of publications. The size, orientation and colour may change, but the logo remains uniquely identifiable. The same is true of images that are reproduced many times. This means that visual items are independent of their physical support. \nThe class E36 Visual Item provides a means of identifying and linking together instances of E24 Physical Man-Made Thing that carry the same visual symbols, marks or images etc. The property P62 depicts (is depicted by) between E24 Physical Man-Made Thing and depicted subjects (E1 CRM Entity) can be regarded as a short-cut of the more fully developed path from E24 Physical Man-Made Thing through P65 shows visual item (is shown by), E36 Visual Item, P138 represents (has representation) to E1CRM Entity, which in addition captures the optical features of the depiction.  \n"},
      label: {en: "Visual Item", cn: "视觉项目", de: "Bildliches", el: "Οπτικό Στοιχείο", fr: "Item visuel", pt: "Item Visual", ru: "Визуальный Предмет"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E37_Mark,
      comment: {en: "This class comprises symbols, signs, signatures or short texts applied to instances of E24 Physical Man-Made Thing by arbitrary techniques in order to indicate the creator, owner, dedications, purpose, etc. \nThis class specifically excludes features that have no semantic significance, such as scratches or tool marks. These should be documented as instances of E25 Man-Made Feature. \n"},
      label: {en: "Mark", cn: "标志", de: "Marke", el: "Σήμανση", fr: "Marque", pt: "Marca", ru: "Пометка"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E38_Image,
      comment: {en: "This class comprises distributions of form, tone and colour that may be found on surfaces such as photos, paintings, prints and sculptures or directly on electronic media. \nThe degree to which variations in the distribution of form and colour affect the identity of an instance of E38 Image depends on a given purpose. The original painting of the Mona Lisa in the Louvre may be said to bear the same instance of E38 Image as reproductions in the form of transparencies, postcards, posters or T-shirts, even though they may differ in size and carrier and may vary in tone and colour. The images in a “spot the difference” competition are not the same with respect to their context, however similar they may at first appear.\n"},
      label: {en: "Image", cn: "图像", de: "Bild", el: "Εικόνα", fr: "Image", pt: "Imagem", ru: "Изображение"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E39_Actor,
      comment: {en: "This class comprises people, either individually or in groups, who have the potential to perform intentional actions of kinds for which someone may be held responsible.\nThe CRM does not attempt to model the inadvertent actions of such actors. Individual people should be documented as instances of E21 Person, whereas groups should be documented as instances of either E74 Group or its subclass E40 Legal Body.\n"},
      label: {en: "Actor", cn: "角色", de: "Akteur", el: "Δράστης", fr: "Agent", pt: "Agente", ru: "Агент"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E3_Condition_State,
      comment: {en: "This class comprises the states of objects characterised by a certain condition over a time-span. \nAn instance of this class describes the prevailing physical condition of any material object or feature during a specific E52 Time Span. In general, the time-span for which a certain condition can be asserted may be shorter than the real time-span, for which this condition held.\n The nature of that condition can be described using P2 has type. For example, the E3 Condition State “condition of the SS Great Britain between 22 September 1846 and 27 August 1847” can be characterized as E55 Type “wrecked”. \n"},
      label: {en: "Condition State", cn: "状态", de: "Zustandsphase", el: "Κατάσταση", fr: "État matériel", pt: "Estado Material", ru: "Состояние"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E40_Legal_Body,
      comment: {en: "This class comprises institutions or groups of people that have obtained a legal recognition as a group and can act collectively as agents.  \nThis means that they can perform actions, own property, create or destroy things and can be held collectively responsible for their actions like individual people. The term 'personne morale' is often used for this in French. \n"},
      label: {en: "Legal Body", cn: "法律组织", de: "Juristische Person", el: "Νομικό Πρόσωπο", fr: "Collectivité", pt: "Pessoa Jurídica", ru: "Юридическое Лицо"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E41_Appellation,
      comment: {en: "This class comprises signs, either meaningful or not, or arrangements of signs following a specific syntax, that are used or can be used to refer to and identify a specific instance of some class or category within a certain context.\nInstances of E41 Appellation do not identify things by their meaning, even if they happen to have one, but instead by convention, tradition, or agreement. Instances of E41 Appellation are cultural constructs; as such, they have a context, a history, and a use in time and space by some group of users. A given instance of E41 Appellation can have alternative forms, i.e., other instances of E41 Appellation that are always regarded as equivalent independent from the thing it denotes. \nSpecific subclasses of E41 Appellation should be used when instances of E41 Appellation of a characteristic form are used for particular objects. Instances of E49 Time Appellation, for example, which take the form of instances of E50 Date, can be easily recognised.\nE41 Appellation should not be confused with the act of naming something. Cf. E15 Identifier Assignment\n"},
      label: {en: "Appellation", cn: "称号", de: "Benennung", el: "Ονομασία", fr: "Appellation", pt: "Designação", ru: "Обозначение"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E42_Identifier,
      comment: {en: "This class comprises strings or codes assigned to instances of E1 CRM Entity in order to identify them uniquely and permanently within the context of one or more organisations. Such codes are often known as inventory numbers, registration codes, etc. and are typically composed of alphanumeric sequences. The class E42 Identifier is not normally used for machine-generated identifiers used for automated processing unless these are also used by human agents."},
      label: {en: "Identifier", cn: "标识符", de: "Kennung", el: "Κωδικός Αναγνώρισης", fr: "Identificateur d'objet", pt: "Identificador de Objeto", ru: "Идентификатор Объекта"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E44_Place_Appellation,
      comment: {en: "This class comprises any sort of identifier characteristically used to refer to an E53 Place. \nInstances of E44 Place Appellation may vary in their degree of precision and their meaning may vary over time - the same instance of E44 Place Appellation may be used to refer to several places, either because of cultural shifts, or because objects used as reference points have moved around. Instances of E44 Place Appellation can be extremely varied in form: postal addresses, instances of E47 Spatial Coordinate, and parts of buildings can all be considered as instances of E44 Place Appellation.\n"},
      label: {en: "Place Appellation", cn: "地点称号", de: "Ortsbenennung", el: "Ονομασία Τόπου", fr: "Appellation de lieu", pt: "Designação de Local", ru: "Обозначение Места"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E45_Address,
      comment: {en: "This class comprises identifiers expressed in coding systems for places, such as postal addresses used for mailing.\nAn E45 Address can be considered both as the name of an E53 Place and as an E51 Contact Point for an E39 Actor. This dual aspect is reflected in the multiple inheritance. However, some forms of mailing addresses, such as a postal box, are only instances of E51 Contact Point, since they do not identify any particular Place. These should not be documented as instances of E45 Address.\n"},
      label: {en: "Address", cn: "地址", de: "Adresse", el: "Διεύθυνση", fr: "Adresse", pt: "Endereço", ru: "Адрес"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation", "http://www.cidoc-crm.org/cidoc-crm/E51_Contact_Point"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E46_Section_Definition,
      comment: {en: "This class comprises areas of objects referred to in terms specific to the general geometry or structure of its kind. \nThe 'prow' of the boat, the 'frame' of the picture, the 'front' of the building are all instances of E46 Section Definition. The class highlights the fact that parts of objects can be treated as locations. This holds in particular for features without natural boundaries, such as the “head” of a marble statue made out of one block (cf. E53 Place). In answer to the question 'where is the signature?' one might reply 'on the lower left corner'. (Section Definition is closely related to the term “segment” in Gerstl, P.& Pribbenow, S, 1996 “ A conceptual theory of part – whole relations and its applications”, Data & Knowledge \tEngineering 20 305-322, North Holland- Elsevier ).\n"},
      label: {en: "Section Definition", cn: "区域定义", de: "Abschnittsdefinition", el: "Ονομασία Τμήματος", fr: "Désignation de section", pt: "Designação de Seção", ru: "Определение Района"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E47_Spatial_Coordinates,
      comment: {en: "This class comprises the textual or numeric information required to locate specific instances of E53 Place within schemes of spatial identification. \n\nCoordinates are a specific form of E44 Place Appellation, that is, a means of referring to a particular E53 Place. Coordinates are not restricted to longitude, latitude and altitude. Any regular system of reference that maps onto an E19 Physical Object can be used to generate coordinates.\n"},
      label: {en: "Spatial Coordinates", cn: "空间坐标", de: "Raumkoordinaten", el: "Χωρικές Συντεταγμένες", fr: "Coordonnées spatiales", pt: "Coordenadas Espaciais", ru: "Пространственные Координаты"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E48_Place_Name,
      comment: {en: "This class comprises particular and common forms of E44 Place Appellation. \nPlace Names may change their application over time: the name of an E53 Place may change, and a name may be reused for a different E53 Place. Instances of E48 Place Name are typically subject to place name gazetteers."},
      label: {en: "Place Name", cn: "地名", de: "Orts- oder Flurname", el: "Τοπωνύμιο", fr: "Toponyme", pt: "Nome de Local", ru: "Название Места"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E49_Time_Appellation,
      comment: {en: "This class comprises all forms of names or codes, such as historical periods, and dates, which are characteristically used to refer to a specific E52 Time-Span. \nThe instances of E49 Time Appellation may vary in their degree of precision, and they may be relative to other time frames, “Before Christ” for example. Instances of E52 Time-Span are often defined by reference to a cultural period or an event e.g. ‘the duration of the Ming Dynasty’."},
      label: {en: "Time Appellation", cn: "时间称号", de: "Zeitbenennung", el: "Ονομασία Χρόνου", fr: "Appellation temporelle", pt: "Designação de Tempo", ru: "Обозначение Времени"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E4_Period,
      comment: {en: "This class comprises sets of coherent phenomena or cultural manifestations bounded in time and space.\n\nIt is the social or physical coherence of these phenomena that identify an E4 Period and not the associated spatiotemporal bounds. These bounds are a mere approximation of the actual process of growth, spread and retreat. Consequently, different periods can overlap and coexist in time and space, such as when a nomadic culture exists in the same area as a sedentary culture. As the actual extent of an E4 Period in spacetime we regard the trajectories of the participating physical things during their participation in an instance of E4 Period, the open spaces via which they have interacted and the spaces by which they had the potential to interact during that period or event in the way defined by the type of the respective period or event, such as the air in a meeting room transferring the voices. Since these phenomena are fuzzy, we assume the spatiotemporal extent to be contiguous, except for cases of phenomena spreading out over islands or other separated areas. In these cases, the trajectories necessary for participants to travel between these areas are not regarded as part of the spatiotemporal extent. Consequently, instances of E4 Period may occupy each a limited number of disjoint spacetime volumes, however there must not be a discontinuity in the total timespan covered by these spacetime volumes.\n\nTypically this class is used to describe prehistoric or historic periods such as the “Neolithic Period”, the “Ming Dynasty” or the “McCarthy Era”, but also geopolitical units and activities of settlements are regarded as special cases of E4 Period. Geopolitical units may be distributed over disconnected areas, such as islands or colonies. In such cases, the spatiotemporal extent is composed of more than one spacetime volume. One may argue that the activities to govern disconnected areas imply travelling through spaces connecting them and that these areas hence are spatially connected in a way, but it appears counterintuitive to consider for instance travel routes in international waters as extensions of geopolitical units. Nevertheless, an instance of E4 Period must be contiguous in time. I.e., if it has ended in all areas, it has ended as a whole, but it may involve one area after another, such as the Polynesian migration, as long as it is ongoing at least in one area.\n\nThere are no assumptions about the scale of the associated phenomena. In particular all events are seen as synthetic processes consisting of coherent phenomena. Therefore E4 Period is a superclass of E5 Event. For example, a modern clinical E67 Birth can be seen as both an atomic E5 Event and as an E4 Period that consists of multiple activities performed by multiple instances of E39 Actor.\n\nThere are two different conceptualisations of ‘artistic style’, defined either by physical features or by historical context. For example, “Impressionism” can be viewed as a period lasting from approximately 1870 to 1905 during which paintings with particular characteristics were produced by a group of artists that included (among others) Monet, Renoir, Pissarro, Sisley and Degas. Alternatively, it can be regarded as a style applicable to all paintings sharing the characteristics of the works produced by the Impressionist painters, regardless of historical context. The first interpretation is an E4 Period, and the second defines morphological object types that fall under E55 Type.\nAnother specific case of an E4 Period is the set of activities and phenomena associated with a settlement, such as the populated period of Nineveh.\n"},
      label: {en: "Period", cn: "期间", de: "Phase", el: "Περίοδος", fr: "Période", pt: "Período", ru: "Период"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E50_Date,
      comment: {en: "This class comprises specific forms of E49 Time Appellation."},
      label: {en: "Date", cn: "日期", de: "Datum", el: "Ημερομηνία", fr: "Date", pt: "Data", ru: "Дата"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E49_Time_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E51_Contact_Point,
      comment: {en: "This class comprises identifiers employed, or understood, by communication services to direct communications to an instance of E39 Actor. These include E-mail addresses, telephone numbers, post office boxes, Fax numbers, URLs etc. Most postal addresses can be considered both as instances of E44 Place Appellation and E51 Contact Point. In such cases the subclass E45 Address should be used. \nURLs are addresses used by machines to access another machine through an http request. Since the accessed machine acts on behalf of the E39 Actor providing the machine, URLs are considered as instances of E51 Contact Point to that E39 Actor.\n"},
      label: {en: "Contact Point", cn: "联系方式", de: "Kontaktpunkt", el: "Στοιχείο Επικοινωνίας", fr: "Coordonnées individuelles", pt: "Ponto de Contato", ru: "Контакт"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E52_Time-Span",
      comment: {en: "This class comprises abstract temporal extents, in the sense of Galilean physics, having a beginning, an end and a duration. \nTime Span has no other semantic connotations. Time-Spans are used to define the temporal extent of instances of E4 Period, E5 Event and any other phenomena valid for a certain time. An E52 Time-Span may be identified by one or more instances of E49 Time Appellation. \nSince our knowledge of history is imperfect, instances of E52 Time-Span can best be considered as approximations of the actual Time-Spans of temporal entities. The properties of E52 Time-Span are intended to allow these approximations to be expressed precisely.  An extreme case of approximation, might, for example, define an E52 Time-Span having unknown beginning, end and duration. Used as a common E52 Time-Span for two events, it would nevertheless define them as being simultaneous, even if nothing else was known. \n\tAutomatic processing and querying of instances of E52 Time-Span is facilitated if data can be parsed into an E61 Time Primitive.\n"},
      label: {en: "Time-Span", cn: "时段", de: "Zeitspanne", el: "Χρονικό Διάστημα", fr: "Durée", pt: "Período de Tempo", ru: "Интервал Времени"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E53_Place,
      comment: {en: "This class comprises extents in space, in particular on the surface of the earth, in the pure sense of physics: independent from temporal phenomena and matter. \nThe instances of E53 Place are usually determined by reference to the position of “immobile” objects such as buildings, cities, mountains, rivers, or dedicated geodetic marks. A Place can be determined by combining a frame of reference and a location with respect to this frame. It may be identified by one or more instances of E44 Place Appellation.\n It is sometimes argued that instances of E53 Place are best identified by global coordinates or absolute reference systems. However, relative references are often more relevant in the context of cultural documentation and tend to be more precise. In particular, we are often interested in position in relation to large, mobile objects, such as ships. For example, the Place at which Nelson died is known with reference to a large mobile object – H.M.S Victory. A resolution of this Place in terms of absolute coordinates would require knowledge of the movements of the vessel and the precise time of death, either of which may be revised, and the result would lack historical and cultural relevance.\nAny object can serve as a frame of reference for E53 Place determination. The model foresees the notion of a \"section\" of an E19 Physical Object as a valid E53 Place determination."},
      label: {en: "Place", cn: "地点", de: "Ort", el: "Τόπος", fr: "Lieu", pt: "Local", ru: "Место"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E54_Dimension,
      comment: {en: "This class comprises quantifiable properties that can be measured by some calibrated means and can be approximated by values, i.e. points or regions in a mathematical or conceptual space, such as natural or real numbers, RGB values etc.\nAn instance of E54 Dimension represents the true quantity, independent from its numerical approximation, e.g. in inches or in cm. The properties of the class E54 Dimension allow for expressing the numerical approximation of the values of an instance of E54 Dimension. If the true values belong to a non-discrete space, such as spatial distances, it is recommended to record them as approximations by intervals or regions of indeterminacy enclosing the assumed true values. For instance, a length of 5 cm may be recorded as 4.5-5.5 cm, according to the precision of the respective observation. Note, that interoperability of values described in different units depends critically on the representation as value regions.\nNumerical approximations in archaic instances of E58 Measurement Unit used in historical records should be preserved. Equivalents corresponding to current knowledge should be recorded as additional instances of E54 Dimension as appropriate.\n"},
      label: {en: "Dimension", cn: "规模数量", de: "Maß", el: "Μέγεθος", fr: "Dimensions", pt: "Dimensão", ru: "Величина"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E55_Type,
      comment: {en: "This class comprises concepts denoted by terms from thesauri and controlled vocabularies used to characterize and classify instances of CRM classes. Instances of E55 Type represent concepts  in contrast to instances of E41 Appellation which are used to name instances of CRM classes. \nE55 Type is the CRM’s interface to domain specific ontologies and thesauri. These can be represented in the CRM as subclasses of E55 Type, forming hierarchies of terms, i.e. instances of E55 Type linked via P127 has broader  term (has narrower term). Such hierarchies may be extended with additional properties. \n"},
      label: {en: "Type", cn: "类型", de: "Typus", el: "Τύπος", fr: "Type", pt: "Tipo", ru: "Тип"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E56_Language,
      comment: {en: "This class is a specialization of E55 Type and comprises the natural languages in the sense of concepts. \nThis type is used categorically in the model without reference to instances of it, i.e. the Model does not foresee the description of instances of instances of E56 Language, e.g.: “instances of  Mandarin Chinese”.\nIt is recommended that internationally or nationally agreed codes and terminology are used to denote instances of E56 Language, such as those defined in ISO 639:1988. \n"},
      label: {en: "Language", cn: "语言", de: "Sprache", el: "Γλώσσα", fr: "Langue", pt: "Língua", ru: "Язык"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E57_Material,
      comment: {en: "This class is a specialization of E55 Type and comprises the concepts of materials. \nInstances of E57 Material may denote properties of matter before its use, during its use, and as incorporated in an object, such as ultramarine powder, tempera paste, reinforced concrete. Discrete pieces of raw-materials kept in museums, such as bricks, sheets of fabric, pieces of metal, should be modelled individually in the same way as other objects. Discrete used or processed pieces, such as the stones from Nefer Titi's temple, should be modelled as parts (cf. P46 is composed of).\nThis type is used categorically in the model without reference to instances of it, i.e. the Model does not foresee the description of instances of instances of E57 Material, e.g.: “instances of  gold”.\nIt is recommended that internationally or nationally agreed codes and terminology are used."},
      label: {en: "Material", cn: "材料", de: "Material", el: "Υλικό", fr: "Matériau", pt: "Material", ru: "Материал"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E58_Measurement_Unit,
      comment: {en: "This class is a specialization of E55 Type and comprises the types of measurement units: feet, inches, centimetres, litres, lumens, etc. \nThis type is used categorically in the model without reference to instances of it, i.e. the Model does not foresee the description of instances of instances of E58 Measurement Unit, e.g.: “instances of cm”.\nSyst?me International (SI) units or internationally recognized non-SI terms should be used whenever possible. (ISO 1000:1992). Archaic Measurement Units used in historical records should be preserved.\n"},
      label: {en: "Measurement Unit", cn: "测量单位", de: "Maßeinheit", el: "Μονάδα Μέτρησης", fr: "Unité de mesure", pt: "Unidade de Medida", ru: "Единица Измерения"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E5_Event,
      comment: {en: "This class comprises changes of states in cultural, social or physical systems, regardless of scale, brought about by a series or group of coherent physical, cultural, technological or legal phenomena. Such changes of state will affect instances of E77 Persistent Item or its subclasses.\nThe distinction between an E5 Event and an E4 Period is partly a question of the scale of observation. Viewed at a coarse level of detail, an E5 Event is an ‘instantaneous’ change of state. At a fine level, the E5 Event can be analysed into its component phenomena within a space and time frame, and as such can be seen as an E4 Period. The reverse is not necessarily the case: not all instances of E4 Period give rise to a noteworthy change of state.\n"},
      label: {en: "Event", cn: "事件", de: "Ereignis", el: "Συμβάν", fr: "Événement", pt: "Evento", ru: "Событие"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E63_Beginning_of_Existence,
      comment: {en: "This class comprises events that bring into existence any E77 Persistent Item. \nIt may be used for temporal reasoning about things (intellectual products, physical items, groups of people, living beings) beginning to exist; it serves as a hook for determination of a terminus post quem and ante quem. "},
      label: {en: "Beginning of Existence", cn: "存在开始", de: "Daseinsbeginn", el: "Αρχή Ύπαρξης", fr: "Début d'existence", pt: "Início da Existência", ru: "Начало Существования"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E64_End_of_Existence,
      comment: {en: "This class comprises events that end the existence of any E77 Persistent Item. \nIt may be used for temporal reasoning about things (physical items, groups of people, living beings) ceasing to exist; it serves as a hook for determination of a terminus postquem and antequem. In cases where substance from a Persistent Item continues to exist in a new form, the process would be documented by E81 Transformation.\n"},
      label: {en: "End of Existence", cn: "存在结束", de: "Daseinsende", el: "Τέλος Ύπαρξης", fr: "Fin d'existence", pt: "Fim da Existência", ru: "Конец Существования"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E65_Creation,
      comment: {en: "This class comprises events that result in the creation of conceptual items or immaterial products, such as legends, poems, texts, music, images, movies, laws, types etc.\n"},
      label: {en: "Creation", cn: "创造", de: "Begriffliche Schöpfung", el: "Δημιουργία", fr: "Création", pt: "Criação", ru: "Событие Творения"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence", "http://www.cidoc-crm.org/cidoc-crm/E7_Activity"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E66_Formation,
      comment: {en: "This class comprises events that result in the formation of a formal or informal E74 Group of people, such as a club, society, association, corporation or nation. \nE66 Formation does not include the arbitrary aggregation of people who do not act as a collective.\nThe formation of an instance of E74 Group does not mean that the group is populated with members at the time of formation. In order to express the joining of members at the time of formation, the respective activity should be simultaneously an instance of both E66 Formation and E85 Joining. \n"},
      label: {en: "Formation", cn: "组成", de: "Gruppenbildung", el: "Συγκρότηση Ομάδας", fr: "Formation", pt: "Formação", ru: "Событие Формирования"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence", "http://www.cidoc-crm.org/cidoc-crm/E7_Activity"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E67_Birth,
      comment: {en: "This class comprises the births of human beings. E67 Birth is a biological event focussing on the context of people coming into life. (E63 Beginning of Existence comprises the coming into life of any living beings). \nTwins, triplets etc. are brought into life by the same E67 Birth event. The introduction of the E67 Birth event as a documentation element allows the description of a range of family relationships in a simple model. Suitable extensions may describe more details and the complexity of motherhood with the intervention of modern medicine. In this model, the biological father is not seen as a necessary participant in the E67 Birth event.\n"},
      label: {en: "Birth", cn: "诞生", de: "Geburt", el: "Γέννηση", fr: "Naissance", pt: "Nascimento", ru: "Рождение"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E68_Dissolution,
      comment: {en: "This class comprises the events that result in the formal or informal termination of an E74 Group of people. \nIf the dissolution was deliberate, the Dissolution event should also be instantiated as an E7 Activity.\n"},
      label: {en: "Dissolution", cn: "解散", de: "Gruppenauflösung", el: "Διάλυση Ομάδας", fr: "Dissolution", pt: "Dissolução", ru: "Роспуск"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E69_Death,
      comment: {en: "This class comprises the deaths of human beings. \nIf a person is killed, their death should be instantiated as E69 Death and as E7 Activity. The death or perishing of other living beings should be documented using E64 End of Existence.\n"},
      label: {en: "Death", cn: "死亡", de: "Tod", el: "Θάνατος", fr: "Mort", pt: "Morte", ru: "Смерть"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E6_Destruction,
      comment: {en: "This class comprises events that destroy one or more instances of E18 Physical Thing such that they lose their identity as the subjects of documentation.  \nSome destruction events are intentional, while others are independent of human activity. Intentional destruction may be documented by classifying the event as both an E6 Destruction and E7 Activity. \nThe decision to document an object as destroyed, transformed or modified is context sensitive: \n1.  If the matter remaining from the destruction is not documented, the event is modelled solely as E6 Destruction. \n2. An event should also be documented using E81 Transformation if it results in the destruction of one or more objects and the simultaneous production of others using parts or material from the original. In this case, the new items have separate identities. Matter is preserved, but identity is not.\n3. When the initial identity of the changed instance of E18 Physical Thing is preserved, the event should be documented as E11 Modification. \n"},
      label: {en: "Destruction", cn: "摧毁", de: "Zerstörung", el: "Καταστροφή", fr: "Destruction", pt: "Destruição", ru: "Разрушение"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E70_Thing,
      comment: {en: "This general class comprises discrete, identifiable, instances of E77 Persistent Item that are documented as single units, that either consist of matter or depend on being carried by matter and are characterized by relative stability.\nThey may be intellectual products or physical things. They may for instance have a solid physical form, an electronic encoding, or they may be a logical concept or structure.\n"},
      label: {en: "Thing", cn: "万物", de: "Sache", el: "Πράγμα", fr: "Chose", pt: "Coisa"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E71_Man-Made_Thing",
      comment: {en: "This class comprises discrete, identifiable man-made items that are documented as single units. \nThese items are either intellectual products or man-made physical things, and are characterized by relative stability. They may for instance have a solid physical form, an electronic encoding, or they may be logical concepts or structures.\n"},
      label: {en: "Man-Made Thing", cn: "人造物", de: "Künstliches", el: "Ανθρώπινο Δημιούργημα", fr: "Chose fabriquée", pt: "Coisa Fabricada", ru: "Рукотворная Вещь"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E72_Legal_Object,
      comment: {en: "This class comprises those material or immaterial items to which instances of E30 Right, such as the right of ownership or use, can be applied. \nThis is true for all E18 Physical Thing. In the case of instances of E28 Conceptual Object, however, the identity of the E28 Conceptual Object or the method of its use may be too ambiguous to reliably establish instances of E30 Right, as in the case of taxa and inspirations. Ownership of corporations is currently regarded as out of scope of the CRM. \n"},
      label: {en: "Legal Object", cn: "法律物件", de: "Rechtsobjekt", el: "Νομικό Αντικείμενο", fr: "Objet juridique", pt: "Objeto Jurídico", ru: "Объект Права"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E73_Information_Object,
      comment: {en: "This class comprises identifiable immaterial items, such as a poems, jokes, data sets, images, texts, multimedia objects, procedural prescriptions, computer program code, algorithm or mathematical formulae, that have an objectively recognizable structure and are documented as single units. \nAn E73 Information Object does not depend on a specific physical carrier, which can include human memory, and it can exist on one or more carriers simultaneously.\nInstances of E73 Information Object of a linguistic nature should be declared as instances of the E33 Linguistic Object subclass. Instances of E73 Information Object of a documentary nature should be declared as instances of the E31 Document subclass. Conceptual items such as types and classes are not instances of E73 Information Object, nor are ideas without a reproducible expression. \n"},
      label: {en: "Information Object", cn: "信息物件", de: "Informationsgegenstand", el: "Πληροφοριακό Αντικείμενο", fr: "Objet d'information", pt: "Objeto de Informação", ru: "Информационный Объект"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object", "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E74_Group,
      comment: {en: "This class comprises any gatherings or organizations of E39 Actors that act collectively or in a similar way due to any form of unifying relationship. In the wider sense this class also comprises official positions which used to be regarded in certain contexts as one actor, independent of the current holder of the office, such as the president of a country. In such cases, it may happen that the Group never had more than one member. A joint pseudonym (i.e., a name that seems indicative of an individual but that is actually used as a persona by two or more people) is a particular case of E74 Group.\nA gathering of people becomes an E74 Group when it exhibits organizational characteristics usually typified by a set of ideas or beliefs held in common, or actions performed together. These might be communication, creating some common artifact, a common purpose such as study, worship, business, sports, etc. Nationality can be modeled as membership in an E74 Group (cf. HumanML markup). Married couples and other concepts of family are regarded as particular examples of E74 Group.\n"},
      label: {en: "Group", cn: "群组", de: "Menschliche Gruppe", el: "Ομάδα", fr: "Groupe", pt: "Grupo", ru: "Группа"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E75_Conceptual_Object_Appellation,
      comment: {en: "This class comprises appellations that are by their form or syntax specific to identifying instances of E28 Conceptual Object, such as intellectual products, standardized patterns etc."},
      label: {en: "Conceptual Object Appellation", cn: "概念物件称号", de: "Begriff- oder Konzeptbenennung ", el: "Ονομασία Νοητικού Αντικειμένου", fr: "Appellation d'objet conceptuel", pt: "Designação de Objeto Conceitual", ru: "Обозначение Концептуального Объекта"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E77_Persistent_Item,
      comment: {en: "This class comprises items that have a persistent identity, sometimes known as “endurants” in philosophy. \nThey can be repeatedly recognized within the duration of their existence by identity criteria rather than by continuity or observation. Persistent Items can be either physical entities, such as people, animals or things, or conceptual entities such as ideas, concepts, products of the imagination or common names.\nThe criteria that determine the identity of an item are often difficult to establish -; the decision depends largely on the judgement of the observer. For example, a building is regarded as no longer existing if it is dismantled and the materials reused in a different configuration. On the other hand, human beings go through radical and profound changes during their life-span, affecting both material composition and form, yet preserve their identity by other criteria. Similarly, inanimate objects may be subject to exchange of parts and matter. The class E77 Persistent Item does not take any position about the nature of the applicable identity criteria and if actual knowledge about identity of an instance of this class exists. There may be cases, where the identity of an E77 Persistent Item is not decidable by a certain state of knowledge.\nThe main classes of objects that fall outside the scope the E77 Persistent Item class are temporal objects such as periods, events and acts, and descriptive properties. "},
      label: {en: "Persistent Item", cn: "持续性项目", de: "Seiendes", el: "Ον", fr: "Entité persistante", pt: "Entidade Persistente", ru: "Постоянная Сущность"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E78_Collection,
      comment: {en: "This class comprises aggregations of instances of E18 Physical Thing that are assembled and maintained (“curated” and “preserved,” in museological terminology) by one or more instances of E39 Actor over time for a specific purpose and audience, and according to a particular collection development plan.  \nItems may be added or removed from an E78 Collection in pursuit of this plan. This class should not be confused with the E39 Actor maintaining the E78 Collection often referred to with the name of the E78 Collection (e.g. “The Wallace Collection decided…”).\nCollective objects in the general sense, like a tomb full of gifts, a folder with stamps or a set of chessmen, should be documented as instances of E19 Physical Object, and not as instances of E78 Collection. This is because they form wholes either because they are physically bound together or because they are kept together for their functionality.\n"},
      label: {en: "Collection", cn: "收藏", de: "Sammlung", el: "Συλλογή", fr: "Collection", pt: "Coleção", ru: "Коллекция"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E79_Part_Addition,
      comment: {en: "This class comprises activities that result in an instance of E24 Physical Man-Made Thing being increased, enlarged or augmented by the addition of a part. \nTypical scenarios include the attachment of an accessory, the integration of a component, the addition of an element to an aggregate object, or the accessioning of an object into a curated E78 Collection. Objects to which parts are added are, by definition, man-made, since the addition of a part implies a human activity. Following the addition of parts, the resulting man-made assemblages are treated objectively as single identifiable wholes, made up of constituent or component parts bound together either physically (for example the engine becoming a part of the car), or by sharing a common purpose (such as the 32 chess pieces that make up a chess set). This class of activities forms a basis for reasoning about the history and continuity of identity of objects that are integrated into other objects over time, such as precious gemstones being repeatedly incorporated into different items of jewellery, or cultural artifacts being added to different museum instances of E78 Collection over their lifespan.\n"},
      label: {en: "Part Addition", cn: "部件增加", de: "Teilhinzufügung", el: "Προσθήκη Μερών", fr: "Addition d'élément", pt: "Adição de Parte", ru: "Добавление Части"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E7_Activity,
      comment: {en: "This class comprises actions intentionally carried out by instances of E39 Actor that result in changes of state in the cultural, social, or physical systems documented. \nThis notion includes complex, composite and long-lasting actions such as the building of a settlement or a war, as well as simple, short-lived actions such as the opening of a door.\n"},
      label: {en: "Activity", cn: "活动", de: "Handlung", el: "Δράση", fr: "Activité", pt: "Atividade", ru: "Деятельность"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E80_Part_Removal,
      comment: {en: "This class comprises the activities that result in an instance of E18 Physical Thing being decreased by the removal of a part.\nTypical scenarios include the detachment of an accessory, the removal of a component or part of a composite object, or the deaccessioning of an object from a curated E78 Collection. If the E80 Part Removal results in the total decomposition of the original object into pieces, such that the whole ceases to exist, the activity should instead be modelled as an E81 Transformation, i.e. a simultaneous destruction and production. In cases where the part removed has no discernible identity prior to its removal but does have an identity subsequent to its removal, the activity should be regarded as both E80 Part Removal and E12 Production. This class of activities forms a basis for reasoning about the history, and continuity of identity over time, of objects that are removed from other objects, such as precious gemstones being extracted from different items of jewelry, or cultural artifacts being deaccessioned from different museum collections over their lifespan.\n"},
      label: {en: "Part Removal", cn: "部件删除", de: "Teilentfernung", el: "Αφαίρεση Μερών", fr: "Soustraction d'élément", pt: "Remoção de Parte", ru: "Удаление Части"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E81_Transformation,
      comment: {en: "This class comprises the events that result in the simultaneous destruction of one or more than one E77 Persistent Item and the creation of one or more than one E77 Persistent Item that preserves recognizable substance from the first one(s) but has fundamentally different nature and identity. \nAlthough the old and the new instances of E77 Persistent Item are treated as discrete entities having separate, unique identities, they are causally connected through the E81 Transformation; the destruction of the old E77 Persistent Item(s) directly causes the creation of the new one(s) using or preserving some relevant substance. Instances of E81 Transformation are therefore distinct from re-classifications (documented using E17 Type Assignment) or modifications (documented using E11 Modification) of objects that do not fundamentally change their nature or identity. Characteristic cases are reconstructions and repurposing of historical buildings or ruins, fires leaving buildings in ruins, taxidermy of specimen in natural history and the reorganization of a corporate body into a new one.\n"},
      label: {en: "Transformation", cn: "转变", de: "Umwandlung", el: "Μετατροπή", fr: "Transformation", pt: "Transformação", ru: "Трансформация"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence", "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E82_Actor_Appellation,
      comment: {en: "This class comprises any sort of name, number, code or symbol characteristically used to identify an E39 Actor. \nAn E39 Actor will typically have more than one E82 Actor Appellation, and instances of E82 Actor Appellation in turn may have alternative representations. The distinction between corporate and personal names, which is particularly important in library applications, should be made by explicitly linking the E82 Actor Appellation to an instance of either E21 Person or E74 Group/E40 Legal Body. If this is not possible, the distinction can be made through the use of the P2 has type mechanism. \n"},
      label: {en: "Actor Appellation", cn: "角色称号", de: "Akteurbenennung", el: "Ονομασία Δράστη", fr: "Appellation d'agent", pt: "Designação de Agente", ru: "Обозначение Агента"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E83_Type_Creation,
      comment: {en: "This class comprises activities formally defining new types of items. \nIt is typically a rigorous scholarly or scientific process that ensures a type is exhaustively described and appropriately named. In some cases, particularly in archaeology and the life sciences, E83 Type Creation requires the identification of an exemplary specimen and the publication of the type definition in an appropriate scholarly forum. The activity of E83 Type Creation is central to research in the life sciences, where a type would be referred to as a “taxon,” the type description as a “protologue,” and the exemplary specimens as “orgininal element” or “holotype”.\n"},
      label: {en: "Type Creation", cn: "类型创造", de: "Typuserfindung", el: "Δημιουργία Τύπου", fr: "Création de type", pt: "Criação de Tipo", ru: "Создание Типа"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E65_Creation",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E84_Information_Carrier,
      comment: {en: "This class comprises all instances of E22 Man-Made Object that are explicitly designed to act as persistent physical carriers for instances of E73 Information Object.\nAn E84 Information Carrier may or may not contain information, e.g., a diskette. Note that any E18 Physical Thing may carry information, such as an E34 Inscription. However, unless it was specifically designed for this purpose, it is not an Information Carrier. Therefore the property P128 carries (is carried by) applies to E18 Physical Thing in general.\n\t"},
      label: {en: "Information Carrier", cn: "信息载体", de: "Informationsträger", el: "Φορέας Πληροφορίας", fr: "Support d'information", pt: "Suporte de Informação", ru: "Носитель Информации"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E22_Man-Made_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E85_Joining,
      comment: {en: "This class comprises the activities that result in an instance of E39 Actor becoming a member of an instance of E74 Group. This class does not imply initiative by either party.\nTypical scenarios include becoming a member of a social organisation, becoming employee of a company, marriage, the adoption of a child by a family and the inauguration of somebody into an official position. \n"},
      label: {en: "Joining", cn: "加入", de: "Beitritt"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E86_Leaving,
      comment: {en: "This class comprises the activities that result in an instance of E39 Actor to be disassociated from an instance of E74 Group. This class does not imply initiative by either party. \nTypical scenarios include the termination of membership in a social organisation, ending the employment at a company, divorce, and the end of tenure of somebody in an official position."},
      label: {en: "Leaving", cn: "脱离", de: "Austritt"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E87_Curation_Activity,
      comment: {en: "This class comprises the activities that result in the continuity of management and the preservation and evolution of instances of E78 Collection, following an implicit or explicit curation plan. \nIt specializes the notion of activity into the curation of a collection and allows the history of curation to be recorded.\nItems are accumulated and organized following criteria like subject, chronological period, material type, style of art etc. and can be added or removed from an E78 Collection for a specific purpose and/or audience. The initial aggregation of items of a collection is regarded as an instance of E12 Production Event while the activity of evolving, preserving and promoting a collection is regarded as an instance of E87 Curation Activity.\n"},
      label: {en: "Curation Activity", cn: "典藏管理", de: "Kuratorische Tätigkeit"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E89_Propositional_Object,
      comment: {en: "This class comprises immaterial items, including but not limited to stories, plots, procedural prescriptions, algorithms, laws of physics or images that are, or represent in some sense, sets of propositions about real or imaginary things and that are documented as single units or serve as topics of discourse. \n\t\nThis class also comprises items that are “about” something in the sense of a subject. In the wider sense, this class includes expressions of psychological value such as non-figural art and musical themes. However, conceptual items such as types and classes are not instances of E89 Propositional Object. This should not be confused with the definition of a type, which is indeed an instance of E89 Propositional Object.\n"},
      label: {en: "Propositional Object", cn: "陈述性物件", de: "Aussagenobjekt"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E8_Acquisition,
      comment: {en: "This class comprises transfers of legal ownership from one or more instances of E39 Actor to one or more other instances of E39 Actor. \nThe class also applies to the establishment or loss of ownership of instances of E18 Physical Thing. It does not, however, imply changes of any other kinds of right. The recording of the donor and/or recipient is optional. It is possible that in an instance of E8 Acquisition there is either no donor or no recipient. Depending on the circumstances, it may describe:\n1.\tthe beginning of ownership\n2.\tthe end of ownership\n3.\tthe transfer of ownership\n4.\tthe acquisition from an unknown source \n5.\tthe loss of title due to destruction of the item\nIt may also describe events where a collector appropriates legal title, for example by annexation or field collection. The interpretation of the museum notion of \"accession\" differs between institutions. The CRM therefore models legal ownership (E8 Acquisition) and physical custody (E10 Transfer of Custody) separately. Institutions will then model their specific notions of accession and deaccession as combinations of these.\n"},
      label: {en: "Acquisition", cn: "征集取得", de: "Erwerb", el: "Απόκτηση", fr: "Acquisition", pt: "Aquisição", ru: "Событие Приобретения"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E90_Symbolic_Object,
      comment: {en: "This class comprises identifiable symbols and any aggregation of symbols, such as characters, identifiers, traffic signs, emblems, texts, data sets, images, musical scores, multimedia objects, computer program code or mathematical formulae that have an objectively recognizable structure and that are documented as single units.\n\tIt includes sets of signs of any nature, which may serve to designate something, or to communicate some propositional content.\n\tAn instance of E90 Symbolic Object does not depend on a specific physical carrier, which can include human memory, and it can exist on one or more carriers simultaneously. An instance of E90 Symbolic Object may or may not have a specific meaning, for example an arbitrary character string.\n\tIn some cases, the content of an instance of E90 Symbolic Object may completely be represented by a serialized content model, such.. as the property P3 has note allows for describing this content model…P3.1 has type: E55 Type to specify the encoding..\n"},
      label: {en: "Symbolic Object", cn: "符号物件", de: "Symbolisches Objekt"},
      subClassOf: ["http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object", "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object"],
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :"E91_Co-Reference_Assignment",
      comment: {en: "This class comprises actions of making the assertion whether two or more particular instances of E89 Propositional Object refer to the same instance of E1 CRM Entity. The assertion is based on the assumption that this was an implicit fact being made explicit by this assignment. Use of this class allows for the full description of the context of this assignment. The Actor making the assertion may have different kinds of confidence in the truth of the asserted fact of co-reference, because it may imply an interpretation of the (past) knowledge behind the propositional objects assumed to be co-referring. This kind of confidence can be described by using the property P2 has type (is type of). In case different propositional attitudes should be expressed per asserted propositional object, the assertion has accordingly to be divided into one instance of E91 Co-Reference Assignment for each kind of confidence.\nThis class aims at the problem of interpreting within a particular passage of an historical text, to which real-world entity a particular name, pronoun or equivalent expression was intended to refer by the texts author. In other words, it expresses the uncertainty of the creator of the assertion about the meaning of the information provided by another person.\nEach such interpretation can only be documented with respect to another reference – either found in another text by the same or a different author, and/or by referring to the world known to the creator of the co-reference assertion. To do the latter, the property P155 has co-reference target (is co-reference target of) allows for referring to an instance of CRM Entity of the creator’s world. In a sense, the respective instance of E91 Co-Reference Assignment using the property P155 has co-reference target (is co-reference target of) in a knowledge base forms propositional object referring to the creator’s target entity, since a knowledge base as a whole can be seen as a propositional object. Consequently, if in a Semantic Web implementation the target entity is instantiated by a URI, the meaning of this identifier must be unambiguous to the creator of the co-reference assignment. Similarly, a URI of another authority, such as an author catalogue of a library, can be interpreted as a referring proposition of this catalogue, and be referred to by the property P153 assigned co-reference to (was regarded to co-refer by) or P154 assigned non co-reference to (was regarded not to co-refer by): E89 Propositional Object in order to express that it does not immediately represent the creator’s known world. In this case, the authority that knows the meaning of this URI must be unambiguous by the form of the URI itself.\nIn contrast, the meaning of the property ‘owl:same_as’ of the OWL knowledge representation language cannot specify who’s knowledge it represents and cannot express kind of confidence. Therefore it is not adequate to model the progress of scholarly co-reference research.\n"},
      label: {en: "Co-Reference Assignment"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E92_Spacetime_Volume,
      comment: {en: "This class comprises 4 dimensional point sets (volumes) in physical spacetime regardless its true geometric form. They may derive their identity from being the extent of a material phenomenon or from being the interpretation of an expression defining an extent in spacetime. \n\tIntersections of instances of E92 Spacetime Volume, Place and Timespan are also regarded as instances of E92 Spacetime Volume.  An instance of E92 Spacetime Volume is either contiguous or composed of a finite number of contiguous subsets. \n\tIts boundaries may be fuzzy due to the properties of the phenomena it derives from or due to the limited precision up to which defining expression can be identified with a real extent in spacetime. The duration of existence of an instance of a spacetime volume is trivially its projection on time.\n"},
      label: {en: "Spacetime Volume"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E93_Spacetime_Snapshot,
      comment: {en: "This class comprises instances of E92 Spacetime Volume that result from intersection of instances of E92 Spacetime Volume with an instance of E52 Time-Span. The identity of an instance of this class is determined by the identities of the constituing spacetime volume and the time-span.\nThis class can be used to define temporal snapshots at a particular time-span, such as the extent of the Roman Empire at 33 B.C., or the extent occupied by a museum object at rest in an exhibit. In particular, it can be used to define the spatial projection of a spacetime volume during a particular time-span, such as the maximal spatial extent of a flood at some particular hour, or all areas covered by the Poland within the 20th century AD\n"},
      label: {en: "Spacetime Snapshot"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E92_Spacetime_Volume",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"
    term :E9_Move,
      comment: {en: "This class comprises changes of the physical location of the instances of E19 Physical Object. \nNote, that the class E9 Move inherits the property P7 took place at (witnessed): E53 Place. This property should be used to describe the trajectory or a larger area within which a move takes place, whereas the properties P26 moved to (was destination of), P27 moved from (was origin of) describe the start and end points only. Moves may also be documented to consist of other moves (via P9 consists of (forms part of)), in order to describe intermediate stages on a trajectory. In that case, start and end points of the partial moves should match appropriately between each other and with the overall event.\n"},
      label: {en: "Move", cn: "移动", de: "Objektbewegung", el: "Μετακίνηση", fr: "Déplacement", pt: "Locomoção", ru: "Перемещение"},
      subClassOf: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/2000/01/rdf-schema#Class"

    # Property definitions
    property :P100_was_death_of,
      comment: {en: "This property property links an E69 Death event to the E21 Person that died."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E69_Death",
      label: {en: "was death of", cn: "灭亡了", de: "Tod von", el: "ήταν θάνατος του/της", fr: "a été la mort de", pt: "foi a morte para ", ru: "был смертью для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93_took_out_of_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P100i_died_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "died in", cn: "死亡於", de: "starb in", el: "πέθανε σε", fr: "est mort par", pt: "morreu em", ru: "умер в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E69_Death",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93i_was_taken_out_of_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P101_had_as_general_use,
      comment: {en: "This property links an instance of E70 Thing to an E55 Type of usage.\nIt allows the relationship between particular things, both physical and immaterial, and general methods and techniques of use to be documented. Thus it can be asserted that a baseball bat had a general use for sport and a specific use for threatening people during the Great Train Robbery.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      label: {en: "had as general use", cn: "被惯用於", de: "hatte die allgemeine Verwendung", el: "είχε ως γενική χρήση", fr: "avait comme utilisation générale", pt: "tem como uso geral", ru: "имел основное применение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P101i_was_use_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was use of", cn: "可使用", de: "war die Verwendung von", el: "ήταν χρήση του/της", fr: "était l’utilisation de", pt: "foi uso de", ru: "был применением для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P102_has_title,
      comment: {en: "This property describes the E35 Title applied to an instance of E71 Man-Made Thing. The E55 Type of Title is assigned in a sub property.\nThe P102.1 has type property of the P102 has title (is title of) property enables the relationship between the Title and the thing to be further clarified, for example, if the Title was a given Title, a supplied Title etc.\nIt allows any man-made material or immaterial thing to be given a Title. It is possible to imagine a Title being created without a specific object in mind.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      label: {en: "has title", cn: "有标题", de: "trägt den Titel", el: "έχει τίτλο", fr: "a pour titre", pt: "tem título", ru: "имеет заголовок"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E35_Title",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P102i_is_title_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E35_Title",
      label: {en: "is title of", cn: "被用为标题来称呼", de: "ist der Titel von", el: "είναι τίτλος του/της", fr: "est le titre de", pt: "é título de", ru: "является заголовком для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P103_was_intended_for,
      comment: {en: "This property links an instance of E71 Man-Made Thing to an E55 Type of usage. \nIt creates a property between specific man-made things, both physical and immaterial, to Types of intended methods and techniques of use. Note: A link between specific man-made things and a specific use activity should be expressed using P19 was intended use of (was made for)."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      label: {en: "was intended for", cn: "被制作来用於", de: "bestimmt für", el: "προοριζόταν για", fr: "était destiné à", pt: "era destinado à", ru: "был задуман для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P103i_was_intention_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was intention of", de: "war Bestimmung von", el: "ήταν προορισμός του", fr: "était la raison d'être de", pt: "era a destinação de", ru: "был интенцией для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P104_is_subject_to,
      comment: {en: "This property links a particular E72 Legal Object to the instances of E30 Right to which it is subject.\nThe Right is held by an E39 Actor as described by P75 possesses (is possessed by).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object",
      label: {en: "is subject to", cn: "受制於", de: "Gegenstand von", el: "υπόκειται σε", fr: "est sujet à", pt: "está sujeito à", ru: "является объектом для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E30_Right",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P104i_applies_to,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E30_Right",
      label: {en: "applies to", cn: "被应用於", de: "findet Anwendung auf", el: "ισχύει για", fr: "s’applique à", pt: "se aplicam à", ru: "применяется к"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P105_right_held_by,
      comment: {en: "This property identifies the E39 Actor who holds the instances of E30 Right to an E72 Legal Object.\n\tIt is a superproperty of P52 has current owner (is current owner of) because ownership is a right that is held on the owned object.\nP105 right held by (has right on) is a shortcut of the fully developed path from E72 Legal Object through P104 is subject to (applies to), E30 Right, P75 possesses (is possessed by) to E39 Actor.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object",
      label: {en: "right held by", cn: "有权限持有者", de: "Rechte stehen zu", el: "δικαίωμα κατέχεται από", fr: "droit détenu par", pt: "são direitos de ", ru: "право принадлежит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P105i_has_right_on,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "has right on", cn: "持有权限来管制", de: "hat Rechte an", el: "έχει δικαίωμα σε", fr: "détient un droit sur", pt: "possui direitos sobre", ru: "владеет правом на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E72_Legal_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P106_is_composed_of,
      comment: {en: "This property associates an instance of E90 Symbolic Object with a part of it that is by itself an instance of E90 Symbolic Object, such as fragments of texts or clippings from an image.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      label: {en: "is composed of", cn: "有组成元素", de: " ist zusammengesetzt aus", el: "αποτελείται από", fr: "est composé de", pt: "é composto de", ru: "составлен из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P106i_forms_part_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      label: {en: "forms part of", cn: "组成了", de: "bildet Teil von", el: "αποτελεί μέρος του/της", fr: "fait partie de", pt: "faz parte de", ru: "формирует часть"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P107_has_current_or_former_member,
      comment: {en: "This property relates an E39 Actor to the E74 Group of which that E39 Actor is a member.\nGroups, Legal Bodies and Persons, may all be members of Groups. A Group necessarily consists of more than one member.\nThis property is a shortcut of the more fully developed path from E74 Group through P144 joined with (gained member by), E85 Joining, P143 joined (was joined by) to E39 Actor\nThe property P107.1 kind of member can be used to specify the type of membership or the role the member has in the group. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "has current or former member", cn: "有现任或前任成员", de: "hat derzeitiges oder früheres Mitglied", el: "έχει ή είχε μέλος", fr: "a pour membre actuel ou ancien", pt: "tem ou teve membro", ru: "имеет действующего или бывшего члена"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P107i_is_current_or_former_member_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is current or former member of", cn: "目前或曾经加入群组", de: "ist derzeitiges oder früheres Mitglied von", el: "είναι ή ήταν μέλος του/της", fr: "est actuel ou ancien membre de", pt: "é ou foi membro de", ru: "является действующим или бывшим членом"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P108_has_produced,
      comment: {en: "This property identifies the E24 Physical Man-Made Thing that came into existence as a result of an E12 Production.\nThe identity of an instance of E24 Physical Man-Made Thing is not defined by its matter, but by its existence as a subject of documentation. An E12 Production can result in the creation of multiple instances of E24 Physical Man-Made Thing.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E12_Production",
      label: {en: "has produced", cn: "有产出物", de: "hat hergestellt", el: "παρήγαγε", fr: "a produit", pt: "produziu", ru: "произвел"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P31_has_modified", "http://www.cidoc-crm.org/cidoc-crm/P92_brought_into_existence"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P108i_was_produced_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "was produced by", cn: "被制作於", de: "wurde hergestellt durch", el: "παρήχθη από", fr: "a été produit par", pt: "foi produzido por", ru: "был произведен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E12_Production",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P31i_was_modified_by", "http://www.cidoc-crm.org/cidoc-crm/P92i_was_brought_into_existence_by"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P109_has_current_or_former_curator,
      comment: {en: "This property identifies the E39 Actor or Actors who assume or have assumed overall curatorial responsibility for an E78 Collection.\nThis property is effectively a short-cut. It does not allow a history of curation to be recorded. This would require use of an Event assigning responsibility for a Collection to a curator.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E78_Collection",
      label: {en: "has current or former curator", cn: "有现任或前任典藏管理员", de: "hat derzeitigen oder früheren Kurator", el: "έχει ή είχε επιμελητή", fr: "a pour conservateur actuel ou ancien", pt: "tem ou teve curador", ru: "имеет действующего или бывшего хранителя"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P49_has_former_or_current_keeper",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P109i_is_current_or_former_curator_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is current or former curator of", cn: "目前或曾经典藏管理", de: "ist derzeitiger oder früherer Kurator von", el: "είναι ή ήταν επιμελητής του/της", fr: "est ou a été le conservateur de", pt: "é ou foi curador de", ru: "является действующим или бывшим хранителем"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E78_Collection",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P49i_is_former_or_current_keeper_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P10_falls_within,
      comment: {en: "This property describes an instance of E4 Period, which falls within the E53 Place and E52 Time-Span of another. \nThe difference with P9 consists of (forms part of) is subtle. Unlike P9 consists of (forms part of), P10 falls within (contains) does not imply any logical connection between the two periods and it may refer to a period of a completely different type.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "falls within", cn: "发生时间涵盖於", de: "fällt in", el: "εμπίπτει", fr: "s’insère dans le cours de", pt: "está contido em", ru: "находится в пределах"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P10i_contains,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "contains", cn: "时间上涵盖", de: "enthält", el: "περιλαμβάνει", fr: "contient", pt: "contém", ru: "содержит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P110_augmented,
      comment: {en: "This property identifies the E24 Physical Man-Made Thing that is added to (augmented) in an E79 Part Addition.\nAlthough a Part Addition event normally concerns only one item of Physical Man-Made Thing, it is possible to imagine circumstances under which more than one item might be added to (augmented). For example, the artist Jackson Pollock trailing paint onto multiple canvasses.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E79_Part_Addition",
      label: {en: "augmented", cn: "扩增了", de: "erweiterte", el: "επαύξησε", fr: "a augmenté", pt: "aumentou", ru: "увеличил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P31_has_modified",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P110i_was_augmented_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "was augmented by", cn: "被扩增於", de: "wurde erweitert durch", el: "επαυξήθηκε από", fr: "a été augmenté par", pt: "foi aumentada por", ru: "был увеличен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E79_Part_Addition",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P31i_was_modified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P111_added,
      comment: {en: "This property identifies the E18 Physical Thing that is added during an E79 Part Addition activity\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E79_Part_Addition",
      label: {en: "added", cn: "附加上部件", de: "fügte hinzu", el: "προσέθεσε", fr: "a ajouté", pt: "adicionou", ru: "добавил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of", "http://www.cidoc-crm.org/cidoc-crm/P16_used_specific_object"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P111i_was_added_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "was added by", cn: "被附加於", de: "wurde hinzugefügt durch", el: "προστέθηκε από", fr: "a été ajouté par", pt: "foi adicionado por", ru: "был добавлен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E79_Part_Addition",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at", "http://www.cidoc-crm.org/cidoc-crm/P16i_was_used_for"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P112_diminished,
      comment: {en: "This property identifies the E24 Physical Man-Made Thing that was diminished by E80 Part Removal.\nAlthough a Part removal activity normally concerns only one item of Physical Man-Made Thing, it is possible to imagine circumstances under which more than one item might be diminished by a single Part Removal activity. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E80_Part_Removal",
      label: {en: "diminished", cn: "缩减了", de: "verminderte", el: "εξάλειψε", fr: "a diminué", pt: "diminuiu", ru: "уменьшил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P31_has_modified",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P112i_was_diminished_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "was diminished by", cn: "被缩减於", de: "wurde vermindert durch", el: "εξαλείφθηκε από", fr: "a été diminué par", pt: "foi diminuído por", ru: "был уменьшен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E80_Part_Removal",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P31i_was_modified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P113_removed,
      comment: {en: "This property identifies the E18 Physical Thing that is removed during an E80 Part Removal activity."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E80_Part_Removal",
      label: {en: "removed", cn: "移除了", de: "entfernte", el: "αφαίρεσε", fr: "a enlevé", pt: "removeu", ru: "удален"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P113i_was_removed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "was removed by", cn: "被移除於", de: "wurde entfernt durch", el: "αφαιρέθηκε από", fr: "a été enlevée par", pt: "foi removido por", ru: "был удален посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E80_Part_Removal",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P114_is_equal_in_time_to,
      comment: {en: "This symmetric property allows the instances of E2 Temporal Entity with the same E52 Time-Span to be equated. \nThis property is only necessary if the time span is unknown (otherwise the equivalence can be calculated).\nThis property is the same as the \"equal\" relationship of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "is equal in time to", cn: "时段相同於", de: "zeitgleich zu", el: "συμπίπτει χρονικά με", fr: "est temporellement égale à", pt: "é temporalmente igual a", ru: "равен по времени"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P115_finishes,
      comment: {en: "This property allows the ending point for a E2 Temporal Entity to be situated by reference to the ending point of another temporal entity of longer duration.  \nThis property is only necessary if the time span is unknown (otherwise the relationship can be calculated). This property is the same as the \"finishes / finished-by\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "finishes", cn: "结束了", de: "beendet", el: "περατώνει", fr: "termine", pt: "finaliza", ru: "заканчивает"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P115i_is_finished_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "is finished by", cn: "被结束于", de: "wurde beendet mit", el: "περατώνεται με", fr: "est terminée par", pt: "é finalizada por", ru: "заканчивается"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P116_starts,
      comment: {en: "This property allows the starting point for a E2 Temporal Entity to be situated by reference to the starting point of another temporal entity of longer duration.  \nThis property is only necessary if the time span is unknown (otherwise the relationship can be calculated). This property is the same as the \"starts / started-by\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "starts", cn: "开始了", de: "beginnt", el: "αρχίζει", fr: "commence", pt: "inicia", ru: "начинает"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P116i_is_started_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "is started by", cn: "被开始于", de: "wurde begonnen mit", el: "αρχίζει με", fr: "est commencée par", pt: "é iniciada por", ru: "начинается"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P117_occurs_during,
      comment: {en: "This property allows the entire E52 Time-Span of an E2 Temporal Entity to be situated within the Time-Span of another temporal entity that starts before and ends after the included temporal entity.   \nThis property is only necessary if the time span is unknown (otherwise the relationship can be calculated). This property is the same as the \"during / includes\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "occurs during", cn: "时段被涵盖於", de: "fällt in", el: "εμφανίζεται κατά τη διάρκεια", fr: "a lieu pendant", pt: "ocorre durante", ru: "появляется во течение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P117i_includes,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "includes", cn: "时段涵盖了", de: "beinhaltet", el: "περιλαμβάνει", fr: "comporte", pt: "inclui", ru: "включает"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P118_overlaps_in_time_with,
      comment: {en: "This property identifies an overlap between the instances of E52 Time-Span of two instances of E2 Temporal Entity. \nIt implies a temporal order between the two entities: if A overlaps in time B, then A must start before B, and B must end after A. This property is only necessary if the relevant time spans are unknown (otherwise the relationship can be calculated).\nThis property is the same as the \"overlaps / overlapped-by\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "overlaps in time with", cn: "时段重叠了", de: "überlappt zeitlich mit", el: "προηγείται μερικώς επικαλύπτοντας", fr: "est partiellement recouverte dans le temps par", pt: "sobrepõe temporalmente", ru: "перекрывает во времени"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P118i_is_overlapped_in_time_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "is overlapped in time by", cn: "时段被重叠于", de: "wird zeitlich überlappt von", el: "έπεται μερικώς επικαλυπτόμενο", fr: "recouvre partiellement dans le temps", pt: "é sobreposto temporalmente por", ru: "перекрывается во времени"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P119_meets_in_time_with,
      comment: {en: "This property indicates that one E2 Temporal Entity immediately follows another. \nIt implies a particular order between the two entities: if A meets in time with B, then A must precede B. This property is only necessary if the relevant time spans are unknown (otherwise the relationship can be calculated). \nThis property is the same as the \"meets / met-by\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "meets in time with", cn: "紧接续了", de: "trifft zeitlich auf", el: "προηγείται", fr: "est temporellement contiguë avec", pt: "é temporalmente contíguo com", ru: "следует во времени за"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P119i_is_met_in_time_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "is met in time by", cn: "紧接续於", de: "wird zeitlich getroffen von", el: "έπεται", fr: "est immédiatement précédé par", pt: "é imediatamente precedido por", ru: "предшествует во времени"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P11_had_participant,
      comment: {en: "This property describes the active or passive participation of instances of E39 Actors in an E5 Event. \nIt connects the life-line of the related E39 Actor with the E53 Place and E50 Date of the event. The property implies that the Actor was involved in the event but does not imply any causal relationship. The subject of a portrait can be said to have participated in the creation of the portrait.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      label: {en: "had participant", cn: "有参与者", de: "hatte Teilnehmer", el: "είχε συμμέτοχο", fr: "a eu pour participant", pt: "tem participante", ru: "имел участника"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P11i_participated_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "participated in", cn: "参与了", de: "nahm Teil an", el: "συμμετείχε σε", fr: "a participé à", pt: "participa em", ru: "участвовал в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P120_occurs_before,
      comment: {en: "This property identifies the relative chronological sequence of two temporal entities. \nIt implies that a temporal gap exists between the end of A and the start of B. This property is only necessary if the relevant time spans are unknown (otherwise the relationship can be calculated).\nThis property is the same as the \"before / after\" relationships of Allen’s temporal logic (Allen, 1983, pp. 832-843).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "occurs before", cn: "发生时段先於", de: "kommt vor", el: "εμφανίζεται πριν", fr: "a lieu avant", pt: "ocorre antes", ru: "появляется до"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P120i_occurs_after,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "occurs after", cn: "发生时段后於", de: "kommt nach", el: "εμφανίζεται μετά", fr: "a lieu après", pt: "ocorre depois", ru: "появляется после"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P121_overlaps_with,
      comment: {en: "This symmetric property allows the instances of E53 Place with overlapping geometric extents to be associated with each other. \nIt does not specify anything about the shared area. This property is purely spatial, in contrast to Allen operators, which are purely temporal.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "overlaps with", cn: "空间重叠于", de: "überlappt mit", el: "επικαλύπτεται με", fr: "chevauche", pt: "sobrepõe com", ru: "пересекается с"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P122_borders_with,
      comment: {en: "This symmetric property allows the instances of E53 Place which share common borders to be related as such. \nThis property is purely spatial, in contrast to Allen operators, which are purely temporal.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "borders with", cn: "接壤于", de: "grenzt an", el: "συνορεύει με", fr: "jouxte", pt: "fronteira com", ru: "граничит с"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P123_resulted_in,
      comment: {en: "This property identifies the E77 Persistent Item or items that are the result of an E81 Transformation. \nNew items replace the transformed item or items, which cease to exist as units of documentation. The physical continuity between the old and the new is expressed by the link to the common Transformation.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E81_Transformation",
      label: {en: "resulted in", cn: "转变出", de: "ergab", el: "είχε ως αποτέλεσμα", fr: "a eu pour résultat", pt: "resultou em", ru: "повлек появление"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92_brought_into_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P123i_resulted_from,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      label: {en: "resulted from", cn: "肇因於", de: "ergab sich aus", el: "προέκυψε από", fr: "est le résultat de", pt: "resultado de", ru: "был результатом"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E81_Transformation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92i_was_brought_into_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P124_transformed,
      comment: {en: "This property identifies the E77 Persistent Item or items that cease to exist due to a E81 Transformation. \nIt is replaced by the result of the Transformation, which becomes a new unit of documentation. The continuity between both items, the new and the old, is expressed by the link to the common Transformation.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E81_Transformation",
      label: {en: "transformed", cn: "转变了", de: "wandelte um", el: "μετέτρεψε", fr: "a transformé", pt: "transformou", ru: "трансформировал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93_took_out_of_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P124i_was_transformed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      label: {en: "was transformed by", cn: "被转变於", de: "wurde umgewandelt durch", el: "μετατράπηκε από", fr: "a été transformé par", pt: "foi transformado por", ru: "был трансформирован посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E81_Transformation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93i_was_taken_out_of_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P125_used_object_of_type,
      comment: {en: "This property defines the kind of objects used in an E7 Activity, when the specific instance is either unknown or not of interest, such as use of \"a hammer\".\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "used object of type", cn: "有使用物件类型", de: "benutzte Objekt des Typus", el: "χρησιμοποίησε αντικείμενο τύπου", fr: "a employé un objet du type", pt: "usou objeto do tipo", ru: "использовал объект типа"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P125i_was_type_of_object_used_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was type of object used in", cn: "被使用於", de: "Objekt des Typus ... wurde benutzt in", el: "ήταν o τύπος αντικείμενου που χρησιμοποιήθηκε σε", fr: "était le type d’objet employé par", pt: "foi tipo do objeto usado em", ru: "был типом объекта использованного в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P126_employed,
      comment: {en: "This property identifies E57 Material employed in an E11 Modification.\nThe E57 Material used during the E11 Modification does not necessarily become incorporated into the E24 Physical Man-Made Thing that forms the subject of the E11 Modification.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      label: {en: "employed", cn: "采用了材料", de: "verwendete", el: "χρησιμοποίησε", fr: "a employé", pt: "empregou", ru: "использовал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P126i_was_employed_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      label: {en: "was employed in", cn: "被使用於", de: "wurde verwendet bei", el: "χρησιμοποιήθηκε σε", fr: "a été employé dans", pt: "foi empregado em", ru: "использовался в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P127_has_broader_term,
      comment: {en: "This property identifies a super-Type to which an E55 Type is related. \n\t\tIt allows Types to be organised into hierarchies. This is the sense of \"broader term generic  \t\t(BTG)\" as defined in ISO 2788\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "has broader term", cn: "有广义术语", de: "hat den Oberbegriff", el: "έχει ευρύτερο όρο", fr: "a pour terme générique", pt: "tem termo genérico", ru: "имеет вышестоящий термин"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P127i_has_narrower_term,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "has narrower term", cn: "有狭义术语", de: "hat den Unterbegriff", el: "έχει στενότερο όρο", fr: "a pour terme spécifique", pt: "tem termo específico"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P128_carries,
      comment: {en: "This property identifies an E90 Symbolic Object carried by an instance of E18 Physical Thing.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "carries", cn: "承载信息", de: "trägt", el: "φέρει", fr: "est le support de", pt: "é o suporte de", ru: "несет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P130_shows_features_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P128i_is_carried_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      label: {en: "is carried by", cn: "被承载于", de: "wird getragen von", el: "φέρεται από", fr: "a pour support", pt: "é suportado por", ru: "переносится посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P130i_features_are_also_found_on",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P129_is_about,
      comment: {en: "This property documents that an E89 Propositional Object has as subject an instance of E1 CRM Entity. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "is about", cn: "陈述关於", de: "handelt über", el: "έχει ως θέμα", fr: "est au sujet de", pt: "é sobre", ru: "касается"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67_refers_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P129i_is_subject_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is subject of", cn: "被陈述於", de: "wird behandelt in", el: "είναι θέμα  του/της", fr: "est le sujet de", pt: "é assunto de", ru: "является предметом для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67i_is_referred_to_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P12_occurred_in_the_presence_of,
      comment: {en: "This property describes the active or passive presence of an E77 Persistent Item in an E5 Event without implying any specific role. \nIt connects the history of a thing with the E53 Place and E50 Date of an event. For example, an object may be the desk, now in a museum on which a treaty was signed. The presence of an immaterial thing implies the presence of at least one of its carriers.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      label: {en: "occurred in the presence of", cn: "发生现场存在", de: "fand statt im Beisein von", el: "συνέβη παρουσία του/της", fr: "est arrivé en présence de", pt: "ocorreu na presença de", ru: "появился в присутствии"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P12i_was_present_at,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      label: {en: "was present at", cn: "当时在场於", de: "war anwesend bei", el: "ήταν παρών/παρούσα/παρόν σε", fr: "était présent à", pt: "estava presente no", ru: "присутствовал при"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P130_shows_features_of,
      comment: {en: "This property generalises the notions of  \"copy of\" and \"similar to\" into a dynamic, asymmetric relationship, where the domain expresses the derivative, if such a direction can be established.\nOtherwise, the relationship is symmetric. It is a short-cut of P15 was influenced by (influenced) in a creation or production, if such a reason for the similarity can be verified. Moreover it expresses similarity in cases that can be stated between two objects only, without historical knowledge about its reasons.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      label: {en: "shows features of", cn: "外观特征原出现於", de: "zeigt Merkmale von", el: "παρουσιάζει χαρακτηριστικά του/της", fr: "présente des caractéristiques de", pt: "apresenta características de", ru: "демонстрирует признаки"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P73i_is_translation_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P130i_features_are_also_found_on,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      label: {en: "features are also found on", cn: "外观特征被复制於", de: "Merkmale auch auf", el: "χαρακτηριστικά του βρίσκονται επίσης σε", fr: "a des caractéristiques se trouvant aussi sur", pt: "características são também encontradas em", ru: "признаки также найдены на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P131_is_identified_by,
      comment: {en: "This property identifies a name used specifically to identify an E39 Actor. \nThis property is a specialisation of P1 is identified by (identifies) is identified by.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is identified by", cn: "有称号", de: "wird identifziert durch", el: "αναγνωρίζεται ως", fr: "est identifié par", pt: "é identificado por", ru: "идентифицируется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E82_Actor_Appellation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P131i_identifies,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E82_Actor_Appellation",
      label: {en: "identifies", cn: "被用来识别", de: "identifiziert", el: "είναι αναγνωριστικό", fr: "identifie", pt: "identifica", ru: "идентифицирует"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P132_overlaps_with,
      comment: {en: "This symmetric property allows instances of E4 Period that overlap both temporally and spatially to be related, i,e. they share some spatio-temporal extent.\nThis property does not imply any ordering or sequence between the two periods, either spatial or temporal.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "overlaps with", cn: "时空重叠于", de: "überlappt mit", el: "επικαλύπτεται με", fr: "chevauche", pt: "sobrepõe", ru: "пересекается с"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P133_is_separated_from,
      comment: {en: "This symmetric property allows instances of E4 Period that do not overlap both temporally and spatially, to be related i,e. they do not share any spatio-temporal extent.\nThis property does not imply any ordering or sequence between the two periods either spatial or temporal.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "is separated from", cn: "时空不重叠于", de: "getrennt von", el: "διαχωρίζεται από", fr: "est séparée de", pt: "é separado de", ru: "отделен от"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P134_continued,
      comment: {en: "This property associates two instances of E7 Activity, where the domain is considered as an intentional continuation of the range. A continuation of an activity may happen when the continued activity is still ongoing or after the continued activity has completely ended. The continuing activity may have started already before it decided to continue the other one. Continuation implies a coherence of intentions and outcomes of the involved activities.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "continued", cn: "延续了", de: "setzte sich fort in", el: "συνέχισε", fr: "est la suite de", pt: "continuou", ru: "продолжил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15_was_influenced_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P134i_was_continued_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "was continued by", cn: "有延续活动", de: "wurde fortgesetzt durch", el: "συνεχίστηκε από", fr: "a été continuée par", pt: "foi continuada por", ru: "был продолжен"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15i_influenced",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P135_created_type,
      comment: {en: "This property identifies the E55 Type, which is created in an E83Type Creation activity."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E83_Type_Creation",
      label: {en: "created type", cn: "创造了类型", de: "erschuf Typus", el: "δημιούργησε τύπο", fr: "a créé le type", pt: "criou tipo", ru: "создал тип"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P94_has_created",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P135i_was_created_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was created by", cn: "被创造於", de: "wurde geschaffen durch", el: "δημιουργήθηκε από", fr: "a été créé par", pt: "foi criado por", ru: "был создан посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E83_Type_Creation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P94i_was_created_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P136_was_based_on,
      comment: {en: "This property identifies one or more items that were used as evidence to declare a new E55 Type.\nThe examination of these items is often the only objective way to understand the precise characteristics of a new Type. Such items should be deposited in a museum or similar institution for that reason. The taxonomic role renders the specific relationship of each item to the Type, such as \"holotype\" or \"original element\".\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E83_Type_Creation",
      label: {en: "was based on", cn: "根据了", de: "stützte sich auf", el: "βασίστηκε σε", fr: "s’est fondée sur", pt: "foi baseado em", ru: "был основан на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15_was_influenced_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P136i_supported_type_creation,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "supported type creation", cn: "提供證據给类型创造", de: "belegte", el: "υποστήριξε τη δημιουργία τύπου", fr: "a justifié la création de type", pt: "suportou a criação de tipo", ru: "поддержал создание типа"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E83_Type_Creation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15i_influenced",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P137_exemplifies,
      comment: {en: "This property allows an item to be declared as a particular example of an E55 Type or taxon\n\tThe P137.1 in the taxonomic role property of P137 exemplifies (is exemplified by) allows differentiation of taxonomic roles. The taxonomic role renders the specific relationship of this example to the Type, such as \"prototypical\", \"archetypical\", \"lectotype\", etc. The taxonomic role \"lectotype\" is not associated with the Type Creation (E83) itself, but selected in a later phase.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "exemplifies", cn: "例示了", de: "erläutert", el: "δειγματίζει", fr: "exemplifie", pt: "é exemplificado por", ru: "поясняет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P2_has_type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P137i_is_exemplified_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "is exemplified by", cn: "有例示", de: "erläutert durch Beispiel", el: "δειγματίζεται από", fr: "est exemplifié par", pt: "exemplifica", ru: "поясняется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P2i_is_type_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P138_represents,
      comment: {en: "This property establishes the relationship between an E36 Visual Item and the entity that it visually represents.\nAny entity may be represented visually. This property is part of the fully developed path from E24 Physical Man-Made Thing through P65 shows visual item (is shown by), E36 Visual Item, P138 represents (has representation) to E1 CRM Entity, which is shortcut by P62depicts (is depicted by). P138.1 mode of representation allows the nature of the representation to be refined.\nThis property is also used for the relationship between an original and a digitisation of the original by the use of techniques such as digital photography, flatbed or infrared scanning. Digitisation is here seen as a process with a mechanical, causal component rendering the spatial distribution of structural and optical properties of the original and does not necessarily include any visual similarity identifiable by human observation.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      label: {en: "represents", cn: "描绘了", de: "stellt dar", el: "παριστάνει", fr: "représente", pt: "representa", ru: "представляет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67_refers_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P138i_has_representation,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "has representation", cn: "有图像描绘", de: "wird dargestellt durch", el: "παριστάνεται από", fr: "est représentée par", pt: "tem representação", ru: "имеет представление"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67i_is_referred_to_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P139_has_alternative_form,
      comment: {en: "This property establishes a relationship of equivalence between two instances of E41 Appellation independent from any item identified by them. It is a dynamic asymmetric relationship, where the range expresses the derivative, if such a direction can be established. Otherwise, the relationship is symmetric. The relationship is not transitive.\nThe equivalence applies to all cases of use of an instance of E41 Appellation. Multiple names assigned to an object, which are not equivalent for all things identified with a specific instance of E41 Appellation, should be modelled as repeated values of P1 is identified by (identifies). \nP139.1 has type allows the type of derivation, such as “transliteration from Latin 1 to ASCII” be refined..\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      label: {en: "has alternative form", cn: "有替代称号", de: "hat alternative Form", el: "έχει εναλλακτική μορφή", fr: "a pour autre forme", pt: "tem forma alternativa", ru: "имеет альтернативную форму"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P13_destroyed,
      comment: {en: "This property allows specific instances of E18 Physical Thing that have been destroyed to be related to a destruction event. \nDestruction implies the end of an item’s life as a subject of cultural documentation – the physical matter of which the item was composed may in fact continue to exist. A destruction event may be contiguous with a Production that brings into existence a derived object composed partly of matter from the destroyed object.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E6_Destruction",
      label: {en: "destroyed", cn: "毁灭了", de: "zerstörte", el: "κατέστρεψε", fr: "a détruit", pt: "destruiu", ru: "уничтожил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93_took_out_of_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P13i_was_destroyed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "was destroyed by", cn: "被毁灭於", de: "wurde zerstört durch", el: "καταστράφηκε από", fr: "a été détruite par", pt: "foi destruído por", ru: "был уничтожен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E6_Destruction",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P93i_was_taken_out_of_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P140_assigned_attribute_to,
      comment: {en: "This property indicates the item to which an attribute or relation is assigned. "},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      label: {en: "assigned attribute to", cn: "指定属性给", de: "wies Merkmal zu", el: "απέδωσε ιδιότητα σε", fr: "a affecté un attribut à", pt: "atribuiu atributo para", ru: "присвоил атрибут для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P140i_was_attributed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "was attributed by", cn: "被指定属性於", de: "bekam Merkmal zugewiesen durch", el: "χαρακτηρίστηκε από", fr: "a reçu un attribut par", pt: "foi atribuído por", ru: "получил атрибут посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P141_assigned,
      comment: {en: "This property indicates the attribute that was assigned or the item that was related to the item denoted by a property P140 assigned attribute to in an Attribute assignment action.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      label: {en: "assigned", cn: "指定了属性值", de: "wies zu", el: "απέδωσε", fr: "a attribué", pt: "atribuiu", ru: "присвоил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P141i_was_assigned_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "was assigned by", cn: "被指定了属性值於", de: "wurde zugewiesen durch", el: "αποδόθηκε από", fr: "a été attribué par", pt: "foi atribuído por", ru: "был присвоен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E13_Attribute_Assignment",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P142_used_constituent,
      comment: {en: "This property associates the event of assigning an instance of E42 Identifier to an entity, with  the instances of E41 Appellation that were used as elements of the identifier.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      label: {en: "used constituent", cn: "使用称号构成部分", de: "benutzte Bestandteil"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P16_used_specific_object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P142i_was_used_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      label: {en: "was used in", cn: "被用来构成称号於", de: "wurde benutzt in"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P16i_was_used_for",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P143_joined,
      comment: {en: "This property identifies the instance of E39 Actor that becomes member of a E74 Group in an E85 Joining.\n \tJoining events allow for describing people becoming members of a group with a more detailed path from E74 Group through P144 joined with (gained member by), E85 Joining, P143 joined (was joined by) to E39 Actor, compared to the shortcut offered by P107 has current or former member (is current or former member of).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E85_Joining",
      label: {en: "joined", cn: "加入了成员", de: "verband"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P143i_was_joined_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "was joined by", cn: "被加入为成员於", de: "wurde verbunden durch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E85_Joining",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P144_joined_with,
      comment: {en: "This property identifies the instance of E74 Group of which an instance of E39 Actor becomes a member through an instance of E85 Joining.\nAlthough a Joining activity normally concerns only one instance of E74 Group, it is possible to imagine circumstances under which becoming member of one Group implies becoming member of another Group as well. \nJoining events allow for describing people becoming members of a group with a more detailed path from E74 Group through P144 joined with (gained member by), E85 Joining, P143 joined (was joined by) to E39 Actor, compared to the shortcut offered by P107 has current or former member (is current or former member of).\nThe property P144.1 kind of member can be used to specify the type of membership or the role the member has in the group. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E85_Joining",
      label: {en: "joined with", cn: "加入成员到", de: "verband mit"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P144i_gained_member_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "gained member by", cn: "获得成员於", de: "erwarb Mitglied durch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E85_Joining",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P145_separated,
      comment: {en: "This property identifies the instance of E39 Actor that leaves an instance of E74 Group through an instance of E86 Leaving."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E86_Leaving",
      label: {en: "separated", cn: "分离了成员", de: "entließ"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P145i_left_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "left by", cn: "脱离群组於", de: "wurde entlassen durch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E86_Leaving",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P146_separated_from,
      comment: {en: "This property identifies the instance of E74 Group an instance of E39 Actor leaves through an instance of E86 Leaving.\nAlthough a Leaving activity normally concerns only one instance of E74 Group, it is possible to imagine circumstances under which leaving one E74 Group implies leaving another E74 Group as well.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E86_Leaving",
      label: {en: "separated from", cn: "脱离了群组", de: "entließ von"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P146i_lost_member_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "lost member by", cn: "失去成员於", de: "verlor Mitglied durch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E86_Leaving",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P147_curated,
      comment: {en: "This property associates an instance of E87 Curation Activity with the instance of E78 Collection that is subject of that  curation activity.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E87_Curation_Activity",
      label: {en: "curated", cn: "典藏管理了", de: "betreute kuratorisch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E78_Collection",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P147i_was_curated_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E78_Collection",
      label: {en: "was curated by", cn: "被典藏管理於", de: "wurde kuratorisch betreut durch"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E87_Curation_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P148_has_component,
      comment: {en: "This property associates an instance of E89 Propositional Object with a structural part of it that is by itself an instance of E89 Propositional Object."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "has component", cn: "有组件", de: "hat Bestandteil"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P148i_is_component_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "is component of", cn: "被用来组成", de: "ist Bestandteil von"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P149_is_identified_by,
      comment: {en: "This property identifies an instance of E28 Conceptual Object using an instance of E75 Conceptual Object Appellation."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      label: {en: "is identified by"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E75_Conceptual_Object_Appellation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P149i_identifies,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E75_Conceptual_Object_Appellation",
      label: {en: "identifies"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P14_carried_out_by,
      comment: {en: "This property describes the active participation of an E39 Actor in an E7 Activity. \nIt implies causal or legal responsibility. The P14.1 in the role of property of the property allows the nature of an Actor’s participation to be specified.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "carried out by", cn: "有执行者", de: "wurde ausgeführt von", el: "πραγματοποιήθηκε από", fr: "réalisée par", pt: "realizada por", ru: "выполнялся"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P14i_performed,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "performed", cn: "执行了", de: "führte aus", el: "πραγματοποίησε", fr: "a exécuté", pt: "executou", ru: "выполнял"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P150_defines_typical_parts_of,
      comment: {en: "The property \"broaderPartitive\" associates an instance of E55 Type “A” with an instance of E55 Type “B”, when items of type “A” typically form part of items of type “B”, such as “car motors” and “cars”.\nIt allows Types to be organised into hierarchies. This is the sense of \"broader term partitive (BTP)\" as defined in ISO 2788 and “broaderPartitive” in SKOS.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "defines typical parts of"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P150i_defines_typical_wholes_for,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "defines typical wholes for"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P151_was_formed_from,
      comment: {en: "This property associates an instance of E66 Formation with an instance of E74 Group from which the new group was formed preserving a sense of continuity such as in mission, membership or tradition.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E66_Formation",
      label: {en: "was formed from"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P151i_participated_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "participated in"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E66_Formation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P152_has_parent,
      comment: {en: "This property associates an instance of E21 Person with another instance of E21 Person who plays the role of the first instance’s parent, regardless of whether the relationship is biological parenthood, assumed or pretended biological parenthood or an equivalent legal status of rights and obligations obtained by a social or legal act. \n\tThis property is, among others, a shortcut of the fully developed paths from ‘E21Person’ through ‘P98i was born’, ‘E67 Birth’, ‘P96 by mother’ to ‘E21 Person’, and from ‘E21Person’ through ‘P98i was born’, ‘E67 Birth’, ‘P97 from father’ to ‘E21 Person’.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "has parent"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P152i_is_parent_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "is parent of"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P153_assigned_co-reference_to",
      comment: {en: "This property connects an E91 Co-Reference Assignment to one of the propositional objects co-referring to the co-reference target\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      label: {en: "assigned co-reference to"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140_assigned_attribute_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P153i_was_regarded_to_co-refer_by",
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "was regarded to co-refer by"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140i_was_attributed_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P154_assigned_non_co-reference_to",
      comment: {en: "This property connects an E91 Co-Reference Assignment to one of the propositional objects not co-referring to the co-reference target\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      label: {en: "assigned non co-reference to"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140_assigned_attribute_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P154i_was_regarded_not_to_co-refer_by",
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "was regarded not to co-refer by"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140i_was_attributed_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P155_has_co-reference_target",
      comment: {en: "This property connects an E91 Co-Reference Assignment to the target of the references that are regarded as co-referring.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      label: {en: "has co-reference target"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P155i_is_co-reference_target_of",
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is co-reference target of"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E91_Co-Reference_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P156_occupies,
      comment: {en: "This property describes the maximal real volume in space that an instance of E18 Physical Thing has occupied during its lifetime with respect to a reference space relative to which the thing is at rest. In other words, it is the volume that contains all the points which the thing has covered at some time during its existence. In the case of an E26 Physical Feature the default reference space is the one in which the object that bears the feature or at least the surrounding matter of the feature is at rest. In this case there is a 1:1 relation of E26 Feature and E53 Place. For simplicity of implementation multiple inheritance (E26 Feature IsA E53 Place) may be a practical approach.\nFor instances of E19 Physical Objects the default reference space is the one which is at rest to the object itself, i.e. which moves together with the object. We include in the occupied space the space filled by the matter of the physical thing and all its inner spaces. \nThis property is a shortcut of the fully developed path from ‘E18 Physical Thing’ through ‘P157 occupied’, ‘E92 Spacetime Volume’, ‘P159 has spatial projection’ to ‘E53 Place’. For some instances of E18 Physical Object the relative stability of form may not be sufficient to define a useful local reference space, for instance for an amoeba. In such cases the fully developed path to an external reference space and using a temporal validity component may be adequate to determine the place they have occupied.\nIn contrast to P156  occupies, the property P53 has former or current location identifies an instance of E53 Place at which a thing is or has been for some unspecified time span.  Further it does not constrain this reference space of the referred instance of P53 Place.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "occupies"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P157_is_at_rest_relative_to,
      comment: {en: "This property associates an instance of P53 Place with the instance of E18 Physical Thing that determines a reference space for this instance of P53 Place by being at rest with respect to this reference space. The relative stability of form of an E18 Physical Thing defines its default reference space. The reference space is not spatially limited to the referred thing. For example, a ship determines a reference space in terms of which other ships in its neighbourhood may be described. Larger constellations of matter, such as continental plates, may comprise many physical features that are at rest with them and define the same reference space.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is at rest relative to"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P59i_is_located_on_or_within",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P157i_provides_reference_space_for,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "provides reference space for"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P59_has_section",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P158_occupied,
      comment: {en: "This property associates an instance of E4 Period with the real that is phenomenal, 4 dimensional point set or volume in spacetime that it has occupied. The associated instance of E92 Spacetime Volume includes the trajectories of the participating physical things during their participation in the instance of E4 Period. This consists of the open spaces via which they have interacted and the spaces by which they had the potential to interact during that period or event.\nSuch interactions took place in the way defined by the type of the respective period or event, such as the air in a meeting room transferring the voices. Another example are the areas controlled by some military power. In case of phenomena spreading out over islands or other separated areas, the trajectories necessary for participants to travel between these areas are not regarded as part of the occupied spacetime volumes. Such instances of E4 Period occupy each a limited number of contiguous spacetime volumes, however there must not be a discontinuity in the total timespan covered by these spacetime volumes. The real spacetime volumes occupied by an instance of E4 Period must not be confused with declarations of spacetime approximating the real extent. In general, instances of E4 Period have fuzzy boundaries in spacetime.\nTherefore it cannot be verified, if two different instances of E4 Period occupy exactly the same spacetime volume. We therefore determine that a spacetime volume may only be occupied by one instance of E4 Period.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "occupied"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E92_Spacetime_Volume",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P159_occupied,
      comment: {en: "This property describes the real that is (phenomenal), 4 dimensional point sets or volumes in spacetime that the trajectory of an instance of E18 Physical Thing occupies in the course of its existence. We include in the occupied space the space filled by the matter of the physical thing and all its inner spaces. Physical things consisting of aggregations of physically unconnected objects, such as a set of chessmen, occupy a number of individually contiguous spacetime volumes equal to the number of unconnected objects that constitute them.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "occupied"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E92_Spacetime_Volume",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P15_was_influenced_by,
      comment: {en: "This is a high level property, which captures the relationship between an E7 Activity and anything that may have had some bearing upon it.\nThe property has more specific sub properties.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "was influenced by", cn: "有影响事物", de: "wurde beeinflußt durch", el: "επηρεάστηκε από", fr: "a été influencée par", pt: "foi influenciado por ", ru: "находился под влиянием"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P15i_influenced,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "influenced", cn: "影响了", de: "beeinflußte", el: "επηρέασε", fr: "a influencé", pt: "influenciou", ru: "оказал влияние на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P160_has_temporal_projection,
      comment: {en: "This property describes the temporal projection of an instance of an E92 Spacetime Volume. The property P4 has time-span is a shortcut of the more fully developed path from E4 Period through P158 occupied, E92 Spacetime Volume P160 has temporal projection to E52 Time Span.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E92_Spacetime_Volume",
      label: {en: "has temporal projection"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P161_has_spatial_projection,
      comment: {en: "This property associates an instance of a E92 Spacetime Volume with an instance of E53 Place that is the result of the spatial projection of the instance of a E92 Spacetime Volume on a reference space. In general there can be more than one useful reference space to describe the spatial projection of a spacetime volume, such as that of a battle ship versus that of the seafloor. Therefore the projection is not unique.\nThe property P7 took place at is a shortcut of the more fully developed path from E4 Period through P158 occupied, E92 Spacetime Volume P161 has spatial projection to E53 Place.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E92_Spacetime_Volume",
      label: {en: "has spatial projection"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P164_is_restricted_by,
      comment: {en: "This property relates an E93 Spacetime Snapshot with an arbitrary E52 Time-Span that restricts the extent of the former to a volume within these time limits.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E93_Spacetime_Snapshot",
      label: {en: "is restricted by"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P165_incorporates,
      comment: {en: "This property associates an instance of E73 Information Object with an instance of E90 Symbolic Object (or any of its subclasses) that was included in it. This property makes it possible to recognise the autonomous status of the incorporated signs, which were created in a distinct context, and can be incorporated in many distinct self-contained expressions, and to highlight the difference between structural and accidental whole-part relationships between conceptual entities. It accounts for many cultural facts that are quite frequent and significant: the inclusion of a poem in an anthology, the re-use of an operatic aria in a new opera, the use of a reproduction of a painting for a book cover or a CD booklet, the integration of textual quotations, the presence of lyrics in a song that sets those lyrics to music, the presence of the text of a play in a movie based on that play, etc.\n\t"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      label: {en: "incorporates"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P106_is_composed_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P165i_is_incorporated_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E90_Symbolic_Object",
      label: {en: "is incorporated in"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E73_Information_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P106i_forms_part_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P16_used_specific_object,
      comment: {en: "This property describes the use of material or immaterial things in a way essential to the performance or the outcome of an E7 Activity. \nThis property typically applies to tools, instruments, moulds, raw materials and items embedded in a product. It implies that the presence of the object in question was a necessary condition for the action. For example, the activity of writing this text required the use of a computer. An immaterial thing can be used if at least one of its carriers is present. For example, the software tools on a computer.\nAnother example is the use of a particular name by a particular group of people over some span to identify a thing, such as a settlement. In this case, the physical carriers of this name are at least the people understanding its use.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "used specific object", cn: "使用特定物", de: "benutzte das bestimmte Objekt", el: "χρησιμοποίησε αντικείμενο", fr: "a utilisé l'objet spécifique", pt: "usou objeto específico", ru: "использовал особый объект"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of", "http://www.cidoc-crm.org/cidoc-crm/P15_was_influenced_by"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P16i_was_used_for,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      label: {en: "was used for", cn: "被用於", de: "wurde benutzt für", el: "χρησιμοποιήθηκε για", fr: "a été utilisé pour", pt: "foi usado por", ru: "был использован для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at", "http://www.cidoc-crm.org/cidoc-crm/P15i_influenced"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P17_was_motivated_by,
      comment: {en: "This property describes an item or items that are regarded as a reason for carrying out the E7 Activity. \nFor example, the discovery of a large hoard of treasure may call for a celebration, an order from head quarters can start a military manoeuvre. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "was motivated by", cn: "有促动事物", de: "wurde angeregt durch", el: "είχε ως αφορμή", fr: "a été motivée par", pt: "foi motivado por", ru: "был обусловлен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15_was_influenced_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P17i_motivated,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "motivated", cn: "促动了", de: "regte an", el: "ήταν αφορμή", fr: "a motivé", pt: "motivou", ru: "обусловил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P15i_influenced",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P19_was_intended_use_of,
      comment: {en: "This property relates an E7 Activity with objects created specifically for use in the activity. \nThis is distinct from the intended use of an item in some general type of activity such as the book of common prayer which was intended for use in Church of England services (see P101 had as general use (was use of))."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "was intended use of", cn: "特别使用了", de: "war beabsichtigteter Gebrauch von ", el: "ήταν προορισμένη χρήση του", fr: "était l'utilisation prévue de", pt: "era prevista a utilização de", ru: "был предполагаемым использованием для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P19i_was_made_for,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E71_Man-Made_Thing",
      label: {en: "was made for", cn: "被制造来用於", de: "wurde hergestellt für", el: "έγινε για", fr: "a été fabriquée pour", pt: "foi feito para", ru: "был создан для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P1_is_identified_by,
      comment: {en: "This property describes the naming or identification of any real world item by a name or any other identifier. \nThis property is intended for identifiers in general use, which form part of the world the model intends to describe, and not merely for internal database identifiers which are specific to a technical system, unless these latter also have a more general use outside the technical context. This property includes in particular identification by mathematical expressions such as coordinate systems used for the identification of instances of E53 Place. The property does not reveal anything about when, where and by whom this identifier was used. A more detailed representation can be made using the fully developed (i.e. indirect) path through E15 Identifier Assignment.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is identified by", cn: "有识别称号", de: "wird bezeichnet als", el: "αναγνωρίζεται ως", fr: "est identifiée par", pt: "é identificado por", ru: "идентифицируется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P1i_identifies,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E41_Appellation",
      label: {en: "identifies", cn: "被用来识别", de: "bezeichnet", el: "είναι αναγνωριστικό", fr: "identifie", pt: "identifica", ru: "идентифицирует"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P20_had_specific_purpose,
      comment: {en: "This property identifies the relationship between a preparatory activity and the event it is intended to be preparation for.\nThis includes activities, orders and other organisational actions, taken in preparation for other activities or events. \nP20 had specific purpose (was purpose of) implies that an activity succeeded in achieving its aim. If it does not succeed, such as the setting of a trap that did not catch anything, one may document the unrealized intention using P21 had general purpose (was purpose of):E55 Type and/or  P33 used specific technique (was used by): E29 Design or Procedure."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "had specific purpose", cn: "有特定目地", de: "hatte den bestimmten Zweck", el: "είχε συγκεκριμένο σκοπό", fr: "avait pour but spécifique", pt: "tinha propósito específico", ru: "имел конкретную цель"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P20i_was_purpose_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E5_Event",
      label: {en: "was purpose of", cn: "之準備活動是", de: "war Zweck von", el: "ήταν σκοπός του/της", fr: "était le but de", pt: "era o propósito de", ru: "был целью для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P21_had_general_purpose,
      comment: {en: "This property describes an intentional relationship between an E7 Activity and some general goal or purpose. \nThis may involve activities intended as preparation for some type of activity or event. P21had general purpose (was purpose of) differs from P20 had specific purpose (was purpose of) in that no occurrence of an event is implied as the purpose. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "had general purpose", cn: "有通用目地", de: "hatte den allgemeinen Zweck", el: "είχε γενικό σκοπό", fr: "avait pour but général", pt: "tinha propósito geral", ru: "имел общую цель"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P21i_was_purpose_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was purpose of", cn: "可利用", de: "war Zweck von", el: "ήταν σκοπός του/της", fr: "était le but de", pt: "era o propósito de", ru: "был целью для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P22_transferred_title_to,
      comment: {en: "This property identifies the E39 Actor that acquires the legal ownership of an object as a result of an E8 Acquisition. \nThe property will typically describe an Actor purchasing or otherwise acquiring an object from another Actor. However, title may also be acquired, without any corresponding loss of title by another Actor, through legal fieldwork such as hunting, shooting or fishing.\nIn reality the title is either transferred to or from someone, or both.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      label: {en: "transferred title to", cn: "转交所有权给", de: "übertrug Besitztitel auf", el: "μετεβίβασε τον τίτλο σε", fr: "a fait passer le droit de propriété à", pt: "transferiu os direitos de propriedade para", ru: "передал право собственности"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14_carried_out_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P22i_acquired_title_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "acquired title through", cn: "获取所有权於", de: "erwarb Besitztitel durch", el: "απέκτησε τον τίτλο μέσω", fr: "a acquis le droit de propriété du fait de", pt: "adquiriu os direitos de propriedade por meio da", ru: "получил право собственности через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14i_performed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P23_transferred_title_from,
      comment: {en: "This property identifies the E39 Actor or Actors who relinquish legal ownership as the result of an E8 Acquisition.\nThe property will typically be used to describe a person donating or selling an object to a museum. In reality title is either transferred to or from someone, or both.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      label: {en: "transferred title from", cn: "原所有权者是", de: "übertrug Besitztitel von", el: "μετεβίβασε τον τίτλο από", fr: "a fait passer le droit de propriété de", pt: "transferiu os direitos de propriedade de", ru: "передал право собственности от"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14_carried_out_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P23i_surrendered_title_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "surrendered title through", cn: "交出所有权於", de: "trat Besitztitel ab in", el: "παρέδωσε τον τίτλο μέσω", fr: "a perdu le droit de propriété du fait de", pt: "perdeu os direitos de propriedade por meio da", ru: "право собственности отдано через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14i_performed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P24_transferred_title_of,
      comment: {en: "This property identifies the E18 Physical Thing or things involved in an E8 Acquisition. \nIn reality, an acquisition must refer to at least one transferred item.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      label: {en: "transferred title of", cn: "转移所有权的标的物是", de: "übertrug Besitz über", el: "μετεβίβασε τον τίτλο του/της", fr: "a fait passer le droit de propriété sur", pt: "transferiu os direitos de propriedade sobre o", ru: "передал право собственности на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P24i_changed_ownership_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "changed ownership through", cn: "转移了所有权於", de: "ging über in Besitz durch", el: "άλλαξε ιδιοκτησία μέσω", fr: "a changé de mains du fait de", pt: "mudou de proprietário por meio de", ru: "сменил владельца через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E8_Acquisition",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P25_moved,
      comment: {en: "This property identifies the E19 Physical Object that is moved during a move event. \nThe property implies the object’s passive participation. For example, Monet’s painting “Impression sunrise” was moved for the first Impressionist exhibition in 1874. \nIn reality, a move must concern at least one object.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      label: {en: "moved", cn: "移动了", de: "bewegte", el: "μετεκίνησε", fr: "a déplacé", pt: "locomoveu", ru: "переместил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P25i_moved_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      label: {en: "moved by", cn: "被移动於", de: "wurde bewegt durch", el: "μετακινήθηκε από", fr: "a été déplacé par", pt: "foi locomovido por", ru: "перемещен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P26_moved_to,
      comment: {en: "This property identifies the destination of a E9 Move. \nA move will be linked to a destination, such as the move of an artefact from storage to display. A move may be linked to many terminal instances of E53 Places. In this case the move describes a distribution of a set of objects. The area of the move includes the origin, route and destination.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      label: {en: "moved to", cn: "移入物件至", de: "bewegte bis zu", el: "μετακινήθηκε προς", fr: "a déplacé vers", pt: "locomoveu para", ru: "перемещен в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P7_took_place_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P26i_was_destination_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "was destination of", cn: "被作为移入地於", de: "war Zielort von", el: "ήταν προορισμός του/της", fr: "a été la destination de", pt: "era destinação de", ru: "был пунктом назначения для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P7i_witnessed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P27_moved_from,
      comment: {en: "This property identifies the starting E53 Place of an E9 Move.\nA move will be linked to an origin, such as the move of an artefact from storage to display. A move may be linked to many origins. In this case the move describes the picking up of a set of objects. The area of the move includes the origin, route and destination.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      label: {en: "moved from", cn: "有移出地", de: "bewegte weg von", el: "μετακινήθηκε από", fr: "a retiré de", pt: "locomoveu de", ru: "перемещен из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P7_took_place_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P27i_was_origin_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "was origin of", cn: "被作为移出地於", de: "war Ausgangsort von", el: "ήταν αφετηρία του/της", fr: "a été l'origine de", pt: "era origem de", ru: "был исходной точкой для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E9_Move",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P7i_witnessed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P28_custody_surrendered_by,
      comment: {en: "This property identifies the E39 Actor or Actors who surrender custody of an instance of E18 Physical Thing in an E10 Transfer of Custody activity. \nThe property will typically describe an Actor surrendering custody of an object when it is handed over to someone else’s care. On occasion, physical custody may be surrendered involuntarily – through accident, loss or theft.\nIn reality, custody is either transferred to someone or from someone, or both.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      label: {en: "custody surrendered by", cn: "有原保管人", de: "übergab Gewahrsam an", el: "μετεβίβασε κατοχή από", fr: "changement de détenteur au détriment de", pt: "custódia concedida por", ru: "опека отдана"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14_carried_out_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P28i_surrendered_custody_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "surrendered custody through", cn: "交出保管作业於", de: "wurde Gewahrsam übergeben durch", el: "παρέδωσε κατοχή μέσω", fr: "a cessé d’être détenteur à cause de", pt: "final da custódia por meio de", ru: "опека отдана через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14i_performed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P29_custody_received_by,
      comment: {en: "This property identifies the E39 Actor or Actors who receive custody of an instance of E18 Physical Thing in an E10 Transfer of Custody activity. \nThe property will typically describe Actors receiving custody of an object when it is handed over from another Actor’s care. On occasion, physical custody may be received involuntarily or illegally – through accident, unsolicited donation, or theft.\nIn reality, custody is either transferred to someone or from someone, or both.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      label: {en: "custody received by", cn: "移转保管作业给", de: "übertrug Gewahrsam auf", el: "μετεβίβασε κατοχή σε", fr: "changement de détenteur au profit de", pt: "custódia recebida por", ru: "опека получена"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14_carried_out_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P29i_received_custody_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "received custody through", cn: "取得保管作业於", de: "erhielt Gewahrsam durch", el: "παρέλαβε κατοχή μέσω", fr: "est devenu détenteur grâce à", pt: "início da custódia por meio de", ru: "получил опеку через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P14i_performed",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P2_has_type,
      comment: {en: "This property allows sub typing of CRM entities - a form of specialisation – through the use of a terminological hierarchy, or thesaurus. \nThe CRM is intended to focus on the high-level entities and relationships needed to describe data structures. Consequently, it does not specialise entities any further than is required for this immediate purpose. However, entities in the isA hierarchy of the CRM may by specialised into any number of sub entities, which can be defined in the E55 Type hierarchy. E51 Contact Point, for example, may be specialised into “e-mail address”, “telephone number”, “post office box”, “URL” etc. none of which figures explicitly in the CRM hierarchy. Sub typing obviously requires consistency between the meaning of the terms assigned and the more general intent of the CRM entity in question.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "has type", cn: "有类型", de: "hat den Typus", el: "έχει τύπο", fr: "est de type", pt: "é do tipo", ru: "имеет тип"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P2i_is_type_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "is type of", cn: "被用来分类", de: "ist Typus von", el: "είναι ο τύπος του/της", fr: "est le type de", pt: "é o tipo de", ru: "является типом для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P30_transferred_custody_of,
      comment: {en: "This property identifies an item or items of E18 Physical Thing concerned in an E10 Transfer of Custody activity. \nThe property will typically describe the object that is handed over by an E39 Actor to another Actor’s custody. On occasion, physical custody may be transferred involuntarily or illegally – through accident, unsolicited donation, or theft.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      label: {en: "transferred custody of", cn: "有保管标的物", de: "übertrug Gewahrsam über", el: "μετεβίβασε κατοχή του/της/των", fr: "changement de détenteur concernant", pt: "transferida custódia de", ru: "передало опеку на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P30i_custody_transferred_through,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "custody transferred through", cn: "被移转了保管作业於", de: "wechselte Gewahrsam durch", el: "άλλαξε κατοχή μέσω", fr: "a changé de détenteur du fait de", pt: "custódia transferida por meio de", ru: "опека передана через"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E10_Transfer_of_Custody",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P31_has_modified,
      comment: {en: "This property identifies the E24 Physical Man-Made Thing modified in an E11 Modification.\nIf a modification is applied to a non-man-made object, it is regarded as an E22 Man-Made Object from that time onwards. \n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      label: {en: "has modified", cn: "修改了", de: "veränderte", el: "τροποποίησε", fr: "a modifié", pt: "modificou", ru: "изменил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P31i_was_modified_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "was modified by", cn: "被修改於", de: "wurde verändert durch", el: "τροποποιήθηκε από", fr: "a été modifié par", pt: "foi modificada por", ru: "был изменен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E11_Modification",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P32_used_general_technique,
      comment: {en: "This property identifies the technique or method that was employed in an activity.\nThese techniques should be drawn from an external E55 Type hierarchy of consistent terminology of general techniques or methods such as embroidery, oil-painting, carbon dating, etc. Specific documented techniques should be described as instances of E29 Design or Procedure. This property identifies the technique that was employed in an act of modification.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "used general technique", cn: "使用通用技术", de: "benutzte das allgemeine Verfahren", el: "χρησιμοποίησε γενική τεχνική", fr: "a employé comme technique générique", pt: "usou técnica geral", ru: "использовал общую технику"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P125_used_object_of_type",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P32i_was_technique_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was technique of", cn: "被使用於", de: "war Verfahren von", el: "ήταν τεχνική του/της", fr: "a été la technique mise en œuvre dans", pt: "foi técnica da", ru: "был техникой для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P125i_was_type_of_object_used_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P33_used_specific_technique,
      comment: {en: "This property identifies a specific instance of E29 Design or Procedure in order to carry out an instance of E7 Activity or parts of it. \nThe property differs from P32 used general technique (was technique of) in that P33 refers to an instance of E29 Design or Procedure, which is a concrete information object in its own right rather than simply being a term or a method known by tradition. \nTypical examples would include intervention plans for conservation or the construction plans of a building.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      label: {en: "used specific technique", cn: "使用特定技术", de: "benutzte das bestimmte Verfahren", el: "χρησιμοποίησε συγκεκριμένη τεχνική", fr: "a employé comme technique spécifique", pt: "usou técnica específica", ru: "использовал особую технику"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P16_used_specific_object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P33i_was_used_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      label: {en: "was used by", cn: "被特别使用於", de: "wurde benutzt von", el: "χρησιμοποιήθηκε για", fr: "a été employée par", pt: "foi usada por", ru: "был использован посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E7_Activity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P16i_was_used_for",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P34_concerned,
      comment: {en: "This property identifies the E18 Physical Thing that was assessed during an E14 Condition Assessment activity. \nConditions may be assessed either by direct observation or using recorded evidence. In the latter case the E18 Physical Thing does not need to be present or extant.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E14_Condition_Assessment",
      label: {en: "concerned", cn: "评估了", de: "betraf", el: "αφορούσε σε", fr: "a concerné", pt: "interessada", ru: "имел дело с"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140_assigned_attribute_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P34i_was_assessed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "was assessed by", cn: "被评估於", de: "wurde beurteilt durch", el: "εκτιμήθηκε από", fr: "expertisé par le biais de", pt: "foi avaliada por", ru: "был оценен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E14_Condition_Assessment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140i_was_attributed_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P35_has_identified,
      comment: {en: "This property identifies the E3 Condition State that was observed in an E14 Condition Assessment activity."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E14_Condition_Assessment",
      label: {en: "has identified", cn: "评估认定了", de: "hat identifiziert", el: "έχει διαπιστώσει", fr: "a identifié", pt: "identificou", ru: "идентифицировал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P35i_was_identified_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      label: {en: "was identified by", cn: "被评估认定於", de: "wurde identifiziert durch", el: "έχει διαπιστωθεί από", fr: "est identifié par", pt: "foi identificado por", ru: "идентифицирован посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E14_Condition_Assessment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P37_assigned,
      comment: {en: "This property records the identifier that was assigned to an item in an Identifier Assignment activity.\nThe same identifier may be assigned on more than one occasion.\nAn Identifier might be created prior to an assignment.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      label: {en: "assigned", cn: "指定标识符为", de: "wies zu", el: "απέδωσε", fr: "a attribué", pt: "atribuiu", ru: "назначил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P37i_was_assigned_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      label: {en: "was assigned by", cn: "被指定为标识符於", de: "wurde zugewiesen durch", el: "αποδόθηκε ως ιδιότητα από", fr: "a été attribuée par", pt: "foi atribuído por", ru: "был присвоен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P38_deassigned,
      comment: {en: "This property records the identifier that was deassigned from an instance of E1 CRM Entity.\nDeassignment of an identifier may be necessary when an item is taken out of an inventory, a new numbering system is introduced or items are merged or split up. \nThe same identifier may be deassigned on more than one occasion.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      label: {en: "deassigned", cn: "取消标识符", de: " hob Zuweisung auf von", el: "ακύρωσε", fr: "a désattribué", pt: "retirou a atribuição do", ru: "отменил назначение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P38i_was_deassigned_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      label: {en: "was deassigned by", cn: "被取消标识符於", de: "wurde aufgehoben durch", el: "ακυρώθηκε από", fr: "a été désattribué par", pt: "foi retirada a atribuição por", ru: "был отменен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E15_Identifier_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P39_measured,
      comment: {en: "This property associates an instance of E16 Measurement with the instance of E1 CRM Entity to which it applied. An instance of E1 CRM Entity may be measured more than once. Material and immaterial things and processes may be measured, e.g. the number of words in a text, or the duration of an event.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E16_Measurement",
      label: {en: "measured", cn: "测量了", de: "vermaß", el: "μέτρησε", fr: "a mesuré", pt: "mediu", ru: "измерил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140_assigned_attribute_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P39i_was_measured_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "was measured by", cn: "被测量於", de: "wurde vermessen durch", el: "μετρήθηκε από", fr: "a été mesuré par", pt: "foi medida por", ru: "был измерен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E16_Measurement",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140i_was_attributed_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P3_has_note,
      comment: {en: "This property is a container for all informal descriptions about an object that have not been expressed in terms of CRM constructs. \nIn particular it captures the characterisation of the item itself, its internal structures, appearance etc.\nLike property P2 has type (is type of), this property is a consequence of the restricted focus of the CRM. The aim is not to capture, in a structured form, everything that can be said about an item; indeed, the CRM formalism is not regarded as sufficient to express everything that can be said. Good practice requires use of distinct note fields for different aspects of a characterisation. The P3.1 has type property of P3 has note allows differentiation of specific notes, e.g. “construction”, “decoration” etc. \nAn item may have many notes, but a note is attached to a specific item.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "has note", cn: "有说明", de: "hat Anmerkung", el: "έχει επεξήγηση", fr: "a pour note", pt: "tem nota", ru: "имеет примечание"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P40_observed_dimension,
      comment: {en: "This property records the dimension that was observed in an E16 Measurement Event.\nE54 Dimension can be any quantifiable aspect of E70 Thing. Weight, image colour depth and monetary value are dimensions in this sense. One measurement activity may determine more than one dimension of one object.\nDimensions may be determined either by direct observation or using recorded evidence. In the latter case the measured Thing does not need to be present or extant.\nEven though knowledge of the value of a dimension requires measurement, the dimension may be an object of discourse prior to, or even without, any measurement being made.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E16_Measurement",
      label: {en: "observed dimension", cn: "观察认定的规模是", de: "beobachtete Dimension", el: "παρατήρησε", fr: "a relevé comme dimension", pt: "verificou a dimensão", ru: "определил величину"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P40i_was_observed_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "was observed in", cn: "被观察认定於", de: "wurde beobachtet in", el: "παρατηρήθηκε από", fr: "a été relevée au cours de", pt: "foi verificada durante", ru: "наблюдался в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E16_Measurement",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P41_classified,
      comment: {en: "This property records the item to which a type was assigned in an E17 Type Assignment activity.\nAny instance of a CRM entity may be assigned a type through type assignment. Type assignment events allow a more detailed path from E1 CRM Entity through P41 classified (was classified), E17 Type Assignment, P42 assigned (was assigned by) to E55 Type for assigning types to objects compared to the shortcut offered by P2 has type (is type of).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E17_Type_Assignment",
      label: {en: "classified", cn: "分类了", de: "klassifizierte", el: "χαρακτήρισε", fr: "a classifié", pt: "classificou", ru: "классифицировал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140_assigned_attribute_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P41i_was_classified_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "was classified by", cn: "被分类於", de: "wurde klassifiziert durch", el: "χαρακτηρίσθηκε από", fr: "a été classifiée par le biais de", pt: "foi classificada por", ru: "был классифицирован посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E17_Type_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P140i_was_attributed_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P42_assigned,
      comment: {en: "This property records the type that was assigned to an entity by an E17 Type Assignment activity. \nType assignment events allow a more detailed path from E1 CRM Entity through P41 classified (was classified by), E17 Type Assignment, P42 assigned (was assigned by) to E55 Type for assigning types to objects compared to the shortcut offered by P2 has type (is type of).\nFor example, a fragment of an antique vessel could be assigned the type “attic red figured belly handled amphora” by expert A. The same fragment could be assigned the type “shoulder handled amphora” by expert B.\nA Type may be intellectually constructed independent from assigning an instance of it.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E17_Type_Assignment",
      label: {en: "assigned", cn: "指定类型为", de: "wies zu", el: "απέδωσε ως ιδιότητα", fr: "a attribué", pt: "atribuiu", ru: "назначил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141_assigned",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P42i_was_assigned_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E55_Type",
      label: {en: "was assigned by", cn: "被指定类型於", de: "wurde zugewiesen durch", el: "αποδόθηκε από", fr: "a été attribué par", pt: "foi atribuído por", ru: "был присвоен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E17_Type_Assignment",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P141i_was_assigned_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P43_has_dimension,
      comment: {en: "This property records a E54 Dimension of some E70 Thing.\nIt is a shortcut of the more fully developed path from E70 Thing through P39 measured (was measured by), E16 Measurement P40 observed dimension (was observed in) to E54 Dimension. It offers no information about how and when an E54 Dimension was established, nor by whom.\nAn instance of E54 Dimension is specific to an instance of E70 Thing.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      label: {en: "has dimension", cn: "有规模数量", de: "hat Dimension", el: "έχει μέγεθος", fr: "a pour dimension", pt: "tem dimensão", ru: "имеет величину"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P43i_is_dimension_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "is dimension of", cn: "估量的标的物是", de: "ist Dimension von", el: "είναι μέγεθος του", fr: "est dimension de", pt: "é dimensão de", ru: "является величиной для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E70_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P44_has_condition,
      comment: {en: "This property records an E3 Condition State for some E18 Physical Thing.\nIt is a shortcut of the more fully developed path from E18 Physical Thing through P34 concerned (was assessed by), E14 Condition Assessment P35 has identified (was identified by) to E3 Condition State. It offers no information about how and when the E3 Condition State was established, nor by whom. \nAn instance of Condition State is specific to an instance of Physical Thing.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has condition", cn: "有状态", de: "hat Zustand", el: "έχει κατάσταση", fr: "a pour état matériel", pt: "tem estado material ", ru: "имеет условие"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P44i_is_condition_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      label: {en: "is condition of", cn: "描述的标的物是", de: "ist Zustand von", el: "είναι κατάσταση του", fr: "état matériel de", pt: "estado material de", ru: "является условием для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P45_consists_of,
      comment: {en: "This property identifies the instances of E57 Materials of which an instance of E18 Physical Thing is composed.\nAll physical things consist of physical materials. P45 consists of (is incorporated in) allows the different Materials to be recorded. P45 consists of (is incorporated in) refers here to observed Material as opposed to the consumed raw material.\nA Material, such as a theoretical alloy, may not have any physical instances"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "consists of", cn: "有构成材料", de: "besteht aus", el: "αποτελείται από", fr: "consiste en", pt: "consiste de", ru: "составлен из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P45i_is_incorporated_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      label: {en: "is incorporated in", cn: "被用来构成", de: "ist enthalten in", el: "είναι ενσωματωμένος/η/ο σε", fr: "est présent dans", pt: "está presente em", ru: "входит в состав"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P46_is_composed_of,
      comment: {en: "This property allows instances of E18 Physical Thing to be analysed into component elements.\nComponent elements, since they are themselves instances of E18 Physical Thing, may be further analysed into sub-components, thereby creating a hierarchy of part decomposition. An instance of E18 Physical Thing may be shared between multiple wholes, for example two buildings may share a common wall.\nThis property is intended to describe specific components that are individually documented, rather than general aspects. Overall descriptions of the structure of an instance of E18 Physical Thing are captured by the P3 has note property.\nThe instances of E57 Materials of which an item of E18 Physical Thing is composed should be documented using P45 consists of (is incorporated in).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "is composed of", cn: "有组件", de: "ist zusammengesetzt aus", el: "αποτελείται από", fr: "est composée de", pt: "é composto de", ru: "составлен из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P46i_forms_part_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "forms part of", cn: "被用来组成", de: "bildet Teil von", el: "αποτελεί μέρος του/της", fr: "fait partie de", pt: "faz parte de", ru: "формирует часть"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P48_has_preferred_identifier,
      comment: {en: "This property records the preferred E42 Identifier that was used to identify an instance of E1 CRM Entity at the time this property was recorded.\nMore than one preferred identifier may have been assigned to an item over time.\nUse of this property requires an external mechanism for assigning temporal validity to the respective CRM instance.\nP48 has preferred identifier (is preferred identifier of), is a shortcut for the path from E1 CRM Entity through P140 assigned attribute to (was attributed by), E15 Identifier Assignment, P37 assigned (was assigned by) to E42 Identifier. The fact that an identifier is a preferred one for an organisation can be better expressed in a context independent form by assigning a suitable E55 Type to the respective instance of E15 Identifier Assignment using the P2 has type property.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "has preferred identifier", cn: "有首选标识符", de: "hat bevorzugtes Kennzeichen", el: "έχει προτιμώμενο αναγνωριστικό", fr: "a pour identificateur retenu", pt: "tem identificador preferido", ru: "имеет предпочтительный идентификатор"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P48i_is_preferred_identifier_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E42_Identifier",
      label: {en: "is preferred identifier of", cn: "首选标识符的标的物是", de: "ist bevorzugtes Kennzeichen für", el: "είναι προτιμώμενο αναγνωριστικό", fr: "est l’identificateur retenu de", pt: "é o identificador preferido de", ru: "является предпочтительным идентификатором для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P49_has_former_or_current_keeper,
      comment: {en: "This property identifies the E39 Actor or Actors who have or have had custody of an instance of E18 Physical Thing at some time. \nThe distinction with P50 has current keeper (is current keeper of) is that P49 has former or current keeper (is former or current keeper of) leaves open the question as to whether the specified keepers are current. \nP49 has former or current keeper (is former or current keeper of) is a shortcut for the more detailed path from E18 Physical Thing through P30 transferred custody of (custody transferred through), E10 Transfer of Custody, P28 custody surrendered by (surrendered custody through) or P29 custody received by (received custody through) to E39 Actor.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has former or current keeper", cn: "有前任或现任保管者", de: "hat früheren oder derzeitigen Betreuer", el: "είναι ή ήταν στην κατοχή του", fr: "est ou a été détenu par", pt: "é ou foi guardada por", ru: "имеет бывшего или текущего смотрителя"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P49i_is_former_or_current_keeper_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is former or current keeper of", cn: "目前或曾经保管", de: "ist früherer oder derzeitiger Betreuer von", el: "κατέχει ή κατείχε", fr: "est ou a été détenteur de", pt: "é ou foi guardador de", ru: "является бывшим или текущим смотрителем для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P4_has_time-span",
      comment: {en: "This property describes the temporal confinement of an instance of an E2 Temporal Entity.\nThe related E52 Time-Span is understood as the real Time-Span during which the phenomena were active, which make up the temporal entity instance. It does not convey any other meaning than a positioning on the “time-line” of chronology. The Time-Span in turn is approximated by a set of dates (E61 Time Primitive). A temporal entity can have in reality only one Time-Span, but there may exist alternative opinions about it, which we would express by assigning multiple Time-Spans. Related temporal entities may share a Time-Span. Time-Spans may have completely unknown dates but other descriptions by which we can infer knowledge.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      label: {en: "has time-span", cn: "发生时段是", de: "hat Zeitspanne", el: "βρισκόταν σε εξέλιξη", fr: "a pour durée", pt: "tem período de tempo", ru: "имеет временной отрезок"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :"P4i_is_time-span_of",
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "is time-span of", cn: "开始并完成了", de: "ist Zeitspanne von", el: "είναι χρονικό διάστημα του/της", fr: "est la durée de", pt: "é o período de tempo de", ru: "является временным отрезком для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E2_Temporal_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P50_has_current_keeper,
      comment: {en: "This property identifies the E39 Actor or Actors who had custody of an instance of E18 Physical Thing at the time of validity of the record or database containing the statement that uses this property.\n\tP50 has current keeper (is current keeper of) is a shortcut for the more detailed path from E18 Physical Thing through P30 transferred custody of (custody transferred through), E10 Transfer of Custody, P29 custody received by (received custody through) to E39 Actor.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has current keeper", cn: "有现任保管者", de: "hat derzeitigen Betreuer", el: "είναι στην κατοχή του", fr: "est actuellement détenu par", pt: "é guardada por", ru: "имеет текущего смотрителя"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P49_has_former_or_current_keeper",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P50i_is_current_keeper_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is current keeper of", cn: "目前保管", de: "ist derzeitiger Betreuer von", el: "κατέχει", fr: "est actuel détenteur de", pt: "é guardador de", ru: "является текущим смотрителем для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P49i_is_former_or_current_keeper_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P51_has_former_or_current_owner,
      comment: {en: "This property identifies the E39 Actor that is or has been the legal owner (i.e. title holder) of an instance of E18 Physical Thing at some time.\nThe distinction with P52 has current owner (is current owner of) is that P51 has former or current owner (is former or current owner of) does not indicate whether the specified owners are current. P51 has former or current owner (is former or current owner of) is a shortcut for the more detailed path from E18 Physical Thing through P24 transferred title of (changed ownership through), E8 Acquisition, P23 transferred title from (surrendered title through), or P22 transferred title to (acquired title through) to E39 Actor.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has former or current owner", cn: "有前任或现任物主", de: "hat früheren oder derzeitigen Besitzer ", el: "έχει ή είχε ιδιοκτήτη", fr: "est ou a été possédée par", pt: "é ou foi propriedade de", ru: "имеет бывшего или текущего владельца"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P51i_is_former_or_current_owner_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is former or current owner of", cn: "目前或曾经拥有", de: "ist früherer oder derzeitiger Besitzer von", el: "είναι ή ήταν ιδιοκτήτης του/της", fr: "est ou a été propriétaire de", pt: "é ou foi proprietário de", ru: "является бывшим или текущим владельцем для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P52_has_current_owner,
      comment: {en: "This property identifies the E21 Person, E74 Group or E40 Legal Body that was the owner of an instance of E18 Physical Thing at the time of validity of the record or database containing the statement that uses this property.\nP52 has current owner (is current owner of) is a shortcut for the more detailed path from E18 Physical Thing through P24 transferred title of (changed ownership through), E8 Acquisition, P22 transferred title to (acquired title through) to E39 Actor, if and only if this acquisition event is the most recent.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has current owner", cn: "有现任物主", de: "hat derzeitigen Besitzer", el: "έχει ιδιοκτήτη", fr: "est actuellement possédée par", pt: "é propriedade de", ru: "имеет текущего владельца"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P105_right_held_by", "http://www.cidoc-crm.org/cidoc-crm/P51_has_former_or_current_owner"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P52i_is_current_owner_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "is current owner of", cn: "目前拥有", de: "ist derzeitiger Besitzer von", el: "είναι ιδιοκτήτης του", fr: "est le propriétaire actuel de", pt: "é proprietário de", ru: "является текущим владельцем для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P105i_has_right_on", "http://www.cidoc-crm.org/cidoc-crm/P51i_is_former_or_current_owner_of"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P53_has_former_or_current_location,
      comment: {en: "This property allows an instance of E53 Place to be associated as the former or current location of an instance of E18 Physical Thing.\nIn the case of E19 Physical Objects, the property does not allow any indication of the Time-Span during which the Physical Object was located at this Place, nor if this is the current location.\nIn the case of immobile objects, the Place would normally correspond to the Place of creation.\nP53 has former or current location (is former or current location of) is a shortcut. A more detailed representation can make use of the fully developed (i.e. indirect) path from E19 Physical Object through P25 moved (moved by), E9 Move, P26 moved to (was destination of) or P27 moved from (was origin of) to E53 Place.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has former or current location", cn: "目前或曾经被置放於", de: "hat früheren oder derzeitigen Standort", el: "βρίσκεται ή βρισκόταν σε", fr: "a ou a eu pour localisation", pt: "é ou foi localizada em", ru: "имеет текущее или бывшее местоположение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P53i_is_former_or_current_location_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is former or current location of", cn: "目前或曾经被置放了", de: "ist früherer oder derzeitiger Standort von", el: "είναι ή ήταν θέση του", fr: "est ou a été localisation de", pt: "é ou foi localização de", ru: "является текущим или бывшим местоположением для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P54_has_current_permanent_location,
      comment: {en: "This property records the foreseen permanent location of an instance of E19 Physical Object at the time of validity of the record or database containing the statement that uses this property.\nP54 has current permanent location (is current permanent location of) is similar to P55 has current location (currently holds). However, it indicates the E53 Place currently reserved for an object, such as the permanent storage location or a permanent exhibit location. The object may be temporarily removed from the permanent location, for example when used in temporary exhibitions or loaned to another institution. The object may never actually be located at its permanent location.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      label: {en: "has current permanent location", cn: "目前的永久位置位於", de: "hat derzeitigen permanenten Standort", el: "έχει μόνιμη θέση", fr: "a actuellement pour localisation à demeure", pt: "é localizado permanentemente em", ru: "имеет текущее постоянное местоположение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P54i_is_current_permanent_location_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is current permanent location of", cn: "目前被用来永久置放", de: "ist derzeitiger permanenter Standort von", el: "είναι μόνιμη θέση του/της", fr: "est actuellement localisation à demeure de", pt: "é localização permanente de", ru: "является текущим постоянным местоположением для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P55_has_current_location,
      comment: {en: "This property records the location of an E19 Physical Object at the time of validity of the record or database containing the statement that uses this property. \n\tThis property is a specialisation of P53 has former or current location (is former or current location of). It indicates that the E53 Place associated with the E19 Physical Object is the current location of the object. The property does not allow any indication of how long the Object has been at the current location. \nP55 has current location (currently holds) is a shortcut. A more detailed representation can make use of the fully developed (i.e. indirect) path from E19 Physical Object through P25 moved (moved by), E9 Move P26 moved to (was destination of) to E53 Place if and only if this Move is the most recent.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      label: {en: "has current location", cn: "目前被置放於", de: "hat derzeitigen Standort", el: "βρίσκεται σε", fr: "a pour localisation actuelle", pt: "é localizado em", ru: "в данный момент находится в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P53_has_former_or_current_location",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P55i_currently_holds,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "currently holds", cn: "目前置放了", de: "hält derzeitig", el: "είναι θέση του", fr: "est localisation actuelle de", pt: "é localização atual de", ru: "в данный момент содержит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P53i_is_former_or_current_location_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P56_bears_feature,
      comment: {en: "This property links an instance of E19 Physical Object to an instance of E26 Physical Feature that it bears.\nAn E26 Physical Feature can only exist on one object. One object may bear more than one E26 Physical Feature. An E27 Site should be considered as an E26 Physical Feature on the surface of the Earth.\nAn instance B of E26 Physical Feature being a detail of the structure of another instance A of E26 Physical Feature can be linked to B by use of the property P46 is composed of (forms part of). This implies that the subfeature B is P56i found on the same E19 Physical Object as A.\nP56 bears feature (is found on) is a shortcut. A more detailed representation can make use of the fully developed (i.e. indirect) path from E19 Physical Object through P59 has section (is located on or\nDefinition of the CIDOC Conceptual Reference Model 149 within), E53 Place, P53 has former or current location (is former or current location of) to E26 Physical Feature.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      label: {en: "bears feature", cn: "有外貌表征", de: "trägt Merkmal", el: "φέρει μόρφωμα", fr: "présente pour caractéristique", pt: "possui característica", ru: "несет признак"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E26_Physical_Feature",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P46_is_composed_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P56i_is_found_on,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E26_Physical_Feature",
      label: {en: "is found on", cn: "被见於", de: "wird gefunden auf", el: "βρίσκεται σε", fr: "se trouve sur", pt: "é encontrada em", ru: "найден на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P46i_forms_part_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P57_has_number_of_parts,
      comment: {en: "This property documents the E60 Number of parts of which an instance of E19 Physical Object is composed.\nThis may be used as a method of checking inventory counts with regard to aggregate or collective objects. What constitutes a part or component depends on the context and requirements of the documentation. Normally, the parts documented in this way would not be considered as worthy of individual attention.\nFor a more complete description, objects may be decomposed into their components and constituents using P46 is composed of (forms parts of) and P45 consists of (is incorporated in). This allows each element to be described individually.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E19_Physical_Object",
      label: {en: "has number of parts", cn: "有组件数目", de: "hat Anzahl Teile", el: "έχει αριθμό μερών", fr: "a pour nombre de parties", pt: "tem número de partes", ru: "имеет число частей"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P58_has_section_definition,
      comment: {en: "This property links an area (section) named by a E46 Section Definition to the instance of E18 Physical Thing upon which it is found.\nThe CRM handles sections as locations (instances of E53 Place) within or on E18 Physical Thing that are identified by E46 Section Definitions. Sections need not be discrete and separable components or parts of an object.\nThis is part of a more developed path from E18 Physical Thing through P58, E46 Section Definition, P87 is identified by (identifies) that allows a more precise definition of a location found on an object than the shortcut P59 has section (is located on or within).\nA particular instance of a Section Definition only applies to one instance of Physical Thing."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has section definition", cn: "有区域定义", de: "hat Abschittsdefinition", el: "έχει ορισμό τμήματος", fr: "a pour désignation de section", pt: "tem designação de seção", ru: "имеет определение района"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E46_Section_Definition",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P58i_defines_section,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E46_Section_Definition",
      label: {en: "defines section", cn: "界定了区域於", de: "definiert Abschitt auf oder von", el: "ορίζει τμήμα σε", fr: "définit une section de", pt: "define uma seção de", ru: "определяет район"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P59_has_section,
      comment: {en: "This property links an area to the instance of E18 Physical Thing upon which it is found.\nIt is typically used when a named E46 Section Definition is not appropriate.\nE18 Physical Thing may be subdivided into arbitrary regions. \nP59 has section (is located on or within) is a shortcut. If the E53 Place is identified by a Section Definition, a more detailed representation can make use of the fully developed (i.e. indirect) path from E18 Physical Thing through P58 has section definition (defines section), E46 Section Definition, P87 is identified by (identifies) to E53 Place. A Place can only be located on or within one Physical Object.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "has section", cn: "有区域", de: "hat Bereich", el: "έχει τομέα", fr: "a pour section", pt: "tem seção", ru: "имеет район"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P59i_is_located_on_or_within,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is located on or within", cn: "位於", de: "befindet sich auf oder in", el: "βρίσκεται σε ή εντός", fr: "se situe sur ou dans", pt: "está localizada sobre ou dentro de", ru: "находится на или внутри"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P5_consists_of,
      comment: {en: "This property describes the decomposition of an E3 Condition State into discrete, subsidiary states. \nIt is assumed that the sub-states into which the condition state is analysed form a logical whole - although the entire story may not be completely known – and that the sub-states are in fact constitutive of the general condition state. For example, a general condition state of “in ruins” may be decomposed into the individual stages of decay"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      label: {en: "consists of", cn: "包含", de: "besteht aus", el: "αποτελείται από", fr: "consiste en", pt: "consiste de", ru: "состоит из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P5i_forms_part_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      label: {en: "forms part of", cn: "组成了", de: "bildet Teil von", el: "αποτελεί μέρος του/της", fr: "fait partie de", pt: "faz parte de", ru: "формирует часть"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E3_Condition_State",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P62_depicts,
      comment: {en: "This property identifies something that is depicted by an instance of E24 Physical Man-Made Thing.\nThis property is a shortcut of the more fully developed path from E24 Physical Man-Made Thing through P65 shows visual item (is shown by), E36 Visual Item, P138 represents (has representation) to E1CRM Entity. P62.1 mode of depiction allows the nature of the depiction to be refined.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "depicts", cn: "描绘", de: "bildet ab", el: "απεικονίζει", fr: "figure", pt: "retrata", ru: "описывает"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P62i_is_depicted_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is depicted by", cn: "被描绘於", de: "wird abgebildet durch", el: "απεικονίζεται σε", fr: "est figurée sur", pt: "é retratada por", ru: "описан посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P65_shows_visual_item,
      comment: {en: "This property documents an E36 Visual Item shown by an instance of E24 Physical Man-Made Thing.\nThis property is similar to P62 depicts (is depicted by) in that it associates an item of E24 Physical Man-Made Thing with a visual representation. However, P65 shows visual item (is shown by) differs from the P62 depicts (is depicted by) property in that it makes no claims about what the E36 Visual Item is deemed to represent. E36 Visual Item identifies a recognisable image or visual symbol, regardless of what this image may or may not represent.\nFor example, all recent British coins bear a portrait of Queen Elizabeth II, a fact that is correctly documented using P62 depicts (is depicted by). Different portraits have been used at different periods, however. P65 shows visual item (is shown by) can be used to refer to a particular portrait.\nP65 shows visual item (is shown by) may also be used for Visual Items such as signs, marks and symbols, for example the 'Maltese Cross' or the 'copyright symbol’ that have no particular representational content. \nThis property is part of the fully developed path from E24 Physical Man-Made Thing through P65 shows visual item (is shown by), E36 Visual Item, P138 represents (has representation) to E1 CRM Entity which is shortcut by, P62 depicts (is depicted by).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      label: {en: "shows visual item", cn: "显示视觉项目", de: "zeigt Bildliches", el: "εμφανίζει οπτικό στοιχείο", fr: "présente l'item visuel", pt: "apresenta item visual", ru: "показывает визуальный предмет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P128_carries",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P65i_is_shown_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E36_Visual_Item",
      label: {en: "is shown by", cn: "被显示於", de: "wird gezeigt durch", el: "εμφανίζεται σε", fr: "est présenté par", pt: "é apresentado por", ru: "показан посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E24_Physical_Man-Made_Thing",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P128i_is_carried_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P67_refers_to,
      comment: {en: "This property documents that an E89 Propositional Object makes a statement about an instance of E1 CRM Entity. P67 refers to (is referred to by) has the P67.1 has type link to an instance of E55 Type. This is intended to allow a more detailed description of the type of reference. This differs from P129 is about (is subject of), which describes the primary subject or subjects of the E89 Propositional Object.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      label: {en: "refers to", cn: "论及", de: "verweist auf", el: "αναφέρεται σε", fr: "fait référence à", pt: "referencia", ru: "ссылается на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P67i_is_referred_to_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is referred to by", cn: "被论及於", de: "wird angeführt von", el: "αναφέρεται από", fr: "est référencé par", pt: "é referenciado por", ru: "имеет ссылку на себя от"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E89_Propositional_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P68_foresees_use_of,
      comment: {en: "This property identifies an E57 Material foreseeen to be used by an E29 Design or Procedure. \nE29 Designs and procedures commonly foresee the use of particular E57 Materials. The fabrication of adobe bricks, for example, requires straw, clay and water. This property enables this to be documented.\nThis property is not intended for the documentation of E57 Materials that were used on a particular occasion when an instance of E29 Design or Procedure was executed.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      label: {en: "foresees use of", cn: "指定使用材料", de: " sieht den Gebrauch vor von", el: "συνήθως χρησιμοποιεί", fr: "utilise habituellement", pt: "normalmente emprega", ru: "обычно применяет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67_refers_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P68i_use_foreseen_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E57_Material",
      label: {en: "use foreseen by", cn: "被指定使用於", de: "vorgesehen für Gebrauch durch defined", el: "συνήθως χρησιμοποιείται από", fr: "est habituellement utilisé par", pt: "é empregado por", ru: "обычно используется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67i_is_referred_to_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P69_is_associated_with,
      comment: {en: "This property generalises relationships like whole-part, sequence, prerequisite or inspired by between instances of E29 Design or Procedure. Any instance of E29 Design or Procedure may be associated with other designs or procedures. The property is considered to be symmetrical unless otherwise indicated by P69.1 has type.\nThe P69.1 has type property of P69 has association with allows the nature of the association to be specified reading from domain to range; examples of types of association between instances of E29 Design or Procedure include: has part, follows, requires, etc.\nThe property can typically be used to model the decomposition of the description of a complete workflow into a series of separate procedures.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      label: {en: "is associated with", cn: "相关於", de: "ist verbunden mit", el: "σχετίζεται με", fr: "est associée à", pt: "é associado com", ru: "ассоциирован с"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E29_Design_or_Procedure",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P70_documents,
      comment: {en: "This property describes the CRM Entities documented by instances of E31 Document.\nDocuments may describe any conceivable entity, hence the link to the highest-level entity in the CRM hierarchy. This property is intended for cases where a reference is regarded as being of a documentary character, in the scholarly or scientific sense.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E31_Document",
      label: {en: "documents", cn: "记录了", de: "belegt", el: "τεκμηριώνει", fr: "mentionne", pt: "documenta", ru: "документирует"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67_refers_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P70i_is_documented_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is documented in", cn: "被记录於", de: "wird belegt in", el: "τεκμηριώνεται σε", fr: "est mentionnée dans", pt: "é documentado em", ru: "документирован в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E31_Document",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67i_is_referred_to_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P71_lists,
      comment: {en: "This property documents a source E32 Authority Document for an instance of an E1 CRM Entity.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E32_Authority_Document",
      label: {en: "lists", cn: "条列出", de: "listet", el: "περιλαμβάνει", fr: "définit", pt: "define", ru: "перечисляет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67_refers_to",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P71i_is_listed_in,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E1_CRM_Entity",
      label: {en: "is listed in", cn: "被条列於", de: "wird aufgelistet in", el: "περιλαμβάνεται σε", fr: "est défini par", pt: "é definido por", ru: "перечислен в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E32_Authority_Document",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P67i_is_referred_to_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P72_has_language,
      comment: {en: "This property describes the E56 Language of an E33 Linguistic Object. \nLinguistic Objects are composed in one or more human Languages. This property allows these languages to be documented.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      label: {en: "has language", cn: "使用语言", de: "hat Sprache", el: "έχει γλώσσα", fr: "est en langue", pt: "é da língua ", ru: "имеет язык"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E56_Language",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P72i_is_language_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E56_Language",
      label: {en: "is language of", cn: "被用来撰写", de: "ist Sprache von", el: "είναι γλώσσα του/της", fr: "est la langue de", pt: "é a língua de", ru: "является языком для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P73_has_translation,
      comment: {en: "This property describes the source and target of instances of E33Linguistic Object involved in a translation.\nWhen a Linguistic Object is translated into a new language it becomes a new Linguistic Object, despite being conceptually similar to the source object.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      label: {en: "has translation", cn: "有译文", de: "hat Übersetzung", el: "έχει μετάφραση", fr: "a pour traduction", pt: "tem tradução", ru: "имеет перевод"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P130_shows_features_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P73i_is_translation_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      label: {en: "is translation of", cn: "翻译自", de: "ist Übersetzung von", el: "είναι μετάφραση του/της", fr: "est la traduction de", pt: "é tradução de", ru: "является переводом"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E33_Linguistic_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P130i_features_are_also_found_on",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P74_has_current_or_former_residence,
      comment: {en: "This property describes the current or former E53 Place of residence of an E39 Actor. \nThe residence may be either the Place where the Actor resides, or a legally registered address of any kind.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "has current or former residence", cn: "目前或曾经居住於", de: "hat derzeitigen oder früheren Sitz", el: "έχει ή είχε κατοικία", fr: "réside ou a résidé à", pt: "reside ou residiu em", ru: "имеет текущее или бывшее местожительства"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P74i_is_current_or_former_residence_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is current or former residence of", cn: "历年来的居住者包括", de: "ist derzeitiger oder früherer Sitz von", el: "είναι ή ήταν κατοικία του/της", fr: "est ou a été la résidence de", pt: "é ou foi residência de", ru: "является текущим или бывшим местом жительства для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P75_possesses,
      comment: {en: "This property identifies former or current instances of E30 Rights held by an E39 Actor."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "possesses", cn: "拥有", de: "besitzt", el: "κατέχει", fr: "est détenteur de", pt: "é detentor de", ru: "владеет"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E30_Right",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P75i_is_possessed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E30_Right",
      label: {en: "is possessed by", cn: "有拥有者", de: "sind im Besitz von", el: "κατέχεται από", fr: "est détenu par", pt: "são detidos por", ru: "принадлежит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P76_has_contact_point,
      comment: {en: "This property identifies an E51 Contact Point of any type that provides access to an E39 Actor by any communication method, such as e-mail or fax.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      label: {en: "has contact point", cn: "有联系方式", de: "hat Kontaktpunkt", el: "έχει σημείο επικοινωνίας", fr: "a pour coordonnées individuelles", pt: "possui ponto de contato", ru: "имеет контакт"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E51_Contact_Point",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P76i_provides_access_to,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E51_Contact_Point",
      label: {en: "provides access to", cn: "被用来联系", de: "bietet Zugang zu", el: "παρέχει πρόσβαση σε", fr: "permettent de contacter", pt: "é ponto de contado de", ru: "предоставляет доступ к"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E39_Actor",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P78_is_identified_by,
      comment: {en: "This property identifies an E52 Time-Span using an E49Time Appellation."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "is identified by", cn: "有识别称号", de: "wird bezeichnet als", el: "αναγνωρίζεται ως", fr: "est identifiée par", pt: "é identificado por ", ru: "идентифицируется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E49_Time_Appellation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P78i_identifies,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E49_Time_Appellation",
      label: {en: "identifies", cn: "被用来识别", de: "bezeichnet", el: "είναι αναγνωριστικό", fr: "identifie", pt: "identifica", ru: "идентифицирует"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P79_beginning_is_qualified_by,
      comment: {en: "This property qualifies the beginning of an E52 Time-Span in some way. \nThe nature of the qualification may be certainty, precision, source etc.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "beginning is qualified by", cn: "起点认定的性质是", de: "hat Anfangsbegründung", el: "αρχή προσδιορίζεται από", fr: "début est qualifié par", pt: "início é qualificado por", ru: "начало ограничено"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P3_has_note",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P7_took_place_at,
      comment: {en: "This property describes the spatial location of an instance of E4 Period. \nThe related E53 Place should be seen as an approximation of the geographical area within which the phenomena that characterise the period in question occurred. P7took place at (witnessed) does not convey any meaning other than spatial positioning (generally on the surface of the earth).  For example, the period “R?volution fran?aise” can be said to have taken place in “France”, the “Victorian” period, may be said to have taken place in “Britain” and its colonies, as well as other parts of Europe and north America.\nA period can take place at multiple locations.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "took place at", cn: "发生地在", de: "fand statt in", el: "έλαβε χώρα σε", fr: "a eu lieu dans", pt: "ocorreu em", ru: "совершался на"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P7i_witnessed,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "witnessed", cn: "发生过", de: "bezeugte", el: "υπήρξε τόπος του", fr: "a été témoin de", pt: "testemunhou", ru: "был местом совершения"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P80_end_is_qualified_by,
      comment: {en: "This property qualifies the end of an E52 Time-Span in some way. \nThe nature of the qualification may be certainty, precision, source etc.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "end is qualified by", cn: "终点认定的性质是", de: "hat Begründung des Endes", el: "τέλος προσδιορίζεται από", fr: "fin est qualifiée par", pt: "final é qualificado por", ru: "конец ограничен"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P3_has_note",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P81_ongoing_throughout,
      comment: {en: "This property describes the minimum period of time covered by an E52 Time-Span.\nSince Time-Spans may not have precisely known temporal extents, the CRM supports statements about the minimum and maximum temporal extents of Time-Spans. This property allows a Time-Span’s minimum temporal extent (i.e. its inner boundary) to be assigned an E61 Time Primitive value. Time Primitives are treated by the CRM as application or system specific date intervals, and are not further analysed.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "ongoing throughout", cn: "时段的数值至少涵盖", de: "andauernd während", el: "καθόλη τη διάρκεια του/της", fr: "couvre au moins", pt: "abrange no mínimo", ru: "длится в течение"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P81a_end_of_the_begin,
      comment: {en: "This is defined as the first boundary of the property P81"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "end of the begin", de: "Ende des Anfangs", el: "τέλος της αρχής", fr: "fin du début", pt: "fim do início", ru: "конец начала"},
      range: "http://www.w3.org/2001/XMLSchema#dateTime",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P81_ongoing_throughout",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P81b_begin_of_the_end,
      comment: {en: "This is defined as the second boundary of the property P81"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "begin of the end", de: "Anfang vom Ende", el: "αρχή του τέλους", fr: "début de la fin", pt: "começar do fim", ru: "начать в конце"},
      range: "http://www.w3.org/2001/XMLSchema#dateTime",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P81_ongoing_throughout",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P82_at_some_time_within,
      comment: {en: "This property describes the maximum period of time within which an E52 Time-Span falls.\nSince Time-Spans may not have precisely known temporal extents, the CRM supports statements about the minimum and maximum temporal extents of Time-Spans. This property allows a Time-Span’s maximum temporal extent (i.e. its outer boundary) to be assigned an E61 Time Primitive value. Time Primitives are treated by the CRM as application or system specific date intervals, and are not further analysed.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "at some time within", cn: "时段的数值不会超越", de: "irgendwann innerhalb von", el: "κάποτε εντός", fr: "couvre au plus", pt: "abrange no máximo", ru: "некоторое время в течение"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P82a_begin_of_the_begin,
      comment: {en: "This is defined as the first boundary of the property P82"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "begin of the begin", de: "Anfang des Anfangs", el: "αρχή της αρχής", fr: "début du début", pt: "começar do início", ru: "начать с начала"},
      range: "http://www.w3.org/2001/XMLSchema#dateTime",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P82_at_some_time_within",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P82b_end_of_the_end,
      comment: {en: "This is defined as the second boundary of the property P82"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "end of the end", de: "Ende vom Ende", el: "τέλος του τέλους", fr: "fin de la fin", pt: "fim do fim", ru: "конец конец"},
      range: "http://www.w3.org/2001/XMLSchema#dateTime",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P82_at_some_time_within",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P83_had_at_least_duration,
      comment: {en: "This property describes the minimum length of time covered by an E52 Time-Span. \nIt allows an E52 Time-Span to be associated with an E54 Dimension representing it’s minimum duration (i.e. it’s inner boundary) independent from the actual beginning and end.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "had at least duration", cn: "时间最少持续了", de: "hatte Mindestdauer", el: "είχε ελάχιστη διάρκεια", fr: "a duré au moins", pt: "durou no mínimo", ru: "имеет длительность по крайней мере больше чем"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P83i_was_minimum_duration_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "was minimum duration of", de: "war Mindestdauer von", el: "είναι ελάχιστη διάρκεια του/της", fr: "a été la durée minimum de", pt: "foi a duração mínima de", ru: "был минимальной длительностью для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P84_had_at_most_duration,
      comment: {en: "This property describes the maximum length of time covered by an E52 Time-Span. \nIt allows an E52 Time-Span to be associated with an E54 Dimension representing it’s maximum duration (i.e. it’s outer boundary) independent from the actual beginning and end.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "had at most duration", cn: "时间最多持续了", de: "hatte Höchstdauer", el: "είχε μέγιστη διάρκεια", fr: "a duré au plus", pt: "durou no máximo", ru: "имеет длительность меньше чем"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P84i_was_maximum_duration_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "", de: "war längste Dauer von", el: "είναι μέγιστη διάρκεια του/της", fr: "a été la durée maximum de", pt: "foi a duração máxima de", ru: "был максимальной длительностью для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P86_falls_within,
      comment: {en: "This property describes the inclusion relationship between two instances of E52 Time-Span.\nThis property supports the notion that a Time-Span’s temporal extent falls within the temporal extent of another Time-Span. It addresses temporal containment only, and no contextual link between the two instances of Time-Span is implied.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "falls within", cn: "时间上被涵盖於", de: "fällt in", el: "περιέχεται σε", fr: "s’insère dans", pt: "está contido em", ru: "содержится в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P86i_contains,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      label: {en: "contains", cn: "时间上涵盖了", de: "enthält", el: "περιέχει", fr: "inclut", pt: "contém", ru: "содержит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E52_Time-Span",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P87_is_identified_by,
      comment: {en: "This property identifies an E53 Place using an E44 Place Appellation. \nExamples of Place Appellations used to identify Places include instances of E48 Place Name, addresses, E47 Spatial Coordinates etc.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "is identified by", cn: "有辨认码", de: "wird bezeichnet als", el: "αναγνωρίζεται ως", fr: "est identifié par", pt: "é identificado por", ru: "идентифицируется посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1_is_identified_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P87i_identifies,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E44_Place_Appellation",
      label: {en: "identifies", cn: "被用来辨认", de: "bezeichnet", el: "είναι αναγνωριστικό", fr: "identifie", pt: "identifica", ru: "идентифицирует"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P1i_identifies",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P89_falls_within,
      comment: {en: "This property identifies an instance of E53 Place that falls wholly within the extent of another E53 Place.\nIt addresses spatial containment only, and does not imply any relationship between things or phenomena occupying these places.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "falls within", cn: "空间上被包围於", de: "fällt in", el: "περιέχεται σε", fr: "s’insère dans", pt: "está contido em", ru: "содержится в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P89i_contains,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      label: {en: "contains", cn: "空间上包含了", de: "enthält", el: "περιέχει", fr: "inclut", pt: "contém", ru: "содержит"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E53_Place",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P8_took_place_on_or_within,
      comment: {en: "This property describes the location of an instance of E4 Period with respect to an E18 Physical Thing.\nP8 took place on or within (witnessed) is a short-cut of a path defining a E53 Place with respect to the geometry of an object. cf. E46 Section Definition.\nThis property is in effect a special case of P7 took place at. It describes a period that can be located with respect to the space defined by an E18 Physical Thing such as a ship or a building. The precise geographical location of the object during the period in question may be unknown or unimportant. \nFor example, the French and German armistice of 22 June 1940 was signed in the same railway carriage as the armistice of 11 November 1918.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "took place on or within", cn: "发生所在物件是", de: "fand statt auf oder innerhalb von ", el: "έλαβε χώρα σε ή εντός", fr: "a eu lieu sur ou dans", pt: "ocorreu em ou dentro", ru: "имел место на или в"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P8i_witnessed,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E18_Physical_Thing",
      label: {en: "witnessed", cn: "发生过", de: "bezeugte", el: "υπήρξε τόπος του", fr: "a été témoin de", pt: "testemunhou", ru: "являлся местом для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P90_has_value,
      comment: {en: "This property allows an E54 Dimension to be approximated by an E60 Number primitive."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "has value", cn: "有数值", de: "hat Wert", el: "έχει τιμή", fr: "a la valeur", pt: "tem valor", ru: "имеет значение"},
      range: "http://www.w3.org/2000/01/rdf-schema#Literal",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P91_has_unit,
      comment: {en: "This property shows the type of unit an E54 Dimension was expressed in."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      label: {en: "has unit", cn: "有单位", de: "hat Einheit", el: "έχει μονάδα μέτρησης", fr: "a pour unité", pt: "tem unidade", ru: "имеет единицу"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E58_Measurement_Unit",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P91i_is_unit_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E58_Measurement_Unit",
      label: {en: "is unit of", cn: "被当做单位来表示", de: "ist Einheit von", el: "αποτελεί μονάδα μέτρησης του/της", fr: "est l'unité de", pt: "é unidade de", ru: "является единицей для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E54_Dimension",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P92_brought_into_existence,
      comment: {en: "This property allows an E63 Beginning of Existence event to be linked to the E77 Persistent Item brought into existence by it.\nIt allows a “start” to be attached to any Persistent Item being documented i.e. E70 Thing, E72 Legal Object, E39 Actor, E41 Appellation, E51 Contact Point and E55 Type"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence",
      label: {en: "brought into existence", cn: "开始了", de: "brachte in Existenz", el: "γέννησε", fr: "a fait exister", pt: "trouxe à existência", ru: "создал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P92i_was_brought_into_existence_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      label: {en: "was brought into existence by", cn: "被开始於", de: "wurde in Existenz gebracht durch", el: "γεννήθηκε από", fr: "a commencé à exister du fait de", pt: "passou a existir por", ru: "был создан посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E63_Beginning_of_Existence",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P93_took_out_of_existence,
      comment: {en: "This property allows an E64 End of Existence event to be linked to the E77 Persistent Item taken out of existence by it.\nIn the case of immaterial things, the E64 End of Existence is considered to take place with the destruction of the last physical carrier.\nThis allows an “end” to be attached to any Persistent Item being documented i.e. E70 Thing, E72 Legal Object, E39 Actor, E41 Appellation, E51 Contact Point and E55 Type. For many Persistent Items we know the maximum life-span and can infer, that they must have ended to exist. We assume in that case an End of Existence, which may be as unnoticeable as forgetting the secret knowledge by the last representative of some indigenous nation.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence",
      label: {en: "took out of existence", cn: "结束了", de: "beendete die Existenz von", el: "αναίρεσε", fr: "a fait cesser d’exister", pt: "cessou a existência de", ru: "положил конец существованию"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12_occurred_in_the_presence_of",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P93i_was_taken_out_of_existence_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E77_Persistent_Item",
      label: {en: "was taken out of existence by", cn: "被结束於", de: "wurde seiner Existenz beraubt durch", el: "αναιρέθηκε από", fr: "a cessé d’exister du fait de", pt: "deixou de existir", ru: "прекратил существование посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E64_End_of_Existence",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P12i_was_present_at",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P94_has_created,
      comment: {en: "This property allows a conceptual E65 Creation to be linked to the E28 Conceptual Object created by it. \nIt represents the act of conceiving the intellectual content of the E28 Conceptual Object. It does not represent the act of creating the first physical carrier of the E28 Conceptual Object. As an example, this is the composition of a poem, not its commitment to paper.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E65_Creation",
      label: {en: "has created", cn: "创造了", de: "hat erschaffen", el: "δημιούργησε", fr: "a créé", pt: "criou", ru: "создал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92_brought_into_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P94i_was_created_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E28_Conceptual_Object",
      label: {en: "was created by", cn: "被创造於", de: "wurde erschaffen durch", el: "δημιουργήθηκε από", fr: "a été créé par", pt: "foi criado por", ru: "был создан посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E65_Creation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92i_was_brought_into_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P95_has_formed,
      comment: {en: "This property links the founding or E66 Formation for an E74 Group with the Group itself."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E66_Formation",
      label: {en: "has formed", cn: "组成了", de: "hat gebildet", el: "σχημάτισε", fr: "a fondé", pt: "formou", ru: "сформировал"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92_brought_into_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P95i_was_formed_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "was formed by", cn: "被组成於", de: "wurde gebildet von", el: "σχηματίστηκε από", fr: "a été fondé par", pt: "foi formado por", ru: "была сформирована посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E66_Formation",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92i_was_brought_into_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P96_by_mother,
      comment: {en: "This property links an E67 Birth event to an E21 Person as a participant in the role of birth-giving mother.\n\nNote that biological fathers are not necessarily participants in the Birth (see P97 from father (was father for)). The Person being born is linked to the Birth with the property P98 brought into life (was born). This is not intended for use with general natural history material, only people. There is no explicit method for modelling conception and gestation except by using extensions. This is a sub-property of P11 had participant (participated in).\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      label: {en: "by mother", cn: "来自生母", de: "durch Mutter", el: "είχε μητέρα", fr: "de mère", pt: "pela mãe", ru: "посредством матери"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11_had_participant",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P96i_gave_birth,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "gave birth", cn: "成为生母於", de: "gebar", el: "ήταν μητέρα του/της", fr: "a donné naissance à", pt: "deu nascimento", ru: "дал рождение"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P97_from_father,
      comment: {en: "This property links an E67 Birth event to an E21 Person in the role of biological father.\nNote that biological fathers are not seen as necessary participants in the Birth, whereas birth-giving mothers are (see P96 by mother (gave birth)). The Person being born is linked to the Birth with the property P98 brought into life (was born).\nThis is not intended for use with general natural history material, only people. There is no explicit method for modelling conception and gestation except by using extensions. \nA Birth event is normally (but not always) associated with one biological father.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      label: {en: "from father", cn: "来自父亲", de: "gab Vaterschaft", el: "είχε πατέρα", fr: "de père", pt: "pelo pai", ru: "от отца"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P97i_was_father_for,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "was father for", cn: "成为生父於", de: "war Vater für", el: "ήταν πατέρας του/της", fr: "a été père dans", pt: "foi pai para", ru: "был отцом для"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P98_brought_into_life,
      comment: {en: "This property links an E67Birth event to an E21 Person in the role of offspring.\nTwins, triplets etc. are brought into life by the same Birth event. This is not intended for use with general Natural History material, only people. There is no explicit method for modelling conception and gestation except by using extensions.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      label: {en: "brought into life", cn: "诞生了", de: "brachte zur Welt", el: "έφερε στη ζωή", fr: "a donné vie à", pt: "trouxe à vida", ru: "породил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92_brought_into_existence",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P98i_was_born,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E21_Person",
      label: {en: "was born", cn: "诞生於", de: "wurde geboren durch", el: "γεννήθηκε", fr: "est né", pt: "veio à vida pelo", ru: "был рожден"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E67_Birth",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P92i_was_brought_into_existence_by",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P99_dissolved,
      comment: {en: "This property links the disbanding or E68 Dissolution of an E74 Group to the Group itself."},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E68_Dissolution",
      label: {en: "dissolved", cn: "解散了", de: "löste auf", el: "διέλυσε", fr: "a dissous", pt: "dissolveu", ru: "распустил"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P11_had_participant", "http://www.cidoc-crm.org/cidoc-crm/P93_took_out_of_existence"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P99i_was_dissolved_by,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E74_Group",
      label: {en: "was dissolved by", cn: "被解散於", de: "wurde aufgelöst durch", el: "διαλύθηκε από", fr: "a été dissous par", pt: "foi dissolvido por", ru: "был распущен посредством"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E68_Dissolution",
      subPropertyOf: ["http://www.cidoc-crm.org/cidoc-crm/P11i_participated_in", "http://www.cidoc-crm.org/cidoc-crm/P93i_was_taken_out_of_existence_by"],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P9_consists_of,
      comment: {en: "This property associates an instance of E4 Period with another instance of E4 Period that falls within the spacetime volumes occupied by the former and which is defined by phenomena that form part of or are refinements of the phenomena that define the former.\n"},
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "consists of", cn: "包含子时期", de: "setzt sich zusammen aus", el: "αποτελείται από", fr: "consiste en", pt: "consiste de", ru: "состоит из"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P10i_contains",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
    property :P9i_forms_part_of,
      domain: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      label: {en: "forms part of", cn: "附属於", de: "bildet Teil von", el: "αποτελεί μέρος του/της", fr: "fait partie de", pt: "faz parte de", ru: "формирует часть"},
      range: "http://www.cidoc-crm.org/cidoc-crm/E4_Period",
      subPropertyOf: "http://www.cidoc-crm.org/cidoc-crm/P10_falls_within",
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
  end
end
